@@ -19,12 +19,17 @@
 
 
 from weboob.tools.test import BackendTest
+from weboob.tools.value import Value
 from datetime import datetime
 
 
 class AgendaculturelTest(BackendTest):
     MODULE = 'agendaculturel'
 
+    def setUp(self):
+        if not self.is_backend_configured():
+            self.backend.config['place'] = Value(value='paris')
+
     def test_agendaculturel(self):
         l = list(self.backend.list_events(datetime.now()))
         assert len(l)
