@@ -19,12 +19,17 @@
 
 
 from weboob.tools.test import BackendTest
+from weboob.tools.value import Value
 from datetime import datetime
 
 
 class AgendadulibreTest(BackendTest):
     MODULE = 'agendadulibre'
 
+    def setUp(self):
+        if not self.is_backend_configured():
+            self.backend.config['region'] = Value(value='http://www.agendadulibre.org')
+
     def test_agendadulibre(self):
         l = list(self.backend.list_events(datetime.now()))
         assert len(l)
