@@ -17,21 +17,42 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 from weboob.browser import PagesBrowser, URL
-from .pages import ResultsPage, RecipePage
+from .pages import ResultsPage, RecipePage, HomePage
+
+import urllib
 
 __all__ = ['AllrecipesBrowser']
 
 
 class AllrecipesBrowser(PagesBrowser):
-    BASEURL = 'http://allrecipes.com'
-    results = URL('search/results/\?wt=(?P<pattern>.*)\&sort=re',
-                  'recipes/.*', ResultsPage)
-    recipe = URL('recipe/(?P<_id>.*)/', RecipePage)
+    BASEURL = 'https://apps.allrecipes.com'
+    results = URL('/v1/recipes\?(?P<query>.*)', ResultsPage)
+    recipe = URL('/v1/recipes/(?P<_id>.*)/', RecipePage)
+    home = URL('http://allrecipes.com', HomePage)
+
+    TOKEN = None
+
+    def fill_token(self):
+        self.home.open()
+        self.TOKEN = 'Bearer %s' % self.session.cookies.get('ARToken')
+        self.session.headers['X-Requested-With'] = 'XMLHttpRequest'
+        self.session.headers['Authorization'] = self.TOKEN
 
     def iter_recipes(self, pattern):
-        return self.results.go(pattern=pattern).iter_recipes()
+        query = {'query': pattern,
+                 'page': 1,
+                 'pagesize': 20,
+                 'sort': 're'}
+
+        if not self.TOKEN:
+            self.fill_token()
+
+        return self.results.go(query=urllib.urlencode(query)).iter_recipes()
 
     def get_recipe(self, _id, obj=None):
+        if not self.TOKEN:
+            self.fill_token()
+
         recipe = self.recipe.go(_id=_id).get_recipe(obj=obj)
         comments = list(self.page.get_comments())
         if comments:
