@@ -26,6 +26,6 @@ class AmeliTest(BackendTest):
 
     def test_ameli(self):
         for subscription in self.backend.iter_subscription():
-            list(self.backend.iter_bills_history(subscription.id))
-            for bill in self.backend.iter_bills(subscription.id):
-                self.backend.download_bill(bill.id)
+            list(self.backend.iter_documents_history(subscription.id))
+            for bill in self.backend.iter_documents(subscription.id):
+                self.backend.download_document(bill.id)
