@@ -22,10 +22,10 @@ from weboob.tools.test import BackendTest
 
 
 class AmeliProTest(BackendTest):
-    MODULE = 'AmeliPro'
+    MODULE = 'amelipro'
 
     def test_AmeliPro(self):
         for subscription in self.backend.iter_subscription():
             list(self.backend.iter_history(subscription.id))
-            for bill in self.backend.iter_bills(subscription.id):
-                self.backend.download_bill(bill.id)
+            for bill in self.backend.iter_documents(subscription.id):
+                self.backend.download_document(bill.id)
