@@ -24,6 +24,7 @@ from weboob.capabilities.video import CapVideo, BaseVideo
 from weboob.capabilities.collection import CapCollection, CollectionNotFound, Collection
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import Value
+from weboob.exceptions import BrowserHTTPSDowngrade
 
 from .browser import ArteBrowser
 from .video import ArteVideo, ArteSiteVideo, VERSION_VIDEO, FORMATS, LANG, QUALITY, SITE
@@ -36,7 +37,7 @@ class ArteModule(Module, CapVideo, CapCollection):
     NAME = 'arte'
     MAINTAINER = u'Bezleputh'
     EMAIL = 'carton_ben@yahoo.fr'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = 'Arte French and German TV'
     LICENSE = 'AGPLv3+'
 
@@ -83,9 +84,14 @@ class ArteModule(Module, CapVideo, CapCollection):
         if not _id.startswith('http'):
             return 'videos', _id
 
+        return None, None
+
     def get_video(self, _id):
         site, _id = self.parse_id(_id)
 
+        if not (site and _id):
+            return None
+
         if site in [value.get('id') for value in SITE.values]:
             _site = (value for value in SITE.values if value.get('id') == site).next()
             return getattr(self.browser, _site.get('video'))(_id)
@@ -114,8 +120,10 @@ class ArteModule(Module, CapVideo, CapCollection):
                     break
 
         if 'thumbnail' in fields and video and video.thumbnail:
-            video.thumbnail.data = self.browser.open(video.thumbnail.url).content
-
+            try:
+                video.thumbnail.data = self.browser.open(video.thumbnail.url).content
+            except BrowserHTTPSDowngrade:
+                pass
         return video
 
     def iter_resources(self, objs, split_path):
