@@ -18,10 +18,12 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from datetime import timedelta
+import urllib
 
-from weboob.capabilities.image import BaseImage
+from weboob.capabilities.image import Thumbnail
 from weboob.capabilities.base import BaseObject, NotAvailable
 from weboob.capabilities.collection import Collection
+from weboob.capabilities.base import empty
 
 from weboob.browser.pages import HTMLPage, JsonPage
 from weboob.browser.elements import DictElement, ItemElement, ListElement, method
@@ -54,14 +56,20 @@ class ArteItemElement(ItemElement):
     obj_date = Date(Dict('VDA', default=NotAvailable), default=NotAvailable)
 
     def obj_duration(self):
-        seconds = Dict('videoDurationSeconds')(self)
-        if isinstance(seconds, basestring):
+        seconds = Dict('videoDurationSeconds', default=NotAvailable)(self)
+        if empty(seconds):
+            return seconds
+        elif isinstance(seconds, basestring):
             seconds = int(seconds)
+
         return timedelta(seconds=seconds)
 
     def obj_thumbnail(self):
-        url = Dict('VTU/IUR')(self)
-        thumbnail = BaseImage(url)
+        url = Dict('VTU/IUR', default=NotAvailable)(self)
+        if empty(url):
+            return url
+
+        thumbnail = Thumbnail(url)
         thumbnail.url = thumbnail.id
         return thumbnail
 
@@ -99,7 +107,40 @@ class VideosListPage(HTMLPage):
 
             def obj_thumbnail(self):
                 url = CleanText('div/div/a/figure/span/span/@data-src')(self)
-                thumbnail = BaseImage(url)
+                thumbnail = Thumbnail(url)
+                thumbnail.url = thumbnail.id
+                return thumbnail
+
+    @method
+    class iter_arte_creative_categories(ListElement):
+        item_xpath = '//ul[@class="menu"]/li/a[not(@target)]'
+
+        class item(ItemElement):
+            klass = Collection
+
+            obj_title = CleanText('.', default=u'Accueil')
+            obj_id = CleanText('./@href')
+
+            def obj_split_path(self):
+                _id = Regexp(CleanText('./@href'), '/\w{2}/(.*)', default=u'accueil')(self)
+                return [SITE.CREATIVE.get('id')] + [_id.replace('/', '^')]
+
+    @method
+    class iter_arte_creative_videos(ListElement):
+        item_xpath = '//div[div/i]'
+        ignore_duplicate = True
+
+        class item(ItemElement):
+            klass = ArteSiteVideo
+
+            obj__site = SITE.CREATIVE.get('id')
+            obj_id = Format('%s.%s', Field('_site'),
+                            CleanText('./div/h3/a/@href|./div/h1/a/@href'))
+            obj_title = CleanText('./div/h3/a|./div/h1/a')
+
+            def obj_thumbnail(self):
+                url = CleanText('./div/a/img/@src')(self)
+                thumbnail = Thumbnail(url)
                 thumbnail.url = thumbnail.id
                 return thumbnail
 
@@ -125,18 +166,17 @@ class VideosListPage(HTMLPage):
 
     @method
     class get_arte_cinema_videos(ListElement):
-        item_xpath = '//article'
+        item_xpath = '//div[has-class("article-list")]/article[@id]'
 
         class item(ItemElement):
             klass = ArteSiteVideo
 
             def condition(self):
-                return len(XPath('.//div[@class="article-secondary "]')(self)) == 1 and\
-                    len(XPath('.//article')(self)) == 0
+                return len(XPath('.//div[@class="article-secondary "]')(self)) == 1
 
             obj__site = SITE.CINEMA.get('id')
             obj_id = Format('%s.%s', Field('_site'),
-                            Regexp(CleanText('./div/a/@href'),
+                            Regexp(CleanText('./div/div/a/@href|./div/a/@href'),
                                    '(http://.*\.arte\.tv)?/(.*)',
                                    '\\2'))
             obj_title = Join(u' - ',
@@ -144,12 +184,17 @@ class VideosListPage(HTMLPage):
 
             def obj_thumbnail(self):
                 url = CleanText('.//div[@class="article-primary "]/div[has-class("field-thumbnail")]/span/noscript/img/@src')(self)
-                thumbnail = BaseImage(url)
+                thumbnail = Thumbnail(url)
                 thumbnail.url = thumbnail.id
                 return thumbnail
 
     def get_json_url(self):
-        return self.doc.xpath('//div[@class="video-container"]')[0].attrib['arte_vp_url']
+        if self.doc.xpath('//div[@class="video-container"]'):
+            return self.doc.xpath('//div[@class="video-container"]')[0].attrib['arte_vp_url']
+        elif self.doc.xpath('//iframe'):
+            url = Regexp(CleanText('./@src'), '.*json_url=(.*)')(self.doc.xpath('//iframe')[0])
+            return urllib.unquote(url)
+        return ''
 
 
 class ArteJsonPage(JsonPage):
@@ -173,8 +218,9 @@ class ArteJsonPage(JsonPage):
             streamer = Dict('videoJsonPlayer/VSR/%s/streamer' % (found), default=None)(self.doc)
             url = Dict('videoJsonPlayer/VSR/%s/url' % (found))(self.doc)
             if streamer:
-                return '%s%s' % (streamer, url)
-            return url
+                return '%s%s' % (streamer, url), found
+            return url, found
+        return NotAvailable, ''
 
     def find_url(self, key, urls, version, quality):
         self.logger.debug('available urls: %s' % urls)
@@ -250,7 +296,12 @@ class ArteJsonPage(JsonPage):
     class get_program_video(ArteItemElement):
         def __init__(self, *args, **kwargs):
             super(ArteItemElement, self).__init__(*args, **kwargs)
-            if 'VDO' in self.el['abstractProgram'].keys():
+
+            if 'videoJsonPlayer' in self.el:
+                self.el = self.el.get('videoJsonPlayer')
+            elif 'abstractProgram' not in self.el:
+                return None
+            elif 'VDO' in self.el['abstractProgram'].keys():
                 self.el = self.el['abstractProgram']['VDO']
 
         klass = ArteVideo
