@@ -49,8 +49,8 @@ class AuMException(UserError):
               "1.1.1":  "No member has this login",
               "1.1.2":  "Password don't match",
               "1.1.3":  "User has been banned",
-              "1.12.1": "Invalid country",
-              "1.12.1": "Invalid region",
+              "1.12.1": "Invalid country or region",
+              # "1.12.1": "Invalid region",
               "4.0.1":  "Member not found",
               "4.1.1":  "Thread doesn't exist",
               "4.1.2":  "Cannot write to this member",
