@@ -19,6 +19,7 @@
 
 
 from weboob.capabilities.bank import CapBank, AccountNotFound
+from weboob.capabilities.base import find_object
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword
 
@@ -32,30 +33,24 @@ class AXABanqueModule(Module, CapBank):
     NAME = 'axabanque'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'AXA Banque'
     LICENSE = 'AGPLv3+'
-    CONFIG = BackendConfig(ValueBackendPassword('login',    label=u'N° de client', regexp='\d+', masked=False),
+    CONFIG = BackendConfig(ValueBackendPassword('login',    label='Identifiant', masked=False),
                            ValueBackendPassword('password', label='Code', regexp='\d+'))
     BROWSER = AXABanque
 
     def create_default_browser(self):
-        return self.create_browser(self.config['login'].get(),
-                                   self.config['password'].get())
-
-    def iter_accounts(self):
-        with self.browser:
-            return self.browser.get_accounts_list()
+        return self.create_browser(self.config['login'].get(), self.config['password'].get())
 
     def get_account(self, _id):
-        with self.browser:
-            account = self.browser.get_account(_id)
+        return find_object(self.browser.iter_accounts(), id=_id, error=AccountNotFound)
 
-        if account:
-            return account
-        else:
-            raise AccountNotFound()
+    def iter_accounts(self):
+        return self.browser.iter_accounts()
+
+    def iter_investment(self, account):
+        return self.browser.iter_investment(account)
 
     def iter_history(self, account):
-        with self.browser:
-            return self.browser.get_history(account)
+        return self.browser.iter_history(account)
