@@ -33,7 +33,7 @@ class BanquePopulaireModule(Module, CapBank):
     NAME = 'banquepopulaire'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Banque Populaire'
     LICENSE = 'AGPLv3+'
     website_choices = OrderedDict([(k, u'%s (%s)' % (v, k)) for k, v in sorted({
@@ -41,6 +41,7 @@ class BanquePopulaireModule(Module, CapBank):
         'www.ibps.alsace.banquepopulaire.fr': u'Alsace',
         'www.ibps.bpaca.banquepopulaire.fr': u'Aquitaine Centre atlantique',
         'www.ibps.atlantique.banquepopulaire.fr': u'Atlantique',
+        'www.ibps.banquedesavoie.banquepopulaire.fr': u'Banque de Savoie',
         'www.ibps.bpbfc.banquepopulaire.fr': u'Bourgogne-Franche Comté',
         'www.ibps.bretagnenormandie.cmm.groupe.banquepopulaire.fr': u'Crédit Maritime Bretagne Normandie',
         'www.ibps.atlantique.creditmaritime.groupe.banquepopulaire.fr': u'Crédit Maritime Atlantique',
@@ -70,26 +71,20 @@ class BanquePopulaireModule(Module, CapBank):
                                    self.config['password'].get())
 
     def iter_accounts(self):
-        with self.browser:
-            return self.browser.get_accounts_list()
+        return self.browser.get_accounts_list()
 
     def get_account(self, _id):
-        with self.browser:
-            account = self.browser.get_account(_id)
-
+        account = self.browser.get_account(_id)
         if account:
             return account
         else:
             raise AccountNotFound()
 
     def iter_history(self, account):
-        with self.browser:
-            return self.browser.get_history(account)
+        return self.browser.get_history(account)
 
     def iter_coming(self, account):
-        with self.browser:
-            return self.browser.get_history(account, coming=True)
+        return self.browser.get_history(account, coming=True)
 
     def iter_investment(self, account):
-        with self.browser:
-            return self.browser.get_investment(account)
+        return self.browser.get_investment(account)
