@@ -21,6 +21,7 @@
 from weboob.capabilities.bank import CapBank, AccountNotFound
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword
+from weboob.capabilities.base import find_object
 
 from .browser import Barclays
 
@@ -32,7 +33,7 @@ class BarclaysModule(Module, CapBank):
     NAME = 'barclays'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Barclays'
     LICENSE = 'AGPLv3+'
     CONFIG = BackendConfig(ValueBackendPassword('login',    label=u"N° d'abonné", masked=False),
@@ -46,26 +47,20 @@ class BarclaysModule(Module, CapBank):
                                    self.config['password'].get())
 
     def iter_accounts(self):
-        with self.browser:
-            return self.browser.get_accounts_list()
+        return self.browser.get_accounts_list()
 
     def get_account(self, _id):
-        with self.browser:
-            account = self.browser.get_account(_id)
-
-        if account:
-            return account
-        else:
-            raise AccountNotFound()
+        return find_object(self.browser.get_account(), id=_id, error=AccountNotFound)
 
     def iter_history(self, account):
-        with self.browser:
-            for tr in self.browser.get_history(account):
-                if not tr._coming:
-                    yield tr
+        for tr in self.browser.get_history(account):
+            if not tr._coming:
+                yield tr
 
     def iter_coming(self, account):
-        with self.browser:
-            for tr in self.browser.get_card_operations(account):
-                if tr._coming:
-                    yield tr
+        for tr in self.browser.get_history(account):
+            if tr._coming:
+                yield tr
+
+    def iter_investment(self, account):
+        return self.browser.iter_investments(account)
