@@ -18,46 +18,49 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-import datetime
+import datetime, re
 from decimal import Decimal
-import re
 
-from weboob.deprecated.browser import Page
-from weboob.capabilities.bank import Account
+from weboob.browser.pages import HTMLPage, LoggedPage, PDFPage
+from weboob.browser.filters.standard import CleanText, CleanDecimal
+from weboob.browser.filters.html import Attr, Link
+from weboob.capabilities.bank import Account, Investment, NotAvailable
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 
 
-class LoginPage(Page):
+def MyDecimal(*args, **kwargs):
+    kwargs.update(replace_dots=True, default=NotAvailable)
+    return CleanDecimal(*args, **kwargs)
+
+
+class LoginPage(HTMLPage):
     def login(self, login, passwd):
-        self.browser.select_form(name='frmLogin')
-        self.browser['username'] = login.encode(self.browser.ENCODING)
-        self.browser['password'] = passwd.encode(self.browser.ENCODING)
-        self.browser.submit(nologin=True)
+        form = self.get_form(name='frmLogin')
+        form['username'] = login
+        form['password'] = passwd
+        form.submit()
 
     def has_redirect(self):
-        if len(self.document.getroot().xpath('//form')) > 0:
-            return False
-        else:
-            return True
+        return not len(self.doc.getroot().xpath('//form')) > 0
 
 
-class Login2Page(Page):
+class Login2Page(HTMLPage):
     def login(self, secret):
-        label = self.document.xpath('//span[@class="PF_LABEL"]')[0].text.strip()
+        label = self.doc.xpath('//span[@class="PF_LABEL"]')[0].text.strip()
         letters = ''
         for n in re.findall('(\d+)', label):
             letters += secret[int(n) - 1]
 
-        self.browser.select_form(name='frmControl')
-        self.browser['word'] = letters.encode(self.browser.ENCODING)
-        self.browser.submit(name='valider', nologin=True)
+        form = self.get_form(name='frmControl', submit='//*[@name="valider"]')
+        form['word'] = letters
+        form.submit()
 
 
-class IndexPage(Page):
+class IndexPage(HTMLPage):
     pass
 
 
-class AccountsPage(Page):
+class AccountsPage(LoggedPage, HTMLPage):
     ACCOUNT_TYPES = {u'Epargne':                Account.TYPE_SAVINGS,
                      u'Liquidités':             Account.TYPE_CHECKING,
                      u'Titres':                 Account.TYPE_MARKET,
@@ -67,7 +70,7 @@ class AccountsPage(Page):
     def get_list(self):
         accounts = []
 
-        for block in self.document.xpath('//div[@class="pave"]/div'):
+        for block in self.doc.xpath('//div[@class="pave"]/div'):
             head_type = block.xpath('./div/span[@class="accGroupLabel"]')[0].text.strip()
             account_type = self.ACCOUNT_TYPES.get(head_type, Account.TYPE_UNKNOWN)
             for tr in block.cssselect('ul li.tbord_account'):
@@ -80,27 +83,22 @@ class AccountsPage(Page):
                 link = tr.cssselect('span.accountLabel a')[0]
                 balance = Decimal(FrenchTransaction.clean_amount(tr.cssselect('span.accountTotal')[0].text))
 
-                if id.endswith('CRT'):
-                    account = accounts[-1]
-                    account._card_links.append(link.attrib['href'])
-                    if not account.coming:
-                        account.coming = Decimal('0.0')
-                    account.coming += balance
-                    continue
-
                 account = Account()
+                account._attached_acc = None
                 account.id = id
                 account.label = unicode(link.text.strip())
                 account.type = account_type
                 account.balance = balance
                 account.currency = account.get_currency(tr.cssselect('span.accountDev')[0].text)
                 account._link = link.attrib['href']
-                account._card_links = []
+                if id.endswith('CRT'):
+                    self.populate_cards(account)
+
                 accounts.append(account)
 
         if len(accounts) == 0:
             # Sometimes, accounts are only in javascript...
-            for script in self.document.xpath('//script'):
+            for script in self.doc.xpath('//script'):
                 text = script.text
                 if text is None:
                     continue
@@ -108,7 +106,6 @@ class AccountsPage(Page):
                     continue
 
                 account = None
-                card_account = None
                 attribs = {}
                 account_type = Account.TYPE_UNKNOWN
                 for line in text.split('\n'):
@@ -130,40 +127,51 @@ class AccountsPage(Page):
                             account.balance = Decimal(FrenchTransaction.clean_amount(attribs['soldeDateOpeValeurFormatted']))
                             account.currency = account.get_currency(attribs['codeDevise'])
                             account._link = 'tbord.do?id=%s&%s' % (attribs['id'], self.browser.SESSION_PARAM)
-                            account._card_links = []
+                            account._attached_acc = None
 
                             if account.id.endswith('CRT'):
-                                if not len(accounts):
-                                    card_account = account
-                                else:
-                                    a = accounts[-1]
-                                    a._card_links.append(account._link)
-                                    if not a.coming:
-                                        a.coming = Decimal('0.0')
-                                    a.coming += account.balance
-                            else:
-                                if 'COURANT' in account.label:
-                                    account.type = account.TYPE_CHECKING
-                                elif account.id.endswith('TTR'):
-                                    account.type = account.TYPE_MARKET
-                                elif re.match('^\d+C$', account.id):
-                                    account.type = account.TYPE_LIFE_INSURANCE
-                                elif re.match('^\d+PRT$', account.id):
-                                    account.type = account.TYPE_LOAN
-                                elif not account.type:
-                                    account.type = account.TYPE_SAVINGS
+                                self.populate_cards(account)
+                            elif any([word in account.label.lower() for word in ['courant', 'joint', 'perso']]):
+                                account.type = account.TYPE_CHECKING
+                            elif account.id.endswith('TTR'):
+                                account.type = account.TYPE_MARKET
+                            elif re.match('^\d+C$', account.id):
+                                account.type = account.TYPE_LIFE_INSURANCE
+                            elif re.match('^\d+PRT$', account.id):
+                                account.type = account.TYPE_LOAN
+                            elif not account.type:
+                                account.type = account.TYPE_SAVINGS
 
-                                if card_account:
-                                    account._card_links.append(card_account._link)
-                                    if not account.coming:
-                                        account.coming = Decimal('0.0')
-                                    account.coming += card_account.balance
-                                    card_account = None
-                                accounts.append(account)
+                            accounts.append(account)
                             account = None
 
         return accounts
 
+    def get_ibanlink(self):
+        return Link('//a[@id="editionRibLevel2link"]', default=None)(self.doc)
+
+    def populate_cards(self, account):
+        account.type = account.TYPE_CARD
+        account.coming = account.balance
+        account.balance = Decimal('0.0')
+        doc = self.browser.open(account._link).page.doc
+        self.browser.open(self.browser.url)
+        account._attached_acc = ''.join(re.findall('\d', doc.xpath(u'//td[contains(text(), "Carte rattachée")]')[0].text))
+
+
+class IbanPage(LoggedPage, HTMLPage):
+    def get_list(self):
+        form = self.get_form(name='frmRIB')
+        trs = self.doc.xpath('//tr[td[a[@checkaccount]]]')
+        return {'form': form, 'list': \
+            {CleanText('./td[1]', replace=[(' ', '')])(tr): Attr('.//a[@checkaccount]', 'checkaccount')(tr) for tr in trs}}
+
+
+class IbanPDFPage(LoggedPage, PDFPage):
+    def get_iban(self):
+        ibans = re.findall(r'1001\d{3}.9\d{3}.73Tm\/F18Tf000rg\(([A-Z\d]+)\)', "".join(self.doc.split()))
+        return NotAvailable if not len(ibans) else CleanText().filter(ibans[0])
+
 
 class Transaction(FrenchTransaction):
     PATTERNS = [(re.compile('^RET DAB (?P<text>.*?) RETRAIT DU (?P<dd>\d{2})(?P<mm>\d{2})(?P<yy>\d{2}).*'),
@@ -191,15 +199,24 @@ class Transaction(FrenchTransaction):
                ]
 
 
-class HistoryBasePage(Page):
-    def get_history(self):
-        self.logger.warning('Do not support account of type %s' % type(self).__name__)
+class HistoryBasePage(HTMLPage):
+    def iter_investments(self):
+        self.logger.warning('Do not support investments on account of type %s' % type(self).__name__)
         return iter([])
 
-
-class TransactionsPage(HistoryBasePage):
     def get_history(self):
-        for tr in self.document.xpath('//table[@id="operation"]/tbody/tr'):
+        self.logger.warning('Do not support history on account of type %s' % type(self).__name__)
+        return iter([])
+
+    def get_next_page(self):
+        link = self.doc.xpath('//a[span[contains(text(), "Suiv.")]]')
+        if link:
+            return link[0].attrib['href']
+
+
+class TransactionsPage(LoggedPage, HistoryBasePage):
+    def get_history(self):
+        for tr in self.doc.xpath('//table[@id="operation"]/tbody/tr'):
             tds = tr.findall('td')
 
             if len(tds) < 5:
@@ -215,17 +232,17 @@ class TransactionsPage(HistoryBasePage):
             t.set_amount(credit, debit)
             t._coming = False
 
-            if t.raw.startswith('ACHAT CARTE -DEBIT DIFFERE'):
-                continue
+            if t.raw.startswith('ACHAT CARTE -DEBIT DIFFERE') or 'ACHAT-DEBIT DIFFERE' in t.raw:
+                t.type = t.TYPE_CARD_SUMMARY
 
             yield t
 
 
-class CardPage(HistoryBasePage):
+class CardPage(LoggedPage, HistoryBasePage):
     def get_history(self):
         debit_date = None
         coming = True
-        for tr in self.document.xpath('//table[@class="report"]/tbody/tr'):
+        for tr in self.doc.xpath('//table[@class="report"]/tbody/tr'):
             tds = tr.findall('td')
 
             if len(tds) == 2:
@@ -246,25 +263,38 @@ class CardPage(HistoryBasePage):
             if debit_date is not None:
                 t.date = debit_date
             t.label = unicode(tds[1].find('span').text.strip())
-            t.type = t.TYPE_CARD
+            t.type = t.TYPE_DEFERRED_CARD
             t._coming = coming
             t.set_amount(amount)
             yield t
 
 
-class ValuationPage(HistoryBasePage):
+class ValuationPage(LoggedPage, HistoryBasePage):
     pass
 
 
-class LoanPage(HistoryBasePage):
+class LoanPage(LoggedPage, HistoryBasePage):
     pass
 
 
-class MarketPage(HistoryBasePage):
+class MarketPage(LoggedPage, HistoryBasePage):
     pass
 
-class AssurancePage(HistoryBasePage):
-    pass
 
-class LogoutPage(Page):
+class AssurancePage(LoggedPage, HistoryBasePage):
+    def iter_investments(self):
+        for tr in self.doc.xpath('//table[@id="support"]/tbody/tr'):
+            tds = tr.findall('td')
+
+            inv = Investment()
+            inv.label = CleanText('.')(tds[0])
+            inv.code = NotAvailable
+
+            inv.quantity = MyDecimal('.')(tds[1])
+            inv.unitvalue = MyDecimal('.')(tds[2])
+            inv.valuation = MyDecimal('.')(tds[3])
+            yield inv
+
+
+class LogoutPage(HTMLPage):
     pass
