@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright(C) 2010-2013 Romain Bignon
+# Copyright(C) 2010-2016 Romain Bignon
 #
 # This file is part of weboob.
 #
@@ -21,8 +21,11 @@
 from decimal import Decimal
 from datetime import datetime, timedelta
 
-from weboob.capabilities.bank import CapBank, AccountNotFound, Account, Recipient
+from weboob.capabilities.bank import CapBankTransfer, AccountNotFound, \
+                                     Account, TransferError, RecipientNotFound
 from weboob.capabilities.messages import CapMessages, Thread
+from weboob.capabilities.contact import CapContact
+from weboob.capabilities.base import find_object
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword, Value
 
@@ -35,11 +38,11 @@ from .pp.browser import BNPPartPro, HelloBank
 __all__ = ['BNPorcModule']
 
 
-class BNPorcModule(Module, CapBank, CapMessages):
+class BNPorcModule(Module, CapBankTransfer, CapMessages, CapContact):
     NAME = 'bnporc'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     LICENSE = 'AGPLv3+'
     DESCRIPTION = 'BNP Paribas'
     CONFIG = BackendConfig(
@@ -67,6 +70,8 @@ class BNPorcModule(Module, CapBank, CapMessages):
     def create_default_browser(self):
         b = {'ppold': BNPorc, 'ent': BNPEnterprise, 'ent2': BNPCompany, 'pp': BNPPartPro, 'hbank': HelloBank}
         self.BROWSER = b[self.config['website'].get()]
+        if self.BROWSER is BNPPartPro:
+            return self.create_browser(self.config)
         return self.create_browser(self.config['login'].get(),
                                    self.config['password'].get())
 
@@ -90,32 +95,47 @@ class BNPorcModule(Module, CapBank, CapMessages):
     def iter_investment(self, account):
         return self.browser.iter_investment(account)
 
-    def iter_transfer_recipients(self, ignored):
-        if self.config['website'].get() != 'ppold':
+    def iter_transfer_recipients(self, origin_account):
+        if self.config['website'].get() != 'pp':
+            raise NotImplementedError()
+        if isinstance(origin_account, Account):
+            origin_account = origin_account.id
+        return self.browser.iter_recipients(origin_account)
+
+    def init_transfer(self, transfer, **params):
+        if self.config['website'].get() != 'pp':
             raise NotImplementedError()
 
-        for account in self.browser.get_transfer_accounts().itervalues():
-            recipient = Recipient()
-            recipient.id = account.id
-            recipient.label = account.label
-            yield recipient
+        if transfer.label is None:
+            raise TransferError(u'Veuillez préciser un libellé au virement')
 
-    def transfer(self, account, to, amount, reason=None):
-        if self.config['website'].get() != 'ppold':
-            raise NotImplementedError()
+        self.logger.info('Going to do a new transfer')
+        if transfer.account_iban:
+            account = find_object(self.iter_accounts(), iban=transfer.account_iban, error=AccountNotFound)
+        else:
+            account = find_object(self.iter_accounts(), id=transfer.account_id, error=AccountNotFound)
 
-        if isinstance(account, Account):
-            account = account.id
+        if transfer.recipient_iban:
+            recipient = find_object(self.iter_transfer_recipients(account.id), iban=transfer.recipient_iban, error=RecipientNotFound)
+        else:
+            recipient = find_object(self.iter_transfer_recipients(account.id), id=transfer.recipient_id, error=RecipientNotFound)
 
         try:
-            assert account.isdigit()
-            assert to.isdigit()
-            amount = Decimal(amount)
+            assert account.id.isdigit()
+            # quantize to show 2 decimals.
+            amount = Decimal(transfer.amount).quantize(Decimal(10) ** -2)
         except (AssertionError, ValueError):
-            raise AccountNotFound()
+            raise TransferError('something went wrong')
 
-        with self.browser:
-            return self.browser.transfer(account, to, amount, reason)
+        return self.browser.init_transfer(account, recipient, amount, transfer.label)
+
+    def execute_transfer(self, transfer, **params):
+        return self.browser.execute_transfer(transfer)
+
+    def iter_contacts(self):
+        if not hasattr(self.browser, 'get_advisor'):
+            raise NotImplementedError()
+        return self.browser.get_advisor()
 
     def iter_threads(self, cache=False):
         """
