@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright(C) 2009-2015  Romain Bignon
+# Copyright(C) 2009-2016  Romain Bignon
 #
 # This file is part of weboob.
 #
@@ -24,13 +24,17 @@ from random import randint
 from decimal import Decimal
 from datetime import datetime
 
+from weboob.browser.elements import DictElement, ListElement, ItemElement, method
+from weboob.browser.filters.json import Dict
+from weboob.browser.filters.standard import Format, Regexp, CleanText
 from weboob.browser.pages import JsonPage, LoggedPage, HTMLPage
-from weboob.tools.captcha.virtkeyboard import GridVirtKeyboard
-from weboob.capabilities.bank import Account, Investment
 from weboob.capabilities import NotAvailable
-from weboob.tools.capabilities.bank.transactions import FrenchTransaction
+from weboob.capabilities.bank import Account, Investment, Recipient, Transfer, TransferError
+from weboob.capabilities.contact import Advisor
 from weboob.exceptions import BrowserIncorrectPassword, BrowserUnavailable
-from weboob.tools.json import json
+from weboob.tools.capabilities.bank.iban import rib2iban, rebuild_rib, is_iban_valid
+from weboob.tools.capabilities.bank.transactions import FrenchTransaction
+from weboob.tools.captcha.virtkeyboard import GridVirtKeyboard
 from weboob.tools.date import parse_french_date as Date
 
 
@@ -51,7 +55,7 @@ class ConnectionThresholdPage(HTMLPage):
 
     def on_load(self):
         new_pass = ''.join([str((int(l) + 1) % 10) for l in self.browser.password])
-        self.logger.warning('Password expired. Renewing it...')
+        self.logger.warning('Password expired. Renewing it. Temporary password is %s', new_pass)
         self.change_pass(self.browser.password, new_pass)
         self.change_pass(new_pass, self.browser.password)
 
@@ -98,7 +102,7 @@ class LoginPage(JsonPage):
     def build_doc(self, text):
         try:
             return super(LoginPage, self).build_doc(text)
-        except json.JSONDecodeError:
+        except ValueError:
             # XXX When login is successful, server sends HTML instead of JSON,
             #     we can ignore it.
             return {}
@@ -110,10 +114,12 @@ class LoginPage(JsonPage):
         error = cast(self.get('errorCode'), int, 0)
 
         if error:
-            codes = [201, 21510, 203, 202, 1001]
+            codes = [201, 21510, 203, 202]
             msg = self.get('message')
             if error in codes:
                 raise BrowserIncorrectPassword(msg)
+            elif error == 1001:
+                raise BrowserUnavailable(msg)
             self.logger.debug('Unexpected error at login: "%s" (code=%s)' % (msg, error))
 
     def login(self, username, password):
@@ -140,7 +146,7 @@ class LoginPage(JsonPage):
 class BNPPage(LoggedPage, JsonPage):
     def build_doc(self, text):
         try:
-            return json.loads(text, parse_float=Decimal)
+            return self.response.json(parse_float=Decimal)
         except ValueError:
             raise BrowserUnavailable()
 
@@ -152,6 +158,7 @@ class BNPPage(LoggedPage, JsonPage):
             self.browser.do_login()
         elif code:
             self.logger.debug('Unexpected error: "%s" (code=%s)' % (self.get('message'), code))
+            return (self.get('message'), code)
 
 
 class AccountsPage(BNPPage):
@@ -166,17 +173,25 @@ class AccountsPage(BNPPage):
         9: Account.TYPE_LOAN,
     }
 
+    LABEL_TO_TYPE = {
+        u'PEA Espèces':    Account.TYPE_SAVINGS,
+    }
+
     def iter_accounts(self, ibans):
         for f in self.path('data.infoUdc.familleCompte.*'):
             for a in f.get('compte'):
+                iban = ibans.get(a.get('key'))
+                if iban is not None and not is_iban_valid(iban):
+                    iban = rib2iban(rebuild_rib(iban))
+
                 yield Account.from_dict({
                     'id': a.get('key'),
                     'label': a.get('libellePersoProduit') or a.get('libelleProduit'),
                     'currency': a.get('devise'),
-                    'type': self.FAMILY_TO_TYPE.get(f.get('idFamilleCompte')) or Account.TYPE_UNKNOWN,
+                    'type': self.LABEL_TO_TYPE.get(a.get('libelleProduit')) or self.FAMILY_TO_TYPE.get(f.get('idFamilleCompte')) or Account.TYPE_UNKNOWN,
                     'balance': a.get('soldeDispo'),
                     'coming': a.get('soldeAVenir'),
-                    'iban': ibans.get(a.get('key')),
+                    'iban': iban,
                     'number': a.get('value')
                 })
 
@@ -185,10 +200,126 @@ class AccountsIBANPage(BNPPage):
     def get_ibans_dict(self):
         return dict([(a['ibanCrypte'], a['iban']) for a in self.path('data.listeRib.*.infoCompte')])
 
+class MyRecipient(ItemElement):
+    klass = Recipient
+
+    obj_currency = Dict('devise')
+
+    def obj_enabled_at(self):
+        return datetime.now().replace(microsecond=0)
+
+    def validate(self, el):
+        assert is_iban_valid(el.iban)
+        return True
 
 class TransferInitPage(BNPPage):
-    def get_ibans_dict(self):
-        return dict([(a['ibanCrypte'], a['iban']) for a in self.path('data.infoVirement.listeComptesCrediteur.*')])
+    def on_load(self):
+        message_code = BNPPage.on_load(self)
+        if message_code is not None:
+            raise TransferError('%s, code=%s' % (message_code[0], message_code[1]))
+
+    def get_ibans_dict(self, account_type):
+        return dict([(a['ibanCrypte'], a['iban']) for a in self.path('data.infoVirement.listeComptes%s.*' % account_type)])
+
+    def can_transfer_to_recipients(self, origin_account_id):
+        return next(a['eligibleVersBenef'] for a in self.path('data.infoVirement.listeComptesDebiteur.*') if a['ibanCrypte'] == origin_account_id) == '1'
+
+    @method
+    class transferable_on(DictElement):
+        item_xpath = 'data/infoVirement/listeComptesCrediteur'
+
+        class item(MyRecipient):
+            condition = lambda self: Dict('ibanCrypte')(self.el) != self.env['origin_account_ibancrypte']
+
+            obj_id = Dict('ibanCrypte')
+            obj_label = Dict('libelleCompte')
+            obj_iban = Dict('iban')
+            obj_category = u'Interne'
+
+            def obj_bank_name(self):
+                return u'BNP PARIBAS'
+
+
+class RecipientsPage(BNPPage):
+    @method
+    class iter_recipients(DictElement):
+        item_xpath = 'data/infoBeneficiaire/listeBeneficiaire'
+
+        class item(MyRecipient):
+            # For the moment, only yield ready to transfer on recipients.
+            condition = lambda self: Dict('libelleStatut')(self.el) == u'Activé'
+
+            obj_id = Dict('idBeneficiaire')
+            obj_label = Dict('nomBeneficiaire')
+            obj_iban = Dict('ibanNumCompte')
+            obj_category = u'Externe'
+
+            def obj_bank_name(self):
+                return Dict('nomBanque')(self) or NotAvailable
+
+
+class ValidateTransferPage(BNPPage):
+    def check_errors(self):
+        if not 'data' in self.doc:
+            raise TransferError(self.doc['message'])
+
+    def abort_if_unknown(self, transfer_data):
+        try:
+            assert transfer_data['typeOperation'] in ['1', '2']
+            assert transfer_data['repartitionFrais'] == '0'
+            assert transfer_data['devise'] == 'EUR'
+            assert not transfer_data['montantDeviseEtrangere']
+        except AssertionError as e:
+            raise TransferError(e)
+
+    def handle_response(self, account, recipient, amount, reason):
+        self.check_errors()
+        transfer_data = self.doc['data']['validationVirement']
+
+        self.abort_if_unknown(transfer_data)
+
+        if transfer_data['idBeneficiaire'] is not None:
+            assert transfer_data['idBeneficiaire'] == recipient.id
+
+        exec_date = Date(transfer_data['dateExecution']).date()
+        today = datetime.today().date()
+        if transfer_data['typeOperation'] == '1':
+            assert exec_date == today
+        else:
+            assert exec_date > today
+
+        transfer = Transfer()
+        transfer.currency = transfer_data['devise']
+        transfer.amount = Decimal(transfer_data['montantEuros'])
+        transfer.account_iban = transfer_data['ibanCompteDebiteur']
+        transfer.recipient_iban = transfer_data['ibanCompteCrediteur'] or recipient.iban
+        transfer.account_id = account.id
+        transfer.recipient_id = recipient.id
+        transfer.exec_date = exec_date
+        transfer.fees = Decimal(transfer_data['montantFrais'])
+        transfer.label = transfer_data['motifVirement']
+
+        transfer.account_label = account.label
+        transfer.recipient_label = recipient.label
+        transfer.id = transfer_data['reference']
+        # This is true if a transfer with the same metadata has already been done recently
+        transfer._doublon = transfer_data['doublon']
+        transfer.account_balance = account.balance
+
+        return transfer
+
+
+class RegisterTransferPage(ValidateTransferPage):
+    def handle_response(self, transfer):
+        self.check_errors()
+        transfer_data = self.doc['data']['enregistrementVirement']
+
+        transfer.id = transfer_data['reference']
+        assert transfer.exec_date == Date(self.doc['data']['enregistrementVirement']['dateExecution']).date()
+        # Timestamp at which the bank registered the transfer
+        transfer._register_date = Date(self.doc['data']['enregistrementVirement']['dateEnregistrement'])
+
+        return transfer
 
 
 class Transaction(FrenchTransaction):
@@ -366,3 +497,18 @@ class MarketHistoryPage(BNPPage):
             inv.set_empty_fields(NotAvailable)
             tr.investments.append(inv)
             yield tr
+
+
+class AdvisorPage(BNPPage):
+    @method
+    class get_advisor(ListElement):
+        class item(ItemElement):
+            klass = Advisor
+
+            obj_name = Format('%s %s %s', Dict('data/civilite'), Dict('data/prenom'), Dict('data/nom'))
+            obj_email = Regexp(Dict('data/mail'), '(?=\w)(.*)')
+            obj_phone = CleanText(Dict('data/telephone'), replace=[(' ', '')])
+            obj_mobile = CleanText(Dict('data/mobile'), replace=[(' ', '')])
+            obj_fax = CleanText(Dict('data/fax'), replace=[(' ', '')])
+            obj_agency = Dict('data/agence')
+            obj_address = Format('%s %s %s', Dict('data/adresseAgence'), Dict('data/codePostalAgence'), Dict('data/villeAgence'))
