@@ -18,9 +18,8 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from weboob.browser import LoginBrowser, URL, need_login
-from weboob.browser.exceptions import ServerError
 from weboob.exceptions import BrowserIncorrectPassword
-from .pages import BillsPage, HomePage, LoginPage, ProfilePage, SendSMSPage, SendSMSErrorPage
+from .pages import DocumentsPage, HomePage, LoginPage, ProfilePage, SendSMSPage, SendSMSErrorPage
 
 from weboob.capabilities.messages import CantSendMessage
 
@@ -31,17 +30,16 @@ class BouyguesBrowser(LoginBrowser):
     BASEURL = 'https://www.mon-compte.bouyguestelecom.fr/'
     TIMEOUT = 20
 
-    bills = URL('http://www.bouyguestelecom.fr/mon-compte/mes-factures/historique\?no_reference=(?P<ref>)', BillsPage)
-    profile = URL('https://api-mc.bouyguestelecom.fr/client/me/header.json', ProfilePage)
-    home = URL('https://www.bouyguestelecom.fr/mon-compte/', HomePage)
     login = URL('cas/login', LoginPage)
+    home = URL('https://www.bouyguestelecom.fr/mon-compte', HomePage)
+    profile = URL('https://api-mc.bouyguestelecom.fr/client/me/header.json', ProfilePage)
+    documents = URL('https://www.bouyguestelecom.fr/parcours/mes-factures',
+                    'https://www.bouyguestelecom.fr/parcours/mes-factures/historique\?no_reference=(?P<ref>)', DocumentsPage)
 
     sms_page = URL('http://www.mobile.service.bbox.bouyguestelecom.fr/services/SMSIHD/sendSMS.phtml',
                    'http://www.mobile.service.bbox.bouyguestelecom.fr/services/SMSIHD/confirmSendSMS.phtml',
                    SendSMSPage)
-
     confirm = URL('http://www.mobile.service.bbox.bouyguestelecom.fr/services/SMSIHD/resultSendSMS.phtml')
-
     sms_error_page = URL('http://www.mobile.service.bbox.bouyguestelecom.fr/services/SMSIHD/SMS_erreur.phtml',
                          SendSMSErrorPage)
 
@@ -52,8 +50,10 @@ class BouyguesBrowser(LoginBrowser):
             return
 
         self.login.go()
+
         if self.home.is_here():
             return
+
         self.page.login(self.username, self.password)
 
         if not self.home.is_here():
@@ -79,16 +79,13 @@ class BouyguesBrowser(LoginBrowser):
 
     @need_login
     def get_subscription_list(self):
-        try:
-            # Informations are available in the header.json file.
-            # The only required field is the contract number
-            # which is available is the source of the homepage too.
-            # Possibly the json file contains more informations but
-            # he appears to be unavailable sometimes.
-            return self.profile.stay_or_go().get_list()
-        except ServerError:
-            return self.home.stay_or_go().get_list()
+        return self.profile.stay_or_go().get_list()
 
     @need_login
-    def iter_bills(self, subscription):
-        return self.bills.stay_or_go(ref=subscription._contract).get_bills(subid=subscription.id)
+    def iter_documents(self, subscription):
+        ref = self.documents.go().get_ref(subscription.label)
+
+        if not ref:
+            return iter([])
+
+        return self.documents.go(ref=ref).get_documents(subid=subscription.id)
