@@ -18,7 +18,10 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from weboob.capabilities.bank import CapBank, Account
+from decimal import Decimal
+from weboob.capabilities.bank import CapBankTransfer, Account, AccountNotFound, RecipientNotFound, TransferError
+from weboob.capabilities.contact import CapContact
+from weboob.capabilities.base import find_object
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword, Value
 
@@ -28,11 +31,11 @@ from .browser import BPBrowser, BProBrowser
 __all__ = ['BPModule']
 
 
-class BPModule(Module, CapBank):
+class BPModule(Module, CapBankTransfer, CapContact):
     NAME = 'bp'
     MAINTAINER = u'Nicolas Duhamel'
     EMAIL = 'nicolas@jombi.fr'
-    VERSION = '1.1'
+    VERSION = '1.2'
     LICENSE = 'AGPLv3+'
     DESCRIPTION = u'La Banque Postale'
     CONFIG = BackendConfig(ValueBackendPassword('login',    label='Identifiant', masked=False),
@@ -50,7 +53,7 @@ class BPModule(Module, CapBank):
         return self.browser.get_accounts_list()
 
     def get_account(self, _id):
-        return self.browser.get_account(_id)
+        return find_object(self.browser.get_accounts_list(), id=_id, error=AccountNotFound)
 
     def iter_history(self, account):
         if account.type == Account.TYPE_MARKET:
@@ -64,10 +67,44 @@ class BPModule(Module, CapBank):
             if tr._coming:
                 yield tr
 
-    def transfer(self, id_from, id_to, amount, reason=None):
-        from_account = self.get_account(id_from)
-        to_account = self.get_account(id_to)
+    def iter_investment(self, account):
+        return self.browser.iter_investment(account)
 
-        #TODO: retourner le numero du virement
-        #TODO: support the 'reason' parameter
-        return self.browser.make_transfer(from_account, to_account, amount)
+    def iter_transfer_recipients(self, origin_account):
+        if self.config['website'].get() != 'par':
+            raise NotImplementedError()
+        if isinstance(origin_account, Account):
+            origin_account = origin_account.id
+        return self.browser.iter_recipients(origin_account)
+
+    def init_transfer(self, transfer, **params):
+        if self.config['website'].get() != 'par':
+            raise NotImplementedError()
+
+        self.logger.info('Going to do a new transfer')
+        if transfer.account_iban:
+            account = find_object(self.iter_accounts(), iban=transfer.account_iban, error=AccountNotFound)
+        else:
+            account = find_object(self.iter_accounts(), id=transfer.account_id, error=AccountNotFound)
+
+        if transfer.recipient_iban:
+            recipient = find_object(self.iter_transfer_recipients(account.id), iban=transfer.recipient_iban, error=RecipientNotFound)
+        else:
+            recipient = find_object(self.iter_transfer_recipients(account.id), id=transfer.recipient_id, error=RecipientNotFound)
+
+        try:
+            # quantize to show 2 decimals.
+            amount = Decimal(transfer.amount).quantize(Decimal(10) ** -2)
+        except (AssertionError, ValueError):
+            raise TransferError('something went wrong')
+
+        return self.browser.init_transfer(account, recipient, amount, transfer.label)
+
+    def execute_transfer(self, transfer, **params):
+        return self.browser.execute_transfer(transfer)
+
+    def iter_contacts(self):
+        if self.config['website'].get() != 'par':
+            raise NotImplementedError()
+
+        return self.browser.get_advisor()
