@@ -19,6 +19,7 @@
 
 
 from weboob.capabilities.bank import CapBank, AccountNotFound
+from weboob.capabilities.contact import CapContact
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import Value, ValueBackendPassword
 from weboob.tools.ordereddict import OrderedDict
@@ -29,13 +30,14 @@ from .browser import CaisseEpargne
 __all__ = ['CaisseEpargneModule']
 
 
-class CaisseEpargneModule(Module, CapBank):
+class CaisseEpargneModule(Module, CapBank, CapContact):
     NAME = 'caissedepargne'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Caisse d\'Épargne'
     LICENSE = 'AGPLv3+'
+    BROWSER = CaisseEpargne
     website_choices = OrderedDict([(k, u'%s (%s)' % (v, k)) for k, v in sorted({
         'www.caisse-epargne.fr':     u'Caisse d\'Épargne',
         'www.banquebcp.fr':          u'Banque BCP',
@@ -43,8 +45,7 @@ class CaisseEpargneModule(Module, CapBank):
     CONFIG = BackendConfig(Value('website',  label='Banque', choices=website_choices, default='www.caisse-epargne.fr'),
                            ValueBackendPassword('login',    label='Identifiant client', masked=False),
                            ValueBackendPassword('password', label='Code personnel', regexp='\d+'),
-                           Value('nuser', label='User ID (optional)', default=''))
-    BROWSER = CaisseEpargne
+                           Value('nuser',                   label='User ID (optional)', default=''))
 
     def create_default_browser(self):
         return self.create_browser(nuser=self.config['nuser'].get(),
@@ -52,13 +53,15 @@ class CaisseEpargneModule(Module, CapBank):
                                    password=self.config['password'].get(),
                                    domain=self.config['website'].get())
 
+
     def iter_accounts(self):
-        with self.browser:
-            return self.browser.get_accounts_list()
+        for account in self.browser.get_accounts_list():
+            yield account
+        for account in self.browser.get_loans_list():
+            yield account
 
     def get_account(self, _id):
-        with self.browser:
-            account = self.browser.get_account(_id)
+        account = self.browser.get_account(_id)
 
         if account:
             return account
@@ -66,12 +69,13 @@ class CaisseEpargneModule(Module, CapBank):
             raise AccountNotFound()
 
     def iter_history(self, account):
-        with self.browser:
-            return self.browser.get_history(account)
+        return self.browser.get_history(account)
 
     def iter_coming(self, account):
-        with self.browser:
-            return self.browser.get_coming(account)
+        return self.browser.get_coming(account)
 
     def iter_investment(self, account):
         return self.browser.get_investment(account)
+
+    def iter_contacts(self):
+        return self.browser.get_advisor()
