@@ -24,15 +24,12 @@ from weboob.capabilities.bank import Account, AccountNotFound, Transaction
 from weboob.exceptions import BrowserIncorrectPassword
 from weboob.tools.capabilities.bank.transactions import \
     AmericanTransaction as AmTr
+from weboob.tools.js import Javascript
 
 from .parser import StatementParser, clean_label
 
 import re
-import os
 from datetime import datetime
-from tempfile import mkstemp
-from subprocess import STDOUT
-from weboob.tools.compat import check_output
 
 from time import sleep
 
@@ -43,7 +40,8 @@ __all__ = ['Citibank']
 class SomePage(HTMLPage):
     @property
     def logged(self):
-        return bool(self.doc.xpath(u'//a[text()="Sign Off"]'))
+        return bool(self.doc.xpath(u'//a[text()="Sign Off"]') +
+            self.doc.xpath(u'//div[@id="CardsLoadingDiv"]'))
 
 
 class IndexPage(SomePage):
@@ -56,12 +54,9 @@ class IndexPage(SomePage):
         script = re.sub(APPEND, lambda m: 'return %s;' % m.group(1), script)
         script = re.sub(r'jQuery\(document\)[^\n]+\n', '', script)
         for x in re.findall('function ([^(]+)\(', script):
-            script += '\nvar x = %s(); if (x) print(x);' % x
-        scriptFd, scriptName = mkstemp('.js')
-        os.write(scriptFd, script)
-        os.close(scriptFd)
-        html = check_output(["d8", scriptName], stderr=STDOUT)
-        os.remove(scriptName)
+            script += '\nvar x = %s(); if (x) return x;' % x
+        js = Javascript("function run(){%s}" % script)
+        html = js.call("run")
         return re.findall(r'name=([^ ]+) value=([^>]+)>', html)
 
 
@@ -88,8 +83,13 @@ class AccDetailsPage(JsonPage):
         for bal in details['accountBalances']:
             label, value = bal['label'], (bal['value'] or ['0'])[0]
             if label == u'Current Balance:':
+                if value[0] == '(' and value[-1] == ')':
+                    value = value[1:-1]
+                    sign = 1
+                else:
+                    sign = -1
                 account.currency = Account.get_currency(value)
-                account.balance = -AmTr.decimal_amount(value)
+                account.balance = sign * AmTr.decimal_amount(value)
             elif label == u'Total Revolving Credit Line:':
                 account.cardlimit = AmTr.decimal_amount(value)
             elif label.startswith(u'Minimum Payment Due'):
@@ -166,11 +166,13 @@ class Citibank(LoginBrowser):
     Contributions are welcome!
     """
 
-    BASEURL = 'https://online.citibank.com'
+    BASEURL = 'https://online.citi.com'
     MAX_RETRIES = 10
     TIMEOUT = 30.0
     index = URL(r'/US/JPS/portal/Index.do', IndexPage)
     signon = URL(r'/US/JSO/signon/ProcessUsernameSignon.do', SomePage)
+    accdetailhtml = URL(u'/US/NCPS/accountdetailactivity/flow.action.*$',
+                        SomePage)
     accounts = URL(r'/US/REST/accountsPanel'
                    r'/getCustomerAccounts.jws\?ttc=(?P<ttc>.*)$',
                    AccountsPage)
