@@ -23,8 +23,8 @@ from weboob.capabilities.base import find_object
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import Value, ValueBackendPassword
 
-from .mobile.browser import CmsoMobileBrowser
-from .web.browser import CmsoProBrowser
+from .par.browser import CmsoParBrowser
+from .pro.browser import CmsoProBrowser
 
 
 __all__ = ['CmsoModule']
@@ -34,26 +34,34 @@ class CmsoModule(Module, CapBank):
     NAME = 'cmso'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Crédit Mutuel Sud-Ouest'
     LICENSE = 'AGPLv3+'
     CONFIG = BackendConfig(ValueBackendPassword('login',    label='Identifiant', masked=False),
                            ValueBackendPassword('password', label='Mot de passe'),
                            Value('website', label='Type de compte', default='par',
                                  choices={'par': 'Particuliers', 'pro': 'Professionnels'}))
-    BROWSER = CmsoMobileBrowser
+
+    BROWSER = CmsoParBrowser
 
     def create_default_browser(self):
-        b = {'par': CmsoMobileBrowser, 'pro': CmsoProBrowser}
+        b = {'par': CmsoParBrowser, 'pro': CmsoProBrowser}
         self.BROWSER = b[self.config['website'].get()]
-        return self.create_browser(self.config['login'].get(),
+        return self.create_browser("cmso.com",
+                                   self.config['login'].get(),
                                    self.config['password'].get())
 
-    def iter_accounts(self):
-        return self.browser.get_accounts_list()
-
     def get_account(self, _id):
-        return find_object(self.browser.get_accounts_list(), id=_id, error=AccountNotFound)
+        return find_object(self.browser.iter_accounts(), id=_id, error=AccountNotFound)
+
+    def iter_accounts(self):
+        return self.browser.iter_accounts()
 
     def iter_history(self, account):
-        return self.browser.get_history(account)
+        return self.browser.iter_history(account)
+
+    def iter_coming(self, account):
+        return self.browser.iter_coming(account)
+
+    def iter_investment(self, account):
+        return self.browser.iter_investment(account)
