@@ -22,14 +22,17 @@ import re
 import urllib
 from urlparse import urlparse
 
+from mechanize import FormNotFoundError
+
 from weboob.capabilities.bank import Account
 from weboob.deprecated.browser import Browser, BrowserIncorrectPassword
 from weboob.tools.date import LinearDateGuesser
+from weboob.exceptions import BrowserHTTPError
 
 from .pages import HomePage, LoginPage, LoginErrorPage, AccountsPage, \
                    SavingsPage, TransactionsPage, UselessPage, CardsPage, \
                    LifeInsurancePage, MarketPage, LoansPage, PerimeterPage, \
-                   ChgPerimeterPage
+                   ChgPerimeterPage, MarketHomePage, FirstVisitPage, BGPIPage
 
 
 __all__ = ['Cragr']
@@ -43,26 +46,32 @@ class Cragr(Browser):
              'https?://[^/]+/particuliers.html':                         HomePage,
              'https?://[^/]+/stb/entreeBam':                             LoginPage,
              'https?://[^/]+/stb/entreeBam\?.*typeAuthentification=CLIC_ALLER.*': LoginPage,
-             'https?://[^/]+/stb/entreeBam\?.*pagePremVisite.*':         UselessPage,
+             'https?://[^/]+/stb/entreeBam\?.*pagePremVisite.*':         FirstVisitPage,
              'https?://[^/]+/stb/entreeBam\?.*Interstitielle.*':         UselessPage,
              'https?://[^/]+/stb/entreeBam\?.*act=Tdbgestion':           UselessPage,
              'https?://[^/]+/stb/entreeBam\?.*act=Synthcomptes':         AccountsPage,
+             'https?://[^/]+/stb/collecteNI\?.*sessionAPP=Synthcomptes.*indicePage=.*': AccountsPage,
              'https?://[^/]+/stb/entreeBam\?.*act=Synthcredits':         LoansPage,
+             'https?://[^/]+/stb/collecteNI\?.*sessionAPP=Synthcredits.*indicePage=.*': LoansPage,
              'https?://[^/]+/stb/entreeBam\?.*act=Synthepargnes':        SavingsPage,
+             'https?://[^/]+/stb/collecteNI\?.*sessionAPP=Synthepargnes.*indicePage=.*': SavingsPage,
              'https?://[^/]+/stb/.*act=Releves.*':                       TransactionsPage,
              'https?://[^/]+/stb/collecteNI\?.*sessionAPP=Releves.*':    TransactionsPage,
              'https?://[^/]+/stb/.*/erreur/.*':                          LoginErrorPage,
              'https?://[^/]+/stb/entreeBam\?.*act=Messagesprioritaires': UselessPage,
              'https?://[^/]+/stb/collecteNI\?.*fwkaction=Cartes.*':      CardsPage,
+             'https?://[^/]+/stb/collecteNI\?.*sessionAPP=Cartes.*':      CardsPage,
              'https?://[^/]+/stb/collecteNI\?.*fwkaction=Detail.*sessionAPP=Cartes.*': CardsPage,
              'https?://www.cabourse.credit-agricole.fr/netfinca-titres/servlet/com.netfinca.frontcr.account.WalletVal\?nump=.*': MarketPage,
-             'https://assurance-personnes.credit-agricole.fr:443/filiale/entreeBam\?identifiantBAM=.*': LifeInsurancePage,
+             'https?://www.cabourse.credit-agricole.fr/netfinca-titres/servlet/com.netfinca.frontcr.synthesis.HomeSynthesis': MarketHomePage,
+             'https://assurance-personnes.credit-agricole.fr(:443)?/filiale/.*': LifeInsurancePage,
+             'https://bgpi-gestionprivee.credit-agricole.fr/bgpi/.*': BGPIPage,
 
              'https?://[^/]+/stb/entreeBam\?.*act=Perimetre':        PerimeterPage,
              'https?://[^/]+/stb/entreeBam\?.*act=ChgPerim.*':       ChgPerimeterPage,
             }
 
-    new_login_domain = ['m.ca-normandie.fr']
+    new_login_domain = []
     new_login = False
 
     class WebsiteNotSupported(Exception):
@@ -77,6 +86,7 @@ class Cragr(Browser):
         self.accounts_url = None
         self.savings_url = None
         self._sag = None  # updated while browsing
+        self._old_sag = None
         self.code_caisse = None  # constant for a given website
         self.perimeters = None
         self.current_perimeter = None
@@ -116,7 +126,7 @@ class Cragr(Browser):
                 raise self.WebsiteNotSupported()
 
             # First, post account number to get the password prompt.
-            data = {'CCPTE':                self.username.encode(self.ENCODING),
+            data = {'CCPTE':                self.username[:11].encode(self.ENCODING),
                     'canal':                'WEB',
                     'hauteur_ecran':        768,
                     'largeur_ecran':        1024,
@@ -129,12 +139,15 @@ class Cragr(Browser):
                     'vitrine':              0,
                 }
 
-            self.location(url, urllib.urlencode(data))
+            self.location(url, urllib.urlencode(data), no_login=True)
 
         assert self.is_on_page(LoginPage)
 
         # Then, post the password.
-        self.page.login(self.username, self.password)
+        try:
+            self.page.login(self.username, self.password)
+        except FormNotFoundError:
+            raise BrowserIncorrectPassword()
 
         if self.new_login:
             url = self.page.get_accounts_url()
@@ -145,7 +158,7 @@ class Cragr(Browser):
         if not url.startswith('http'):
             raise BrowserIncorrectPassword(url)
 
-        self.location(url)
+        self.location(url.replace('Synthese', 'Synthcomptes'))
 
         if self.is_on_page(LoginErrorPage):
             raise BrowserIncorrectPassword()
@@ -159,7 +172,7 @@ class Cragr(Browser):
             self.location(new_url)
 
         if not self.is_on_page(AccountsPage):
-            raise self.WebsiteNotSupported()
+            raise BrowserIncorrectPassword()
 
         if self.code_caisse is None:
             scripts = self.page.document.xpath('//script[contains(., " codeCaisse")]')
@@ -192,11 +205,11 @@ class Cragr(Browser):
         if self.page.get_error() is not None:
             self.broken_perimeters.append(perimeter)
 
-    def get_accounts_list(self, no_move=False):
+    def get_accounts_list(self):
         l = list()
-        if self.perimeters and not no_move:
+        if self.perimeters:
             for perimeter in [p for p in self.perimeters if p not in self.broken_perimeters]:
-                if self.current_perimeter != perimeter:
+                if (self.page and not self.page.get_current()) or self.current_perimeter != perimeter:
                     self.go_perimeter(perimeter)
                 for account in self.get_list():
                     if not account in l:
@@ -205,6 +218,24 @@ class Cragr(Browser):
             l = self.get_list()
         return l
 
+    def get_cards_or_card(self, account_id=None):
+        accounts = []
+        if not self.is_on_page(AccountsPage):
+            self.location(self.accounts_url.format(self.sag))
+
+        for idelco in self.page.cards_idelco_or_link():
+            if not self.is_on_page(AccountsPage):
+                self.location(self.accounts_url.format(self.sag))
+            self.location(self.page.cards_idelco_or_link(idelco))
+            assert self.is_on_page(CardsPage)
+            for account in self.page.get_list():
+                if account_id and account.number == account_id:
+                    return account
+                else:
+                    accounts.append(account)
+
+        return accounts
+
     def get_list(self):
         accounts_list = []
         # regular accounts
@@ -213,10 +244,9 @@ class Cragr(Browser):
         accounts_list.extend(self.page.get_list())
 
         # credit cards
-        for cards_page in self.page.cards_pages():
-            self.location(cards_page)
-            assert self.is_on_page(CardsPage)
-            accounts_list.extend(self.page.get_list())
+        # reseting location in case of pagination
+        self.location(self.accounts_url.format(self.sag))
+        accounts_list.extend(self.get_cards_or_card())
 
         # loan accounts
         self.location(self.loans_url.format(self.sag))
@@ -231,12 +261,27 @@ class Cragr(Browser):
             for account in self.page.get_list():
                 if account not in accounts_list:
                     accounts_list.append(account)
+
+        # update market accounts
+        for account in accounts_list:
+            if account.type == Account.TYPE_MARKET:
+                try:
+                    new_location = self.moveto_market_website(account, home=True)
+                except self.WebsiteNotSupported:
+                    account._link = None
+                    self.update_sag()
+                else:
+                    self.location(new_location)
+                    self.page.update(accounts_list)
+                    self.quit_market_website()
+                    break
+
         return accounts_list
 
-    def get_account(self, id, no_move=False):
+    def get_account(self, id):
         assert isinstance(id, basestring)
 
-        l = self.get_accounts_list(no_move)
+        l = self.get_accounts_list()
         for a in l:
             if a.id == ('%s' % id):
                 return a
@@ -246,46 +291,53 @@ class Cragr(Browser):
     def get_history(self, account):
         if account.type in (Account.TYPE_MARKET, Account.TYPE_LIFE_INSURANCE):
             self.logger.warning('This account is not supported')
-            return
+            raise NotImplementedError()
 
         # some accounts may exist without a link to any history page
-        if account._link is None:
+        if account._link is None or 'CATITRES' in account._link:
             return
 
-        did_move = False
         if account._perimeter != self.current_perimeter:
             self.go_perimeter(account._perimeter)
-            did_move = True
 
         # card accounts need to get an updated link
         if account.type == Account.TYPE_CARD:
-            account = self.get_account(account.id, no_move=True)
+            account = self.get_cards_or_card(account.number)
 
         date_guesser = LinearDateGuesser()
-        self.location(account._link.format(self.sag))
+        if account.type != Account.TYPE_CARD or not self.page.is_on_right_detail(account):
+            self.location(account._link.format(self.sag))
 
         if self.is_on_page(CardsPage):
-            for tr in self.page.get_history(date_guesser):
-                yield tr
-        else:
-            url = self.page.get_order_by_date_url()
-
+            url = self.page.url
+            state = None
+            notfirst = False
             while url:
-                self.location(url)
+                if notfirst:
+                    self.location(url)
+                else:
+                    notfirst = True
+                assert self.is_on_page(CardsPage)
+                for state, tr in self.page.get_history(date_guesser, state):
+                    yield tr
+
+                url = self.page.get_next_url()
+
+        elif self.page:
+            self.page.order_transactions()
+            while True:
                 assert self.is_on_page(TransactionsPage)
 
                 for tr in self.page.get_history(date_guesser):
                     yield tr
 
                 url = self.page.get_next_url()
-
-        # Ugly hack needed for for following card accounts history
-        if did_move:
-            self.get_accounts_list()
+                if url is None:
+                    break
+                self.location(url)
 
     def iter_investment(self, account):
         if not account._link or account.type not in (Account.TYPE_MARKET, Account.TYPE_LIFE_INSURANCE):
-            self.logger.warning('This account is not supported')
             return
 
         if account._perimeter != self.current_perimeter:
@@ -293,10 +345,19 @@ class Cragr(Browser):
 
         if account.type == Account.TYPE_MARKET:
             new_location = self.moveto_market_website(account)
-            self.location(new_location)
+            # Detail unavailable
+            try:
+                self.location(new_location)
+            except BrowserHTTPError:
+                return
         elif account.type == Account.TYPE_LIFE_INSURANCE:
             new_location = self.moveto_insurance_website(account)
             self.location(new_location, urllib.urlencode({}))
+            if self.is_on_page(BGPIPage):
+                if not self.page.go_detail():
+                    return
+            if self.is_on_page(LifeInsurancePage):
+                self.page.go_on_detail(account.id)
 
         for inv in self.page.iter_investment():
             yield inv
@@ -306,7 +367,7 @@ class Cragr(Browser):
         elif account.type == Account.TYPE_LIFE_INSURANCE:
             self.quit_insurance_website()
 
-    def moveto_market_website(self, account):
+    def moveto_market_website(self, account, home=False):
         response = self.openurl(account._link % self.sag).read()
         self._sag = None
         # https://www.cabourse.credit-agricole.fr/netfinca-titres/servlet/com.netfinca.frontcr.navigation.AccueilBridge?TOKEN_ID=
@@ -318,6 +379,8 @@ class Cragr(Browser):
             raise self.WebsiteNotSupported()
 
         self.openurl(url)
+        if home:
+            return 'https://www.cabourse.credit-agricole.fr/netfinca-titres/servlet/com.netfinca.frontcr.synthesis.HomeSynthesis'
         parsed = urlparse(url)
         url = '%s://%s/netfinca-titres/servlet/com.netfinca.frontcr.account.WalletVal?nump=%s:%s'
         return url % (parsed.scheme, parsed.netloc, account.id, self.code_caisse)
@@ -338,6 +401,9 @@ class Cragr(Browser):
         self._sag = None
         # POST to https://assurance-personnes.credit-agricole.fr/filiale/ServletReroutageCookie
         form = doc.find('//form[@name="formulaire"]')
+        # bgpi-gestionprivee.
+        if not form:
+            return re.search('location="([^"]+)"', self.openurl(account._link % self.sag).read(), flags=re.MULTILINE).group(1)
         data = {
             'page': form.inputs['page'].attrib['value'],
             'cMaxAge': '-1',
@@ -357,6 +423,8 @@ class Cragr(Browser):
         return form.attrib['action']
 
     def quit_insurance_website(self):
+        if self.is_on_page(BGPIPage):
+            return self.page.go_back()
         exit_url = 'https://assurance-personnes.credit-agricole.fr/filiale/entreeBam?actCrt=Synthcomptes&sessionSAG=%s&stbpg=pagePU&act=&typeaction=reroutage_retour&site=BAMG2&stbzn=bnc'
         doc = self.get_document(self.openurl(exit_url % self.sag), encoding='utf-8')
         form = doc.find('//form[@name="formulaire"]')
@@ -376,4 +444,7 @@ class Cragr(Browser):
             self.login()
 
         script = self.page.document.xpath("//script[contains(.,'idSessionSag =')]")
-        self._sag = re.search('idSessionSag = "([^"]+)";', script[0].text).group(1)
+        if script:
+            self._old_sag = self._sag = re.search('idSessionSag = "([^"]+)";', script[0].text).group(1)
+        else:
+            self._sag = self._old_sag
