@@ -17,17 +17,32 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
+from datetime import date as ddate
 from decimal import Decimal
+from urlparse import urlparse
 import re
 
 from weboob.capabilities import NotAvailable
 from weboob.capabilities.bank import Account, Investment
 from weboob.deprecated.browser import Page, BrokenPageError, BrowserIncorrectPassword
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction as Transaction
-from weboob.tools.date import parse_french_date
+from weboob.tools.date import parse_french_date, LinearDateGuesser
+from weboob.browser.filters.standard import Date
 
 
 class BasePage(Page):
+    def on_loaded(self):
+        self.get_current()
+
+    def get_current(self):
+        try:
+            current_elem = self.document.xpath('//div[@id="libPerimetre_2"]/span[@class="textePerimetre_2"]')[0]
+        except IndexError:
+            self.logger.debug('Can\'t update current perimeter on this page (%s).', type(self).__name__)
+            return False
+        self.browser.current_perimeter = re.search('(.*)$', self.parser.tocleanstring(current_elem)).group(1).lower()
+        return True
+
     def get_error(self):
         try:
             error = self.document.xpath('//h1[@class="h1-erreur"]')[0]
@@ -61,6 +76,7 @@ class LoginPage(BasePage):
             raise BrowserIncorrectPassword()
 
     def login(self, username, password):
+        password = password[:6]
         imgmap = {}
         for td in self.document.xpath('//table[@id="pave-saisie-code"]/tr/td'):
             a = td.find('a')
@@ -98,6 +114,11 @@ class LoginErrorPage(BasePage):
     pass
 
 
+class FirstVisitPage(BasePage):
+    def on_loaded(self):
+        raise BrowserIncorrectPassword(u'Veuillez vous connecter au site du Crédit Agricole pour valider vos données personnelles, et réessayer ensuite.')
+
+
 class _AccountsPage(BasePage):
     COL_LABEL    = 0
     COL_ID       = 2
@@ -120,6 +141,9 @@ class _AccountsPage(BasePage):
              u'TIWI':       Account.TYPE_SAVINGS,
              u'CSL LSO':    Account.TYPE_SAVINGS,
              u'CSL CSP':    Account.TYPE_SAVINGS,
+             u'ESPE INTEG': Account.TYPE_SAVINGS,
+             u'DAV TIGERE': Account.TYPE_SAVINGS,
+             u'CPTEXCPRO':  Account.TYPE_SAVINGS,
              u'PRET PERSO': Account.TYPE_LOAN,
              u'P. HABITAT': Account.TYPE_LOAN,
              u'PRET 0%':    Account.TYPE_LOAN,
@@ -159,7 +183,7 @@ class _AccountsPage(BasePage):
             account = Account()
             account.id = self.parser.tocleanstring(cols[self.COL_ID])
             account.label = self.parser.tocleanstring(cols[self.COL_LABEL])
-            account.type = account_type or self.TYPES.get(account.label, Account.TYPE_UNKNOWN)
+            account.type = self.TYPES.get(account.label, Account.TYPE_UNKNOWN) or account_type
             balance = self.parser.tocleanstring(cols[self.COL_VALUE])
             # we have to ignore those accounts, because using NotAvailable
             # makes boobank and probably many others crash
@@ -174,12 +198,19 @@ class _AccountsPage(BasePage):
             account._perimeter = self.browser.current_perimeter
             yield account
 
+        # Checking pagination
+        next_link = self.document.xpath('//a[@class="btnsuiteliste"]/@href')
+        if next_link:
+            self.browser.location(next_link[0])
+            for account in self.browser.page.get_list():
+                yield account
+
     def set_link(self, account, cols):
         raise NotImplementedError()
 
-    def cards_pages(self):
+    def cards_idelco_or_link(self, account_idelco=None):
         # Use a set because it is possible to see several times the same link.
-        links = set()
+        idelcos = set()
         for line in self.document.xpath('//table[@class="ca-table"]/tr[@class="ligne-connexe"]'):
             try:
                 link = line.xpath('.//a/@href')[0]
@@ -187,21 +218,17 @@ class _AccountsPage(BasePage):
                 pass
             else:
                 if not link.startswith('javascript:'):
-                    links.add(link)
-        return links
+                    if account_idelco and 'IDELCO=%s&' % account_idelco in link:
+                        return link
+                    m = re.search('IDELCO=(\d+)&', link)
+                    if m:
+                        idelcos.add(m.group(1))
+        return idelcos
 
     def check_perimeters(self):
         return len(self.document.xpath('//a[@title="Espace Autres Comptes"]'))
 
 class PerimeterPage(BasePage):
-    def get_current(self):
-        try:
-            current_elem = self.document.xpath('//div[@id="libPerimetre"]/span[@class="texte"]')[0]
-        except IndexError:
-            # The user need to validate CGU, can't do it for him.
-            return
-        self.browser.current_perimeter = re.search(': (.*)$', self.parser.tocleanstring(current_elem)).group(1).lower()
-
     def check_multiple_perimeters(self):
         self.browser.perimeters = list()
         self.get_current()
@@ -210,22 +237,33 @@ class PerimeterPage(BasePage):
         self.browser.perimeters.append(self.browser.current_perimeter)
         multiple = self.document.xpath(u'//p[span/a[contains(text(), "Accès")]]')
         if not multiple:
-            assert self.document.xpath(u'//div[contains(text(), "Périmètre en cours de chargement. Merci de patienter quelques secondes.")]')
+            if not len(self.document.xpath(u'//div[contains(text(), "Périmètre en cours de chargement. Merci de patienter quelques secondes.")]')):
+                self.logger.debug('Possible error on this page.')
             # We change perimeter in this case to add the second one.
-            self.browser.location(self.browser.chg_perimeter_url.format(self.browser.sag))
-        for p in multiple:
-            self.browser.perimeters.append(' '.join(p.find('label').text.lower().split()))
+            self.browser.location(self.browser.chg_perimeter_url.format(self.browser.sag), no_login=True)
+            if self.browser.page.get_error() is not None:
+                self.browser.broken_perimeters.append('the other perimeter is broken')
+                self.browser.login()
+        else:
+            for table in self.document.xpath('//table[@class]'):
+                space = ' '.join(table.find('caption').text.lower().split())
+                for perim in table.xpath('.//label'):
+                    self.browser.perimeters.append(u'%s : %s' % (space, ' '.join(perim.text.lower().split())))
 
     def get_perimeter_link(self, perimeter):
-        for p in self.document.xpath(u'//p[span/a[contains(text(), "Accès")]]'):
-            if perimeter in ' '.join(p.find('label').text.lower().split()):
-                link = p.xpath('./span/a')[0].attrib['href']
-                return link
+        caption = perimeter.split(' : ')[0].title()
+        perim = perimeter.split(' : ')[1]
+        for table in self.document.xpath('//table[@class and caption[contains(text(), "%s")]]' % caption):
+            for p in table.xpath(u'.//p[span/a[contains(text(), "Accès")]]'):
+                if perim in ' '.join(p.find('label').text.lower().split()):
+                    link = p.xpath('./span/a')[0].attrib['href']
+                    return link
 
 
 class ChgPerimeterPage(PerimeterPage):
     def on_loaded(self):
         if self.get_error() is not None:
+            self.logger.debug('Error on ChgPerimeterPage')
             return
         self.get_current()
         if not self.browser.current_perimeter.lower() in [' '.join(p.lower().split()) for p in self.browser.perimeters]:
@@ -239,6 +277,7 @@ class CardsPage(BasePage):
 
         cards_tables = self.document.xpath(TABLE_XPATH)
 
+        currency = self.document.xpath('//table/caption//span/text()[starts-with(.,"Montants en ")]')[0].replace("Montants en ", "") or None
         if cards_tables:
             self.logger.debug('There are several cards')
             xpaths = {
@@ -261,18 +300,24 @@ class CardsPage(BasePage):
             TABLE_XPATH = '(//table[@class="ca-table"])[1]'
             cards_tables = self.document.xpath(TABLE_XPATH)
 
+
         for table in cards_tables:
             get = lambda name: self.parser.tocleanstring(table.xpath(xpaths[name])[0])
 
             account = Account()
             account.type = account.TYPE_CARD
-            account.id = ''.join(get('_id').split()[1:])
+            account.number = ''.join(get('_id').split()[1:])
+            # account.number might be the same for two different cards ..
+            account.id = '%s%s' % (account.number, get('label2').replace(' ', ''))
+            account._id = ' '.join(get('_id').split()[1:])
             account.label = '%s - %s' % (get('label1'),
                                          re.sub('\s*-\s*$', '', get('label2')))
             try:
                 account.balance = Decimal(Transaction.clean_amount(table.xpath(xpaths['balance'])[-1].text))
                 account.currency = account.get_currency(self.document
                         .xpath(xpaths['currency'])[0].replace("Montants en ", ""))
+                if not account.currency and currency:
+                    account.currency = Account.get_currency(currency)
             except IndexError:
                 account.balance = Decimal('0.0')
 
@@ -285,11 +330,25 @@ class CardsPage(BasePage):
                     account._link = re.sub('[\n\r\t]+', '', account._link)
             else:
                 account._link = self.url
-
+            account._idelco = re.search('IDELCO=(\d+)&', self.url).group(1)
             account._perimeter = self.browser.current_perimeter
             yield account
 
-    def get_history(self, date_guesser):
+    def order_transactions(self):
+        pass
+
+    def get_next_url(self):
+        links = self.document.xpath('//font[@class="btnsuiteliste"]')
+        if len(links) < 1:
+            return None
+
+        a = links[-1].find('a')
+        if a.attrib.get('class', '') == 'liennavigationcorpspage':
+            return a.attrib['href']
+
+        return None
+
+    def get_history(self, date_guesser, state=None):
         seen = set()
         lines = self.document.xpath('(//table[@class="ca-table"])[2]/tr')
         debit_date = None
@@ -310,8 +369,10 @@ class CardsPage(BasePage):
                 m = re.search('(\d+ [^ ]+ \d+)', label)
                 if not m:
                     raise BrokenPageError('Unable to read card balance in history: %r' % label)
-
-                debit_date = parse_french_date(m.group(1))
+                if state is None:
+                    debit_date = parse_french_date(m.group(1))
+                else:
+                    debit_date = state
 
                 # Skip the first line because it is balance
                 if i == 0:
@@ -321,6 +382,7 @@ class CardsPage(BasePage):
 
                 # Consider the second one as a positive amount to reset balance to 0.
                 t.amount = -t.amount
+                state = t.date
             else:
                 day, month = map(int, date.split('/', 1))
                 t.rdate = date_guesser.guess_date(day, month)
@@ -334,12 +396,15 @@ class CardsPage(BasePage):
                 self.logger.debug(t.label)
                 raise
 
-            yield t
+            yield state, t
+
+    def is_on_right_detail(self, account):
+        return len(self.document.xpath(u'//h1[contains(text(), "Cartes - détail")]')) and\
+               len(self.document.xpath(u'//td[contains(text(), "%s")] | //td[contains(text(), "%s")] ' % (account.number, account._id)))
 
 
 class AccountsPage(_AccountsPage):
     def set_link(self, account, cols):
-        iban = None
         a = cols[0].find('a')
         if a is not None:
             account._link = a.attrib['href'].replace(' ', '%20')
@@ -348,15 +413,7 @@ class AccountsPage(_AccountsPage):
             url = page.get_iban_url()
             if url:
                 page = self.browser.get_page(self.browser.openurl(url))
-                iban = account.iban = page.get_iban()
-            elif iban:
-                # In case there is no available IBAN on this account (for
-                # example saving account), calculate it from the previous
-                # IBAN.
-                bankcode = iban[4:9]
-                counter = iban[9:14]
-                key = 97 - ((int(bankcode) * 89 + int(counter) * 15 + int(account.id) * 3) % 97)
-                account.iban = iban[:4] + bankcode + counter + account.id + str(key)
+                account.iban = page.get_iban()
 
 
 class LoansPage(_AccountsPage):
@@ -372,23 +429,36 @@ class SavingsPage(_AccountsPage):
     COL_ID = 1
 
     def set_link(self, account, cols):
+        origin = urlparse(self.url)
         if not account._link:
             a = cols[0].xpath('descendant::a[contains(@href, "CATITRES")]')
-            if a:
+            # Sometimes there is no link.
+            if a or account.type == Account.TYPE_MARKET:
                 url = 'https://%s/stb/entreeBam?sessionSAG=%%s&stbpg=pagePU&site=CATITRES&typeaction=reroutage_aller'
-                account._link = url % self.browser.request.host
+                account._link = url % origin.netloc
 
             a = cols[0].xpath("descendant::a[contains(@href, \"'PREDICA','CONTRAT'\")]")
             if a:
                 account.type = Account.TYPE_LIFE_INSURANCE
                 url = 'https://%s/stb/entreeBam?sessionSAG=%%s&stbpg=pagePU&site=PREDICA&' \
                       'typeaction=reroutage_aller&sdt=CONTRAT&parampartenaire=%s'
-                account._link = url % (self.browser.request.host, account.id)
+                account._link = url % (origin.netloc, account.id)
+            a = cols[0].xpath('descendant::a[not(contains(@href, "javascript"))]')
+            if len(a) == 1 and not account._link:
+                account._link = a[0].attrib['href'].replace(' ', '%20')
+                account._link = re.sub('sessionSAG=[^&]+', 'sessionSAG={0}', account._link)
+            a = cols[0].xpath('descendant::a[(contains(@href, "javascript"))]')
+            # This aims to handle bgpi-gestionprivee.
+            if len(a) == 1 and not account._link:
+                m = re.findall("'([^']*)'", a[0].attrib['href'])
+                if len(m) == 3:
+                    url = 'https://%s/stb/entreeBam?sessionSAG=%%s&stbpg=pagePU&typeaction=reroutage_aller&site=%s&sdt=%s&parampartenaire=%s'
+                    account._link = url % (origin.netloc, m[0], m[1], m[2])
 
 
 class TransactionsPage(BasePage):
     def get_iban_url(self):
-        for link in self.document.xpath('//a[contains(text(), "IBAN")]'):
+        for link in self.document.xpath('//a[contains(text(), "RIB")] | //a[contains(text(), "IBAN")]'):
             m = re.search("\('([^']+)'", link.get('href', ''))
             if m:
                 return m.group(1)
@@ -401,6 +471,16 @@ class TransactionsPage(BasePage):
             s += self.parser.tocleanstring(font)
         return s
 
+    def order_transactions(self):
+        date = self.document.xpath('//th[@scope="col"]/a[text()="Date"]')
+        if len(date) < 1:
+            return
+
+        if 'active' in date[0].attrib.get('class', ''):
+            return
+
+        self.browser.location(date[0].attrib['href'])
+
     def get_next_url(self):
         links = self.document.xpath('//span[@class="pager"]/a[@class="liennavigationcorpspage"]')
         if len(links) < 1:
@@ -412,13 +492,6 @@ class TransactionsPage(BasePage):
 
         return None
 
-    def get_order_by_date_url(self):
-        try:
-            link = self.document.xpath('//table[@class="ca-table"]/thead//a[text()="Date"]')[0].attrib['href']
-        except IndexError:
-            link = self.url
-        return link
-
     COL_DATE  = 0
     COL_TEXT  = 1
     COL_DEBIT = None
@@ -440,7 +513,12 @@ class TransactionsPage(BasePage):
             }
 
     def get_history(self, date_guesser):
-        for tr in self.document.xpath('//table[@class="ca-table"]//tr'):
+        trs = self.document.xpath('//table[@class="ca-table" and @summary]//tr')
+        if trs:
+            self.COL_TEXT += 1
+        else:
+            trs = self.document.xpath('//table[@class="ca-table"]//tr')
+        for tr in trs:
             parent = tr.getparent()
             while parent is not None and parent.tag != 'table':
                 parent = parent.getparent()
@@ -468,6 +546,10 @@ class TransactionsPage(BasePage):
             if tr.find('th') is not None or len(cols) < 3:
                 continue
 
+            # On PEL, skip summary.
+            if len(cols[0].findall('span')) == 6:
+                continue
+
             t = Transaction()
 
             col_text = cols[self.COL_TEXT]
@@ -482,8 +564,11 @@ class TransactionsPage(BasePage):
             else:
                 debit = ''
 
-            day, month = map(int, date.split('/', 1))
-            t.date = date_guesser.guess_date(day, month)
+            if date.count('/') == 1:
+                day, month = map(int, date.split('/', 1))
+                t.date = date_guesser.guess_date(day, month)
+            elif date.count('/') == 2:
+                t.date = Date(dayfirst=True).filter(date)
             t.rdate = t.date
             t.raw = raw
 
@@ -494,9 +579,14 @@ class TransactionsPage(BasePage):
             t.category = unicode(col_text.text.strip())
             t.label = re.sub('(.*)  (.*)', r'\2', t.category).strip()
 
-            sub_label = col_text.find('br').tail
-            if sub_label is not None and (len(t.label) < 3 or t.label == t.category or len(re.findall('[^\w\s]', sub_label))/float(len(sub_label)) < len(re.findall('\d', t.label))/float(len(t.label))):
-                t.label = unicode(sub_label.strip())
+            br = col_text.find('br')
+            if br is not None:
+                sub_label = br.tail
+            if br is not None and sub_label is not None:
+                junk_ratio = len(re.findall('[^\w\s]', sub_label)) / float(len(sub_label))
+                nums_ratio = len(re.findall('\d', t.label)) / float(len(t.label))
+                if len(t.label) < 3 or t.label == t.category or junk_ratio < nums_ratio:
+                    t.label = unicode(sub_label.strip())
             # Sometimes, the category contains the label, even if there is another line with it again.
             t.category = re.sub('(.*)  .*', r'\1', t.category).strip()
 
@@ -527,12 +617,16 @@ class MarketPage(BasePage):
     COL_DIFF = 6
 
     def iter_investment(self):
-        for line in self.document.xpath('//table[contains(@class, "ca-data-table")]/descendant::tr[count(td)=8]'):
+        for line in self.document.xpath('//table[contains(@class, "ca-data-table")]/descendant::tr[count(td)>=7]'):
+            for sub in line.xpath('./td[@class="info-produit"]'):
+                sub.drop_tree()
             cells = line.findall('td')
 
+            if cells[self.COL_ID].find('div/a') is None:
+                continue
             inv = Investment()
             inv.label = unicode(cells[self.COL_ID].find('div/a').text.strip())
-            inv.code = cells[self.COL_ID].find('div/br').tail.strip()
+            inv.code = cells[self.COL_ID].find('div/br').tail.strip().split(' ')[0].split(u'\xa0')[0].split(u'\xc2\xa0')[0]
             inv.quantity = self.parse_decimal(cells[self.COL_QUANTITY].find('span').text)
             inv.valuation = self.parse_decimal(cells[self.COL_VALUATION].text)
             inv.diff = self.parse_decimal(cells[self.COL_DIFF].text_content())
@@ -540,24 +634,57 @@ class MarketPage(BasePage):
                 inv.unitvalue = inv.valuation / inv.quantity
                 inv.unitprice = (inv.valuation - inv.diff) / inv.quantity
             else:
-                inv.unitprice = self.parse_decimal(cells[self.COL_UNITPRICE].text)
+                inv.unitprice = self.parse_decimal(re.search('([^(]+)', cells[self.COL_UNITPRICE].text).group(1))
                 inv.unitvalue = self.parse_decimal(cells[self.COL_UNITVALUE].text)
+            date = cells[self.COL_UNITVALUE].find('span').text
+            if ':' in date:
+                inv.vdate = ddate.today()
+            else:
+                day, month = map(int, date.split('/'))[:2]
+                date_guesser = LinearDateGuesser()
+                inv.vdate = date_guesser.guess_date(day, month)
 
             yield inv
 
     def parse_decimal(self, value):
         v = value.strip()
-        if v == '-' or v == '':
+        if v == '-' or v == '' or v == '_':
             return NotAvailable
         return Decimal(Transaction.clean_amount(value))
 
 
+class MarketHomePage(MarketPage):
+    COL_ID_LABEL = 1
+    COL_VALUATION = 5
+    def update(self, accounts):
+        for line in self.document.xpath('//table[contains(@class, "tableau_comptes_details")]/tbody/tr'):
+            cells = line.findall('td')
+
+            id  = cells[self.COL_ID_LABEL].find('div[2]').text.strip()
+            for account in accounts:
+                if account.id == id:
+                    account.label = unicode(cells[self.COL_ID_LABEL].find('div/b').text.strip())
+                    account.balance = self.parse_decimal(cells[self.COL_VALUATION].text)
+
+
 class LifeInsurancePage(MarketPage):
     COL_ID = 0
     COL_QUANTITY = 3
     COL_UNITVALUE = 1
     COL_VALUATION = 4
 
+    def go_on_detail(self, account_id):
+        # Sometimes this page is a synthesis, so we need to go on detail.
+        if len(self.document.xpath(u'//h1[contains(text(), "Synthèse de vos contrats d\'assurance vie, de capitalisation et de prévoyance")]')) == 1:
+            self.browser.select_form('frm_fwk')
+            self.browser.set_all_readonly(False)
+            self.browser['ID_CNT_CAR'] = account_id
+            self.browser['fwkaction'] = 'Enchainer'
+            self.browser['fwkcodeaction'] = 'Executer'
+            self.browser['puCible'] = 'SEPPU'
+            self.browser.submit()
+            self.browser.location('https://assurance-personnes.credit-agricole.fr/filiale/entreeBam?sessionSAG=%s&stbpg=pagePU&act=SEPPU&stbzn=bnt&actCrt=SEPPU' % self.browser.sag)
+
     def iter_investment(self):
 
         for line in self.document.xpath('//table[@summary and count(descendant::td) > 1]/tbody/tr'):
@@ -570,7 +697,7 @@ class LifeInsurancePage(MarketPage):
             a = cells[self.COL_ID].find('a')
             if a is not None:
                 try:
-                    inv.code = a.attrib['id']
+                    inv.code = a.attrib['id'].split(' ')[0].split(u'\xa0')[0].split(u'\xc2\xa0')[0]
                 except KeyError:
                     #For "Mandat d'arbitrage" which is a recapitulatif of more investement
                     continue
@@ -583,3 +710,46 @@ class LifeInsurancePage(MarketPage):
             inv.diff = NotAvailable
 
             yield inv
+
+
+class BGPIPage(MarketPage):
+    COL_ID = 0
+    COL_QUANTITY = 1
+    COL_UNITPRICE = 2
+    COL_UNITVALUE = 3
+    COL_VALUATION = 4
+    COL_PORTFOLIO = 5
+    COL_DIFF = 6
+
+    def iter_investment(self):
+        for line in self.document.xpath('//table[contains(@class, "PuTableauLarge")]/tr[contains(@class, "PuLigne")]'):
+            cells = line.findall('td')
+            inv = Investment()
+
+            inv.label = unicode(cells[self.COL_ID].find('span').text_content().strip())
+            a = cells[self.COL_ID].find('a')
+            if a is not None:
+                inv.code = unicode(a.text_content().strip())
+            else:
+                inv.code = NotAvailable
+            inv.quantity = self.parse_decimal(cells[self.COL_QUANTITY].text_content())
+            inv.unitvalue = self.parse_decimal(cells[self.COL_UNITVALUE].text_content())
+            inv.valuation = self.parse_decimal(cells[self.COL_VALUATION].text_content())
+            inv.unitprice = self.parse_decimal(cells[self.COL_UNITPRICE].text_content())
+            inv.diff = self.parse_decimal(cells[self.COL_DIFF].text_content())
+            inv.portfolio_share = self.parse_decimal(cells[self.COL_PORTFOLIO].text_content())/100
+
+            yield inv
+
+    def go_on(self, link):
+        origin = urlparse(self.url)
+        self.browser.location('https://%s%s' % (origin.netloc, link))
+
+    def go_detail(self):
+        link = self.document.xpath(u'.//a[contains(text(), "Détail")]')
+        return self.go_on(link[0].attrib['href']) if link else False
+
+    def go_back(self):
+        self.go_on(self.document.xpath(u'.//a[contains(text(), "Retour à mes comptes")]')[0].attrib['href'])
+        self.browser.select_form('formulaire')
+        self.browser.submit()
