@@ -21,11 +21,13 @@
 import re
 
 from weboob.tools.json import json
-from weboob.capabilities.bank import Account
+from weboob.capabilities.bank import Account, NotAvailable
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 from weboob.browser.pages import HTMLPage, JsonPage, LoggedPage
-from weboob.browser.filters.standard import Filter, Format, CleanText, CleanDecimal
+from weboob.browser.filters.standard import Filter, Format, CleanText, CleanDecimal, \
+                                            BrowserURL, Field, Async, AsyncLoad
 from weboob.browser.elements import ListElement, ItemElement, method
+from weboob.browser.exceptions import ServerError
 
 
 class LoginPage(HTMLPage):
@@ -49,7 +51,8 @@ class CreditLoggedPage(HTMLPage):
 class AddType(Filter):
     types = {u'COMPTE NEF': Account.TYPE_CHECKING,
              u'CPTE A VUE': Account.TYPE_CHECKING,
-             u'LIVRET AGIR': Account.TYPE_SAVINGS}
+             u'LIVRET AGIR': Account.TYPE_SAVINGS,
+             u'LIVRET A PART': Account.TYPE_SAVINGS}
 
     def filter(self, str_type):
         for key, acc_type in self.types.items():
@@ -66,12 +69,24 @@ class AccountsPage(LoggedPage, HTMLPage):
         class item(ItemElement):
             klass = Account
 
+            load_details = BrowserURL('iban', account_id=Field('id')) & AsyncLoad
+
             obj_label = Format('%s %s', CleanText('.//h2[@class="tt_compte"][1]'), CleanText('.//ul[@class="nClient"]/li[1]'))
             obj_id = CleanText('.//ul[@class="nClient"]/li[last()]', symbols=u'N°')
             obj_type = AddType(CleanText('.//h2[@class="tt_compte"][1]'))
             obj_balance = CleanDecimal('.//td[@class="sum_solde"]//span[last()]', replace_dots=True)
             obj_currency = u'EUR'
 
+            def obj_iban(self):
+                try:
+                    return Async('details', CleanText('(.//div[@class="iban"]/p)[1]', replace=[(' ', '')]))(self)
+                except ServerError:
+                    return NotAvailable
+
+
+class IbanPage(LoggedPage, HTMLPage):
+    pass
+
 
 class Transaction(FrenchTransaction):
     PATTERNS = [(re.compile('^(?P<text>RETRAIT DAB) (?P<dd>\d{2})-(?P<mm>\d{2})-([\d\-]+)'),
