@@ -26,6 +26,9 @@ from weboob.deprecated.browser import Page
 from weboob.capabilities.bank import Account
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 
+class TechnicalErrorPage(Page):
+    pass
+
 
 class LoginPage(Page):
     def login(self, login, pin, strong_auth):
@@ -34,7 +37,7 @@ class LoginPage(Page):
 
         self.browser.select_form(name='loginCoForm', nr=form_nb)
         self.browser['codeUtil'] = login.encode(self.browser.ENCODING)
-        self.browser['motPasse'] = pin.encode(self.browser.ENCODING)
+        self.browser['motPasse'] = pin[:12].encode(self.browser.ENCODING)
 
         assert self.browser['identType'] == indentType
         self.browser.submit(nologin=True)
@@ -64,8 +67,7 @@ class AccountsPage(Page):
 
             account.id = tds[self.CPT_ROW_ID].text.strip()
             account.label = unicode(tds[self.CPT_ROW_NAME].text.strip())
-
-            account_type_str = "".join([td.text for td in tds[self.CPT_ROW_NATURE].xpath('.//td[@class="txt"]')]).strip()
+            account_type_str = "".join([td.text for td in tds[self.CPT_ROW_NATURE].xpath('.//td[@class="txt" and @width="99%"]')]).strip()
 
             account.type = self.ACCOUNT_TYPES.get(account_type_str,  Account.TYPE_UNKNOWN)
 
