@@ -33,15 +33,17 @@ class CreditDuNordModule(Module, CapBank):
     NAME = 'creditdunord'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
-    DESCRIPTION = u'Crédit du Nord, Banque Courtois, Kolb, Tarneaud'
+    VERSION = '1.2'
+    DESCRIPTION = u'Crédit du Nord, Banque Courtois, Kolb, Nuger, Tarneaud, Société Marseillaise de Crédit'
     LICENSE = 'AGPLv3+'
     website_choices = OrderedDict([(k, u'%s (%s)' % (v, k)) for k, v in sorted({
         'www.credit-du-nord.fr':     u'Crédit du Nord',
         'www.banque-courtois.fr':    u'Banque Courtois',
         'www.banque-kolb.fr':        u'Banque Kolb',
+        'www.banque-nuger.fr':       u'Banque Nuger',
         'www.banque-rhone-alpes.fr': u'Banque Rhône-Alpes',
         'www.tarneaud.fr':           u'Tarneaud',
+        'www.smc.fr':                u'Société Marseillaise de Crédit',
         }.iteritems(), key=lambda k_v: (k_v[1], k_v[0]))])
     CONFIG = BackendConfig(Value('website',  label='Banque', choices=website_choices, default='www.credit-du-nord.fr'),
                            ValueBackendPassword('login',    label='Identifiant', masked=False),
@@ -54,34 +56,28 @@ class CreditDuNordModule(Module, CapBank):
                                    self.config['password'].get())
 
     def iter_accounts(self):
-        with self.browser:
-            for account in self.browser.get_accounts_list():
-                yield account
+        for account in self.browser.get_accounts_list():
+            yield account
 
     def get_account(self, _id):
-        with self.browser:
-            account = self.browser.get_account(_id)
-
+        account = self.browser.get_account(_id)
         if account:
             return account
         else:
             raise AccountNotFound()
 
     def iter_history(self, account):
-        with self.browser:
-            account = self.browser.get_account(account.id)
-            transactions = list(self.browser.get_history(account))
-            transactions.sort(key=lambda tr: tr.rdate, reverse=True)
-            return [tr for tr in transactions if not tr._is_coming]
+        account = self.get_account(account.id)
+        for tr in self.browser.get_history(account):
+            if not tr._is_coming:
+                yield tr
 
     def iter_coming(self, account):
-        with self.browser:
-            account = self.browser.get_account(account.id)
-            transactions = list(self.browser.get_card_operations(account))
-            transactions.sort(key=lambda tr: tr.rdate, reverse=True)
-            return [tr for tr in transactions if tr._is_coming]
+        account = self.get_account(account.id)
+        for tr in self.browser.get_history(account, coming=True):
+            if tr._is_coming:
+                yield tr
 
     def iter_investment(self, account):
-        with self.browser:
-            account = self.browser.get_account(account.id)
-            return self.browser.get_investment(account)
+        account = self.get_account(account.id)
+        return self.browser.get_investment(account)
