@@ -20,9 +20,11 @@
 
 
 from decimal import Decimal
-import string
 
-from weboob.capabilities.bank import CapBank, AccountNotFound, Recipient, Account
+from weboob.capabilities.base import find_object
+from weboob.capabilities.bank import CapBankTransfer, AccountNotFound, RecipientNotFound, \
+                                     Account, TransferError
+from weboob.capabilities.contact import CapContact
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword
 
@@ -32,11 +34,11 @@ from .browser import CreditMutuelBrowser
 __all__ = ['CreditMutuelModule']
 
 
-class CreditMutuelModule(Module, CapBank):
+class CreditMutuelModule(Module, CapBankTransfer, CapContact):
     NAME = 'creditmutuel'
     MAINTAINER = u'Julien Veyssier'
     EMAIL = 'julien.veyssier@aiur.fr'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Crédit Mutuel'
     LICENSE = 'AGPLv3+'
     CONFIG = BackendConfig(ValueBackendPassword('login',    label='Identifiant', regexp='^\d{1,13}\w$', masked=False),
@@ -70,24 +72,41 @@ class CreditMutuelModule(Module, CapBank):
     def iter_investment(self, account):
         return self.browser.get_investment(account)
 
-    def iter_transfer_recipients(self, ignored):
-        for account in self.browser.get_accounts_list():
-            recipient = Recipient()
-            recipient.id = account.id
-            recipient.label = account.label
-            yield recipient
+    def iter_transfer_recipients(self, origin_account):
+        if not self.browser.is_new_website:
+            raise NotImplementedError()
 
-    def transfer(self, account, to, amount, reason=None):
-        if isinstance(account, Account):
-            account = account.id
+        if not isinstance(origin_account, Account):
+            origin_account = find_object(self.iter_accounts(), id=origin_account, error=AccountNotFound)
+        return self.browser.iter_recipients(origin_account)
+
+    def init_transfer(self, transfer, **params):
+        # There is a check on the website, transfer can't be done with too long reason.
+        if transfer.label:
+            transfer.label = transfer.label[:27]
+
+        self.logger.info('Going to do a new transfer')
+        if transfer.account_iban:
+            account = find_object(self.iter_accounts(), iban=transfer.account_iban, error=AccountNotFound)
+        else:
+            account = find_object(self.iter_accounts(), id=transfer.account_id, error=AccountNotFound)
+
+        if transfer.recipient_iban:
+            recipient = find_object(self.iter_transfer_recipients(account.id), iban=transfer.recipient_iban, error=RecipientNotFound)
+        else:
+            recipient = find_object(self.iter_transfer_recipients(account.id), id=transfer.recipient_id, error=RecipientNotFound)
 
-        account = str(account).strip(string.letters)
-        to = str(to).strip(string.letters)
         try:
-            assert account.isdigit()
-            assert to.isdigit()
-            amount = Decimal(amount)
+            assert account.id.isdigit()
+            # quantize to show 2 decimals.
+            amount = Decimal(transfer.amount).quantize(Decimal(10) ** -2)
         except (AssertionError, ValueError):
-            raise AccountNotFound()
+            raise TransferError('something went wrong')
 
-        return self.browser.transfer(account, to, amount, reason)
+        return self.browser.init_transfer(account, recipient, amount, transfer.label)
+
+    def execute_transfer(self, transfer, **params):
+        return self.browser.execute_transfer(transfer)
+
+    def iter_contacts(self):
+        return self.browser.get_advisor()
