@@ -29,7 +29,7 @@ __all__ = ['CuisineazBrowser']
 class CuisineazBrowser(PagesBrowser):
 
     BASEURL = 'http://www.cuisineaz.com'
-
+    TIMEOUT = 20
     search = URL('recettes/recherche_v2.aspx\?recherche=(?P<pattern>.*)', ResultsPage)
     recipe = URL('recettes/(?P<_id>.*).aspx', RecipePage)
 
@@ -40,4 +40,4 @@ class CuisineazBrowser(PagesBrowser):
         return self.recipe.go(_id=_id).get_recipe(obj=obj)
 
     def get_comments(self, _id):
-        return self.recipe.go(_id=_id).get_comments()
+        return self.recipe.stay_or_go(_id=_id).get_comments()
