@@ -35,7 +35,7 @@ class CuisineazModule(Module, CapRecipe):
     NAME = 'cuisineaz'
     MAINTAINER = u'Julien Veyssier'
     EMAIL = 'julien.veyssier@aiur.fr'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Cuisine AZ French recipe website'
     LICENSE = 'AGPLv3+'
     BROWSER = CuisineazBrowser
@@ -54,9 +54,6 @@ class CuisineazModule(Module, CapRecipe):
 
         if 'comments' in fields:
             recipe.comments = list(self.browser.get_comments(recipe.id))
-
         return recipe
 
-    OBJECTS = {
-        Recipe: fill_recipe,
-    }
+    OBJECTS = {Recipe: fill_recipe}
