@@ -17,9 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-
-from weboob.tools.test import BackendTest
 from weboob.capabilities.video import BaseVideo
+from weboob.tools.test import BackendTest
 
 
 class PluzzTest(BackendTest):
@@ -27,15 +26,19 @@ class PluzzTest(BackendTest):
 
     def test_search(self):
         # If the test fails, it might be good news!
-        l = list(self.backend.search_videos('d art'))
+        l = list(self.backend.search_videos("pblv"))
         self.assertTrue(len(l) > 0)
         v = l[0]
         self.backend.fillobj(v, ('url',))
         self.assertTrue(v.url, 'URL for video "%s" not found: %s' % (v.id, v.url))
 
+    def test_video_from_url(self):
+        v = self.backend.get_video('http://pluzz.francetv.fr/videos/plus_belle_la_vie.html')
+        self.assertTrue(v.url, 'URL for video "%s" not found: %s' % (v.id, v.url))
+
     def test_latest(self):
         l = list(self.backend.iter_resources([BaseVideo], [u'latest']))
         assert len(l)
         v = l[0]
         self.backend.fillobj(v, ('url',))
-        assert v.url
+        self.assertTrue(v.url, 'URL for video "%s" not found' % (v.id))
