@@ -104,7 +104,7 @@ class DetailsPage(LoggedPage, BadUTF8Page):
 
     @method
     class date_bills(ListElement):
-        item_xpath = '//div[@class="factLigne hide "]'
+        item_xpath = '//div[has-class("factLigne")]'
 
         class item(ItemElement):
             klass = Bill
@@ -113,12 +113,13 @@ class DetailsPage(LoggedPage, BadUTF8Page):
                 num = Attr('.', 'data-fact_ligne', default='')(self)
                 return self.env['subid'] == num
 
-            obj__url = Attr('.//div[@class="pdf"]/a', 'href')
-            obj__localid = Regexp(Field('_url'), '&l=(\d*)&id', u'\\1')
-            obj_label = Regexp(Field('_url'), '&date=(\d*)', u'\\1')
-            obj_id = Format('%s.%s', Env('subid'), Field('label'))
+            obj_url = Attr('.//div[@class="pdf"]/a', 'href')
+            obj__localid = Regexp(Field('url'), '&id=(.*)&date', u'\\1')
+            obj_label = Regexp(Field('url'), '&date=(\d*)', u'\\1')
+            obj_id = Format('%s.%s', Env('subid'), Field('_localid'))
             obj_date = FormatDate(Field('label'))
             obj_format = u"pdf"
+            obj_type = u"bill"
             obj_price = CleanDecimal('div[@class="montant"]', default=Decimal(0), replace_dots=False)
 
     def get_renew_date(self, subscription):
@@ -135,6 +136,8 @@ class DetailsPage(LoggedPage, BadUTF8Page):
                 mydate = mydate.replace(month=mydate.month + 1, day=lastday)
         return mydate
 
+    def get_login(self, phonenumber):
+        return Attr('.', 'login')(self.doc.xpath('//div[div[contains(text(), "%s")]]' % phonenumber)[0])
 
 class HistoryPage(LoggedPage, BadUTF8Page):
     @method
