@@ -20,13 +20,7 @@
 from .history import BadUTF8Page
 from weboob.capabilities.bill import Subscription
 from weboob.browser.elements import ListElement, ItemElement, method
-from weboob.browser.filters.standard import CleanText, Field, Format, Filter
-from weboob.browser.filters.html import Attr
-
-
-class GetID(Filter):
-    def filter(self, txt):
-        return txt.split('=')[-1]
+from weboob.browser.filters.standard import CleanText, Field, Format
 
 
 class HomePage(BadUTF8Page):
@@ -45,5 +39,4 @@ class HomePage(BadUTF8Page):
 
             obj_subscriber = CleanText('div[@class="idAbonne pointer"]/p[1]', symbols='-', children=False)
             obj_id = CleanText('div[@class="idAbonne pointer"]/p/span')
-            obj__login = GetID(Attr('.//div[@class="acceuil_btn"]/a', 'href'))
-            obj_label = Format(u'%s - %s', Field('id'), CleanText('.//div[@class="forfaitChoisi"]'))
+            obj_label = Format(u'%s - %s', Field('id'), CleanText('(.//div[@class="section-contenu"])[1]', children=False))
