@@ -19,10 +19,12 @@
 
 
 from decimal import Decimal
-import re
+import re, requests
 
-from weboob.browser.pages import HTMLPage
+from weboob.browser.pages import HTMLPage, pagination
 from weboob.browser.elements import method
+from weboob.browser.filters.standard import Env
+from weboob.browser.filters.html import Attr
 from weboob.capabilities.bank import Account
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 
@@ -92,18 +94,32 @@ class Transaction(FrenchTransaction):
 class TransactionsPage(HTMLPage):
     logged = True
 
+    @pagination
     @method
     class get_history(Transaction.TransactionsElement):
         head_xpath = '//table[@id="releve_operation"]//tr/th'
         item_xpath = '//table[@id="releve_operation"]//tr'
 
-        col_date =       [u'Date opé', 'Date', u'Date d\'opé']
+        col_date =       [u'Date opé', 'Date', u'Date d\'opé', u'Date opération']
         col_vdate =      [u'Date valeur']
+        col_credit =     [u'Crédit', u'Montant', u'Valeur']
+        col_debit =      [u'Débit']
+
+        def next_page(self):
+            url = Attr('//a[contains(text(), "Page suivante")]', 'onclick', default=None)(self)
+            if url:
+                m = re.search('\'([^\']+).*([\d]+)', url)
+                return requests.Request("POST", m.group(1), data={'numCompte': Env('accid')(self), \
+                                        'vue': "ReleveOperations", 'tri': "DateOperation", 'sens': \
+                                        "DESC", 'page': m.group(2), 'nb_element': "25"})
 
         class item(Transaction.TransactionElement):
             def condition(self):
                 return len(self.el.xpath('./td')) > 3
 
     def get_coming_link(self):
-        a = self.doc.getroot().cssselect('div#sous_nav ul li a.bt_sans_off')[0]
+        try:
+            a = self.doc.getroot().cssselect('div#sous_nav ul li a.bt_sans_off')[0]
+        except IndexError:
+            return None
         return re.sub('[ \t\r\n]+', '', a.attrib['href'])
