@@ -17,8 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-from weboob.capabilities.bill import CapBill, SubscriptionNotFound,\
-    BillNotFound, Subscription, Bill
+from weboob.capabilities.bill import CapDocument, SubscriptionNotFound,\
+    DocumentNotFound, Subscription, Bill
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword
 from .browser import GdfSuez
@@ -26,11 +26,11 @@ from .browser import GdfSuez
 __all__ = ['GdfSuezModule']
 
 
-class GdfSuezModule(Module, CapBill):
+class GdfSuezModule(Module, CapDocument):
     NAME = 'gdfsuez'
     MAINTAINER = u'Mathieu Jourdan'
     EMAIL = 'mathieu.jourdan@gresille.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     LICENSE = 'AGPLv3+'
     DESCRIPTION = u'GDF-Suez French energy provider'
     CONFIG = BackendConfig(ValueBackendPassword('login',
@@ -60,7 +60,7 @@ class GdfSuezModule(Module, CapBill):
         else:
             return subscription
 
-    def iter_bills_history(self, subscription):
+    def iter_documents_history(self, subscription):
         if not isinstance(subscription, Subscription):
             subscription = self.get_subscription(subscription)
         with self.browser:
@@ -74,23 +74,23 @@ class GdfSuezModule(Module, CapBill):
             for detail in self.browser.get_details(subscription):
                 yield detail
 
-    def iter_bills(self, subscription):
+    def iter_documents(self, subscription):
         if not isinstance(subscription, Subscription):
             subscription = self.get_subscription(subscription)
         with self.browser:
-            for bill in self.browser.iter_bills():
+            for bill in self.browser.iter_documents():
                 yield bill
 
-    def get_bill(self, id):
+    def get_document(self, id):
         with self.browser:
-            bill = self.browser.get_bill(id)
+            bill = self.browser.get_document(id)
         if not bill:
-            raise BillNotFound()
+            raise DocumentNotFound()
         else:
             return bill
 
-    def download_bill(self, bill):
+    def download_document(self, bill):
         if not isinstance(bill, Bill):
-            bill = self.get_bill(bill)
+            bill = self.get_document(bill)
         with self.browser:
-            return self.browser.readurl(bill._url)
+            return self.browser.readurl(bill.url)
