@@ -28,7 +28,7 @@ from .browser import GithubBrowser
 __all__ = ['GithubModule']
 
 
-STATUSES = {'open': Status('open', u'Open', Status.VALUE_NEW),
+STATUSES = {'open': Status('open', u'open', Status.VALUE_NEW),
             'closed': Status('closed', u'closed', Status.VALUE_RESOLVED)}
 # TODO tentatively parse github "labels"?
 
@@ -39,7 +39,7 @@ class GithubModule(Module, CapBugTracker):
     MAINTAINER = u'Vincent A'
     EMAIL = 'dev@indigo.re'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.1'
+    VERSION = '1.2'
     CONFIG = BackendConfig(Value('username', label='Username', default=''),
                            ValueBackendPassword('password', label='Password', default=''))
 
@@ -99,9 +99,16 @@ class GithubModule(Module, CapBugTracker):
             _, issue_number = self._extract_issue_id(issue.id)
             self.browser.edit_issue(issue, issue_number)
         else:
-            self.browser.post_issue(issue)
+            d = self.browser.post_issue(issue)
+            issue.id = self._build_issue_id(issue.project.id, d['number'])
+        return issue
 
     def update_issue(self, issue_id, update):
+        try:
+            issue_id = issue_id.id
+        except AttributeError:
+            pass
+
         assert not update.attachments
         self.browser.post_comment(issue_id, update.message)
 
@@ -118,6 +125,7 @@ class GithubModule(Module, CapBugTracker):
     def _make_issue(self, d, project):
         _id = self._build_issue_id(project.id, d['number'])
         issue = Issue(_id)
+        issue.url = d['url']
         issue.project = project
         issue.title = d['title']
         issue.body = d['body']
