@@ -34,7 +34,7 @@ class GroupamaesModule(Module, CapBank):
     MAINTAINER = u'Bezleputh'
     EMAIL = 'carton_ben@yahoo.fr'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.1'
+    VERSION = '1.2'
 
     BROWSER = GroupamaesBrowser
 
@@ -53,5 +53,8 @@ class GroupamaesModule(Module, CapBank):
     def iter_history(self, account):
         return self.browser.get_history()
 
+    def iter_investment(self, account):
+        return self.browser.iter_investment()
+
     def get_account(self, _id):
         return find_object(self.browser.get_accounts_list(), id=_id, error=AccountNotFound)
