@@ -17,11 +17,14 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
+from decimal import Decimal
+from datetime import date
+import re
 
 from weboob.browser.pages import HTMLPage, LoggedPage
 from weboob.browser.elements import TableElement, ItemElement, method
-from weboob.browser.filters.standard import CleanText, CleanDecimal, TableCell, Date, Env
-from weboob.capabilities.bank import Account, Transaction
+from weboob.browser.filters.standard import CleanText, CleanDecimal, TableCell, Date, Env, Regexp, Field
+from weboob.capabilities.bank import Account, Transaction, Investment
 
 
 class LoginPage(HTMLPage):
@@ -36,7 +39,9 @@ class LoginErrorPage(HTMLPage):
     pass
 
 
-class AvoirPage(LoggedPage, HTMLPage):
+class GroupamaesPage(LoggedPage, HTMLPage):
+    NEGATIVE_AMOUNT_LABELS = [u'Retrait', u'Transfert sortant']
+
     @method
     class iter_accounts(TableElement):
         item_xpath = u'//table[@summary="Liste des échéances"]/tbody/tr'
@@ -48,14 +53,71 @@ class AvoirPage(LoggedPage, HTMLPage):
         class item(ItemElement):
             klass = Account
 
+            def condition(self):
+                return u'Vous n\'avez pas d\'avoirs.' not in CleanText(TableCell('name'))(self)
+
             obj_id = CleanText(TableCell('name'))
             obj_label = CleanText(TableCell('name'))
-            obj_balance = CleanDecimal(TableCell('value'), replace_dots=True)
+            obj_balance = CleanDecimal(TableCell('value'), replace_dots=True, default=Decimal(0))
             obj_currency = CleanText(u'//table[@summary="Liste des échéances"]/thead/tr/th/small/text()')
-            obj_type = Account.TYPE_UNKNOWN
+            obj_type = Account.TYPE_PEE
 
+    def iter_investment(self):
+        item = self.doc.xpath(u'//table[@summary="Liste des échéances"]/tfoot/tr/td[@class="tot _c1 d _c1"]')[0]
+        total = CleanDecimal(Regexp(CleanText('.'), '(.*) .*'),
+                             default=1, replace_dots=True)(item)
+
+        item_xpath = u'((//table[@summary="Liste des échéances"])[1]/tbody/tr)[position() < last() and not(contains(./td[1]/@class, "tittot"))]'
+
+        obj = None
+        for tr in self.doc.xpath(item_xpath):
+            tds = tr.xpath('./td')
+            if len(tds) > 3:
+                if obj is not None:
+                    obj.portfolio_share = (obj.valuation / total).quantize(Decimal('.0001'))
+                    yield obj
+
+                obj = Investment()
+                obj.label = CleanText('.')(tds[0])
+                obj.vdate = date.today()  # * En réalité derniere date de valorisation connue
+                obj.unitvalue = CleanDecimal('.', replace_dots=True)(tds[2])
+                obj.valuation = CleanDecimal('.', replace_dots=True)(tds[5])
+                obj.quantity = CleanDecimal('.', replace_dots=True)(tds[4])
+
+            elif obj is not None:
+                obj.quantity += CleanDecimal('.', replace_dots=True)(tds[1])
+                obj.valuation += CleanDecimal('.', replace_dots=True)(tds[2])
+
+        if obj is not None:
+            obj.portfolio_share = (obj.valuation / total).quantize(Decimal('.0001'))
+            yield obj
+
+    @method
+    class get_history(TableElement):
+        head_xpath = u'//table[@summary="Liste des opérations"]/thead/tr/th/text()'
+        item_xpath = u'//table[@summary="Liste des opérations"]/tbody/tr'
+
+        col_date = u'Date'
+        col_operation = u'Opération'
+        col_montant = u'Montant net en EUR'
+
+        class item(ItemElement):
+            klass = Transaction
+
+            def condition(self):
+                return u'Aucune opération' not in CleanText(TableCell('date'))(self)
+
+            obj_date = Date(CleanText(TableCell('date')), Env('date_guesser'))
+            obj_type = Transaction.TYPE_UNKNOWN
+            obj_label = CleanText(TableCell('operation'))
+
+            def obj_amount(self):
+                amount = CleanDecimal(TableCell('montant'), replace_dots=True)(self)
+                for pattern in GroupamaesPage.NEGATIVE_AMOUNT_LABELS:
+                    if Field('label')(self).startswith(pattern):
+                        amount = -amount
+                return amount
 
-class OperationsFuturesPage(LoggedPage, HTMLPage):
     @method
     class get_list(TableElement):
         head_xpath = u'//table[@summary="Liste des opérations en attente"]/thead/tr/th/text()'
@@ -64,7 +126,7 @@ class OperationsFuturesPage(LoggedPage, HTMLPage):
         col_date = u'Date'
         col_operation = u'Opération'
         col_etat = u'Etat'
-        col_montant = u'Montant net en'
+        col_montant = [u'Montant net en', re.compile(u'Montant en')]
         col_action = u'Action'
 
         class item(ItemElement):
@@ -77,25 +139,3 @@ class OperationsFuturesPage(LoggedPage, HTMLPage):
             obj_type = Transaction.TYPE_UNKNOWN
             obj_label = CleanText(TableCell('operation'))
             obj_amount = CleanDecimal(TableCell('montant'), replace_dots=True)
-
-
-class OperationsTraiteesPage(LoggedPage, HTMLPage):
-    @method
-    class get_history(TableElement):
-        head_xpath = u'//table[@summary="Liste des opérations en attente"]/thead/tr/th/text()'
-        item_xpath = u'//table[@summary="Liste des opérations en attente"]/tbody/tr'
-
-        col_date = u'Date'
-        col_operation = u'Opération'
-        col_montant = u'Montant net en'
-
-        class item(ItemElement):
-            klass = Transaction
-
-            def condition(self):
-                return u'Aucune opération' not in CleanText(TableCell('date'))(self)
-
-            obj_date = Date(CleanText(TableCell('date')), Env('date_guesser'))
-            obj_type = Transaction.TYPE_UNKNOWN
-            obj_label = CleanText(TableCell('operation'))
-            obj_amount = CleanDecimal(TableCell('montant'), replace_dots=True)
