@@ -40,6 +40,7 @@ class Transaction(FrenchTransaction):
                 (re.compile(r'^CHEQUE$'),                  FrenchTransaction.TYPE_CHECK),
                 (re.compile(r'^COTIS\.? (?P<text>.*)'),    FrenchTransaction.TYPE_BANK),
                 (re.compile(r'^REMISE (?P<text>.*)'),      FrenchTransaction.TYPE_DEPOSIT),
+                (re.compile(r'^FACTURES CB (?P<text>.*)'), FrenchTransaction.TYPE_CARD_SUMMARY),
                ]
 
 
@@ -69,13 +70,31 @@ class AccountsPage(LoggedPage, HTMLPage):
 
             class Type(Filter):
                 def filter(self, label):
-                    if 'invest' in label.lower():
-                        return Account.TYPE_MARKET
+                    invest  = ['invest']
+                    saving = ['ldd', 'livret']
+                    account = ['compte', 'account']
+                    loan    = ['pret', 'account']
+                    life = ['vie', 'strategie patr.', 'essentiel', 'elysees', 'abondance']
+                    for inv in invest:
+                        if inv in label.lower():
+                            return Account.TYPE_MARKET
+                    for acc in saving:
+                        if acc in label.lower():
+                            return Account.TYPE_SAVINGS
+                    for acc in account:
+                        if acc in label.lower():
+                            return Account.TYPE_CHECKING
+                    for l in loan:
+                        if l in label.lower():
+                            return Account.TYPE_LOAN
+                    for l in life:
+                        if l in label.lower():
+                            return Account.TYPE_LIFE_INSURANCE
                     return Account.TYPE_UNKNOWN
 
             obj_label = Label(CleanText('./td[1]/a'))
             obj_coming = Env('coming')
-            obj_currency = FrenchTransaction.Currency('./td[3]')
+            obj_currency = FrenchTransaction.Currency('./td[2]')
             obj__link_id = Link('./td[1]/a')
             obj_type = Type(Field('label'))
             obj_coming = NotAvailable
@@ -99,6 +118,27 @@ class AccountsPage(LoggedPage, HTMLPage):
                 return CleanText(replace=[('.', ''), (' ', '')]).filter(self.el.xpath('./td[2]'))
 
 
+class RibPage(LoggedPage, HTMLPage):
+    def is_here(self):
+        return bool(self.doc.xpath('//h1[contains(text(), "RIB/IBAN")]'))
+
+    def link_rib(self, accounts):
+        for id, acc in accounts.items():
+            if acc.iban or not acc.type is Account.TYPE_CHECKING:
+                continue
+            digit_id = ''.join(re.findall('\d', id))
+            if digit_id in CleanText('//div[strong[contains(text(), "Account number")]]')(self.doc):
+                acc.iban = re.search('(FR\d{25})', CleanText('//div[strong[contains(text(), "IBAN")]]', replace=[(' ', '')])(self.doc)).group(1)
+
+    def get_rib(self, accounts):
+        self.link_rib(accounts)
+        for nb in range(len(self.doc.xpath('//select/option')) -1):
+            form = self.get_form(name="FORM_RIB")
+            form['index_rib'] = str(nb+1)
+            form.submit()
+            self.browser.page.link_rib(accounts)
+
+
 class Pagination(object):
     def next_page(self):
         links = self.page.doc.xpath('//a[@class="fleche"]')
@@ -133,17 +173,29 @@ class CBOperationPage(LoggedPage, HTMLPage):
 
 class CPTOperationPage(LoggedPage, HTMLPage):
     def get_history(self):
+        if self.doc.xpath('//form[@name="FORM_SUITE"]'):
+            m = re.search('suite[\s]+=[\s]+([\w]+)', CleanText().filter(self.doc.xpath('//script[contains(text(), "var suite")]')))
+            if m and m.group(1) == "true":
+                form = self.get_form(name="FORM_SUITE")
+                self.doc = self.browser.location("%s" % form.url, params=dict(form)).page.doc
+
         for script in self.doc.xpath('//script'):
             if script.text is None or script.text.find('\nCL(0') < 0:
                 continue
 
+            prev_date = None
             for m in re.finditer(r"CL\((\d+),'(.+)','(.+)','(.+)','([\d -\.,]+)',('([\d -\.,]+)',)?'\d+','\d+','[\w\s]+'\);", script.text, flags=re.MULTILINE):
                 op = Transaction()
                 op.parse(date=m.group(3), raw=re.sub(u'[ ]+', u' ', m.group(4).replace(u'\n', u' ')))
                 op.set_amount(m.group(5))
                 op._coming = (re.match(r'\d+/\d+/\d+', m.group(2)) is None)
+                op.deleted = True if op.type == Transaction.TYPE_CARD_SUMMARY else False
+                if prev_date is not None and prev_date < op.date:
+                    break
+                prev_date = op.date
                 yield op
 
+
 class AppGonePage(HTMLPage):
     def on_load(self):
         self.browser.app_gone = True
