@@ -21,10 +21,10 @@ import re
 
 from weboob.capabilities.base import StringField
 from weboob.capabilities.gallery import BaseGallery, BaseImage, CapGallery
+from weboob.capabilities.image import CapImage, Thumbnail
 from weboob.capabilities.paste import BasePaste, CapPaste
 from weboob.tools.backend import Module
 from weboob.tools.capabilities.paste import image_mime
-from weboob.tools.capabilities.thumbnail import Thumbnail
 from weboob.tools.date import datetime
 
 from .browser import ImgurBrowser
@@ -68,13 +68,13 @@ class ImgGallery(BaseGallery):
         return self._imgs
 
 
-class ImgurModule(Module, CapPaste, CapGallery):
+class ImgurModule(Module, CapPaste, CapGallery, CapImage):
     NAME = 'imgur'
     DESCRIPTION = u'imgur image upload service'
     MAINTAINER = u'Vincent A'
     EMAIL = 'dev@indigo.re'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.1'
+    VERSION = '1.2'
 
     BROWSER = ImgurBrowser
 
@@ -82,6 +82,7 @@ class ImgurModule(Module, CapPaste, CapGallery):
     GALLURL = re.compile(r'https?://(?:[a-z]+\.)?imgur.com/a/([a-zA-Z0-9]+)/?$')
     ID = re.compile(r'[0-9a-zA-Z]+$')
 
+    # CapPaste
     def new_paste(self, *a, **kw):
         return ImgPaste(*a, **kw)
 
@@ -114,6 +115,34 @@ class ImgurModule(Module, CapPaste, CapGallery):
         paste.delete_url = res['delete_url']
         return paste
 
+    # CapGallery
+    def _build_img(self, d, n, gallery):
+        img = Img(d['id'], gallery=gallery, url=d['link'], index=n)
+        img.title = d['title'] or u''
+        img.description = d['description'] or u''
+        img.ext = img.url.rsplit('.', 1)[-1]
+        img.date = datetime.fromtimestamp(d['datetime'])
+        img.thumbnail = Thumbnail(img.thumbnail_url)
+        img.thumbnail.date = img.date
+        img.nsfw = bool(d['nsfw'])
+        img.size = d['size']
+        return img
+
+    def _build_gallery(self, d):
+        gallery = ImgGallery(d['id'], url=d['link'])
+        gallery.title = d['title'] or u''
+        gallery.description = d['description'] or u''
+        gallery.date = datetime.fromtimestamp(d['datetime'])
+        gallery.thumbnail = Thumbnail(Img(d['cover']).thumbnail_url)
+
+        if 'images' in d:
+            for n, d in enumerate(d['images']):
+                img = self._build_img(d, n, gallery)
+                gallery._imgs.append(img)
+            gallery.cardinality = len(gallery._imgs)
+
+        return gallery
+
     def get_gallery(self, id):
         mtc = self.GALLURL.match(id)
         if mtc:
@@ -122,29 +151,49 @@ class ImgurModule(Module, CapPaste, CapGallery):
             return None
 
         d = self.browser.get_gallery(id)
-
-        gallery = ImgGallery(id, url=d['link'])
-        gallery.title = d['title'] or u''
-        gallery.description = d['description'] or u''
-        gallery.date = datetime.fromtimestamp(d['datetime'])
-        gallery.thumbnail = Thumbnail(Img(d['cover']).thumbnail_url)
-
-        for n, d in enumerate(d['images']):
-            img = Img(d['id'], gallery=gallery, url=d['link'], index=n)
-            img._title = d['title'] or u''
-            img.ext = img.url.rsplit('.', 1)[-1]
-            img.thumbnail = Thumbnail(img.thumbnail_url)
-            gallery._imgs.append(img)
-        gallery.cardinality = len(gallery._imgs)
-
-        return gallery
+        if d is None:
+            return None
+        return self._build_gallery(d)
 
     def iter_gallery_images(self, gallery):
+        if not len(gallery._imgs):
+            new = self.get_gallery(gallery.id)
+            gallery._imgs = new._imgs
         return gallery._imgs
 
+    def search_galleries(self, pattern, sortby=CapGallery.SEARCH_RELEVANCE):
+        d = self.browser.search_items(pattern, sortby)
+        for sub in d:
+            if sub['is_album']:
+                yield self._build_gallery(sub)
+
+    # CapImage
+    def get_file(self, id):
+        mtc = self.IMGURL.match(id)
+        if mtc:
+            id = mtc.group(1)
+        elif not self.ID.match(id):
+            return None
+
+        d = self.browser.get_image(id)
+        if d is None:
+            return None
+        return self._build_img(d, 0, None)
+
+    def search_file(self, pattern, sortby=CapGallery.SEARCH_RELEVANCE):
+        d = self.browser.search_items(pattern, sortby)
+        for sub in d:
+            if not sub['is_album']:
+                yield self._build_img(sub, 0, None)
+
+    def search_image(self, pattern, sortby=CapGallery.SEARCH_RELEVANCE, nsfw=False):
+        for img in self.search_file(pattern, sortby):
+            if nsfw or not img.nsfw:
+                yield img
+
     def fill_img(self, img, fields):
         if 'data' in fields:
-            img.data = self.browser.open_raw(img.raw_url).content
+            img.data = self.browser.open_raw(img.url).content
         return img
 
     OBJECTS = {Img: fill_img, Thumbnail: fill_img}
