@@ -16,45 +16,70 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
+
+
 import re
 import hashlib
 import time
 
+from requests.exceptions import SSLError
+
 from weboob.browser import LoginBrowser, URL, need_login
 from weboob.exceptions import BrowserIncorrectPassword, ParseError
+from weboob.browser.exceptions import ServerError
 from weboob.capabilities.bank import Account, TransferError, AccountNotFound
 from weboob.capabilities.base import find_object
 
 from .pages import AccountsList, LoginPage, NetissimaPage, TitrePage, TitreHistory,\
-    TransferPage, TransferConfirmPage, BillsPage, StopPage, TitreDetails, TitreValuePage
+    TransferPage, TransferConfirmPage, BillsPage, StopPage, TitreDetails, TitreValuePage, ASVHistory,\
+    ASVInvest, DetailFondsPage, IbanPage, ActionNeededPage, ReturnPage
 
 
 __all__ = ['IngBrowser']
 
 
-def check_bourse(f):
-    def wrapper(*args):
+def start_with_main_site(f):
+    def wrapper(*args, **kwargs):
         browser = args[0]
-        if browser.where == u"titre":
-            browser.location("https://bourse.ingdirect.fr/priv/redirectIng.php?pageIng=COMPTE")
-            browser.where = u"start"
-        return f(*args)
+
+        if browser.url.startswith('https://bourse.ingdirect.fr/'):
+            for i in xrange(3):
+                try:
+                    browser.location('https://bourse.ingdirect.fr/priv/redirectIng.php?pageIng=COMPTE')
+                except ServerError:
+                    pass
+                else:
+                    break
+            browser.where = 'start'
+        elif browser.url.startswith('https://ingdirectvie.ingdirect.fr/'):
+            browser.lifeback.go()
+            browser.where = 'start'
+
+        return f(*args, **kwargs)
     return wrapper
 
 
 class IngBrowser(LoginBrowser):
     BASEURL = 'https://secure.ingdirect.fr'
+    VERIFY = 'certificate.pem'
+    TIMEOUT = 60.0
+
+    # avoid relogin every time
+    lifeback = URL(r'https://ingdirectvie.ingdirect.fr/b2b2c/entreesite/EntAccExit', ReturnPage)
 
     # Login and error
     loginpage = URL('/public/displayLogin.jsf.*', LoginPage)
     errorpage = URL('.*displayCoordonneesCommand.*', StopPage)
+    actioneeded = URL('/general\?command=displayTRAlertMessage', ActionNeededPage)
 
     # CapBank
-    accountspage = URL('/protected/pages/index.jsf', AccountsList)
+    accountspage = URL('/protected/pages/index.jsf',
+                       '/protected/pages/asv/contract/(?P<asvpage>.*).jsf', AccountsList)
     transferpage = URL('/protected/pages/cc/transfer/transferManagement.jsf', TransferPage)
     dotransferpage = URL('/general\?command=DisplayDoTransferCommand', TransferPage)
     valtransferpage = URL('/protected/pages/cc/transfer/create/transferCreateValidation.jsf', TransferConfirmPage)
     titredetails = URL('/general\?command=display.*', TitreDetails)
+    ibanpage = URL('/protected/pages/common/rib/initialRib.jsf', IbanPage)
     # CapBank-Market
     netissima = URL('/data/asv/fiches-fonds/fonds-netissima.html', NetissimaPage)
     starttitre = URL('/general\?command=goToAccount&zone=COMPTE', TitrePage)
@@ -62,7 +87,11 @@ class IngBrowser(LoginBrowser):
     titrehistory = URL('https://bourse.ingdirect.fr/priv/compte.php\?ong=3', TitreHistory)
     titrerealtime = URL('https://bourse.ingdirect.fr/streaming/compteTempsReelCK.php', TitrePage)
     titrevalue = URL('https://bourse.ingdirect.fr/priv/fiche-valeur.php\?val=(?P<val>.*)&pl=(?P<pl>.*)&popup=1', TitreValuePage)
-    # CapBill
+    asv_history = URL('https://ingdirectvie.ingdirect.fr/b2b2c/epargne/CoeLisMvt',
+                      'https://ingdirectvie.ingdirect.fr/b2b2c/epargne/CoeDetMvt', ASVHistory)
+    asv_invest = URL('https://ingdirectvie.ingdirect.fr/b2b2c/epargne/CoeDetCon', ASVInvest)
+    detailfonds = URL('https://ingdirectvie.ingdirect.fr/b2b2c/fonds/PerDesFac\?codeFonds=(.*)', DetailFondsPage)
+    # CapDocument
     billpage = URL('/protected/pages/common/estatement/eStatement.jsf', BillsPage)
 
     __states__ = ['where']
@@ -88,25 +117,23 @@ class IngBrowser(LoginBrowser):
             raise BrowserIncorrectPassword()
         if self.errorpage.is_here():
             raise BrowserIncorrectPassword('Please login on website to fill the form and retry')
+        self.page.check_for_action_needed()
 
     @need_login
-    @check_bourse
-    def get_accounts_list(self):
+    @start_with_main_site
+    def get_accounts_list(self, get_iban=True):
         self.accountspage.go()
         self.where = "start"
-        return self.page.get_list()
+        for acc in self.page.get_list():
+            if get_iban and acc.type in [Account.TYPE_CHECKING, Account.TYPE_SAVINGS]:
+                self.go_account_page(acc)
+                acc.iban = self.ibanpage.go().get_iban()
+            yield acc
 
     def get_account(self, _id):
-        return find_object(self.get_accounts_list(), id=_id, error=AccountNotFound)
+        return find_object(self.get_accounts_list(get_iban=False), id=_id, error=AccountNotFound)
 
-    @need_login
-    @check_bourse
-    def get_coming(self, account):
-        if account.type != Account.TYPE_CHECKING and\
-                account.type != Account.TYPE_SAVINGS:
-            raise NotImplementedError()
-        if self.where != "start":
-            account = self.get_account(account.id)
+    def go_account_page(self, account):
         data = {"AJAX:EVENTS_COUNT": 1,
                 "AJAXREQUEST": "_viewRoot",
                 "ajaxSingle": "index:setAccount",
@@ -118,6 +145,15 @@ class IngBrowser(LoginBrowser):
                 }
         self.accountspage.go(data=data)
         self.where = "history"
+
+    @need_login
+    @start_with_main_site
+    def get_coming(self, account):
+        if account.type != Account.TYPE_CHECKING and\
+                account.type != Account.TYPE_SAVINGS:
+            raise NotImplementedError()
+        account = self.get_account(account.id)
+        self.go_account_page(account)
         jid = self.page.get_history_jid()
         if jid is None:
             self.logger.info('There is no history for this account')
@@ -126,29 +162,19 @@ class IngBrowser(LoginBrowser):
         return self.page.get_coming()
 
     @need_login
-    @check_bourse
+    @start_with_main_site
     def get_history(self, account):
-        if account.type == Account.TYPE_MARKET:
+        if account.type == Account.TYPE_MARKET or account.type == Account.TYPE_LIFE_INSURANCE:
             for result in self.get_history_titre(account):
                 yield result
             return
+
         elif account.type != Account.TYPE_CHECKING and\
                 account.type != Account.TYPE_SAVINGS:
             raise NotImplementedError()
 
-        if self.where != "start":
-            account = self.get_account(account.id)
-        data = {"AJAX:EVENTS_COUNT": 1,
-                "AJAXREQUEST": "_viewRoot",
-                "ajaxSingle": "index:setAccount",
-                "autoScroll": "",
-                "index": "index",
-                "index:setAccount": "index:setAccount",
-                "javax.faces.ViewState": account._jid,
-                "cptnbr": account._id
-                }
-        self.accountspage.go(data=data)
-        self.where = "history"
+        account = self.get_account(account.id)
+        self.go_account_page(account)
         jid = self.page.get_history_jid()
         if jid is None:
             self.logger.info('There is no history for this account')
@@ -185,7 +211,7 @@ class IngBrowser(LoginBrowser):
             self.accountspage.go(data=data)
 
     @need_login
-    @check_bourse
+    @start_with_main_site
     def get_recipients(self, account):
         self.transferpage.stay_or_go()
         if self.page.ischecked(account.id):
@@ -197,7 +223,7 @@ class IngBrowser(LoginBrowser):
             self.transferpage.stay_or_go()
             return self.page.get_recipients()
 
-    @check_bourse
+    @start_with_main_site
     def transfer(self, account, recipient, amount, reason):
         found = False
         # Automatically get the good transfer page
@@ -224,6 +250,21 @@ class IngBrowser(LoginBrowser):
         else:
             raise TransferError('Recipient not found')
 
+    def go_on_asv_detail(self, account, link):
+        try:
+            if self.page.asv_is_other:
+                jid = self.page.get_asv_jid()
+                data = {'index': "index", 'javax.faces.ViewState': jid, 'index:j_idcl': "index:asvInclude:goToAsvPartner"}
+                self.accountspage.go(data=data)
+            else:
+                self.accountspage.go(asvpage="manageASVContract")
+                self.page.submit()
+            self.page.submit()
+            self.location(link)
+
+            return True
+        except SSLError:
+            return False
 
     def go_investments(self, account):
         account = self.get_account(account.id)
@@ -266,7 +307,7 @@ class IngBrowser(LoginBrowser):
         self.titrepage.go()
 
     @need_login
-    @check_bourse
+    @start_with_main_site
     def get_investments(self, account):
         if account.type not in (Account.TYPE_MARKET, Account.TYPE_LIFE_INSURANCE):
             raise NotImplementedError()
@@ -274,6 +315,11 @@ class IngBrowser(LoginBrowser):
 
         if self.where == u'titre':
             self.titrerealtime.go()
+        elif self.page.asv_has_detail or account._jid:
+            if self.go_on_asv_detail(account, '/b2b2c/epargne/CoeDetCon') is False:
+                return iter([])
+
+            self.where = u"asv"
         return self.page.iter_investments()
 
     def get_history_titre(self, account):
@@ -281,19 +327,35 @@ class IngBrowser(LoginBrowser):
 
         if self.where == u'titre':
             self.titrehistory.go()
-            return self.page.iter_history()
+        elif self.page.asv_has_detail or account._jid:
+            if self.go_on_asv_detail(account, '/b2b2c/epargne/CoeLisMvt') is False:
+                return iter([])
         else:
-            # No history for ASV accounts.
-            raise NotImplementedError()
+            return iter([])
 
-    ############# CapBill #############
+        transactions = list()
+        for tr in self.page.iter_history():
+            transactions.append(tr)
+        if self.asv_history.is_here():
+            for tr in transactions:
+                page = tr._detail.result().page if tr._detail else None
+                tr.investments = list(page.get_investments()) if page and 'numMvt' in page.url else []
+            self.lifeback.go()
+        return iter(transactions)
+
+    ############# CapDocument #############
+    @start_with_main_site
     @need_login
-    @check_bourse
     def get_subscriptions(self):
-        return self.billpage.go().iter_account()
+        self.billpage.go()
+        if self.loginpage.is_here():
+            self.do_login()
+            return self.billpage.go().iter_account()
+        else:
+            return self.page.iter_account()
 
     @need_login
-    def get_bills(self, subscription):
+    def get_documents(self, subscription):
         self.billpage.go()
         data = {"AJAXREQUEST": "_viewRoot",
                 "accountsel_form": "accountsel_form",
@@ -303,7 +365,7 @@ class IngBrowser(LoginBrowser):
                 "transfer_issuer_radio": subscription.id
                 }
         self.billpage.go(data=data)
-        return self.page.iter_bills(subid=subscription.id)
+        return self.page.iter_documents(subid=subscription.id)
 
     def predownload(self, bill):
         self.page.postpredown(bill._localid)
