@@ -19,22 +19,23 @@
 
 
 from weboob.capabilities.bank import CapBank, Account, Recipient
-from weboob.capabilities.bill import CapBill, Bill, Subscription,\
-    SubscriptionNotFound, BillNotFound
-from weboob.capabilities.base import UserError, find_object
+from weboob.capabilities.bill import CapDocument, Bill, Subscription,\
+    SubscriptionNotFound, DocumentNotFound
+from weboob.capabilities.base import UserError, find_object, NotAvailable
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword
+from weboob.browser.exceptions import ServerError
 
 from .browser import IngBrowser
 
 __all__ = ['INGModule']
 
 
-class INGModule(Module, CapBank, CapBill):
+class INGModule(Module, CapBank, CapDocument):
     NAME = 'ing'
     MAINTAINER = u'Florent Fourcot'
     EMAIL = 'weboob@flo.fourcot.fr'
-    VERSION = '1.1'
+    VERSION = '1.2'
     LICENSE = 'AGPLv3+'
     DESCRIPTION = 'ING Direct'
     CONFIG = BackendConfig(ValueBackendPassword('login',
@@ -79,8 +80,8 @@ class INGModule(Module, CapBank, CapBill):
             account = self.get_account(account)
         return self.browser.get_recipients(account)
 
-    def transfer(self, account, recipient, amount, reason):
-        if not reason:
+    def transfer(self, account, recipient, amount, reason=None):
+        if reason is None:
             raise UserError('Reason is mandatory to do a transfer on ING website')
         if not isinstance(account, Account):
             account = self.get_account(account)
@@ -106,18 +107,22 @@ class INGModule(Module, CapBank, CapBill):
     def get_subscription(self, _id):
         return find_object(self.browser.get_subscriptions(), id=_id, error=SubscriptionNotFound)
 
-    def get_bill(self, _id):
+    def get_document(self, _id):
         subscription = self.get_subscription(_id.split('-')[0])
-        return find_object(self.browser.get_bills(subscription), id=_id, error=BillNotFound)
+        return find_object(self.browser.get_documents(subscription), id=_id, error=DocumentNotFound)
 
-    def iter_bills(self, subscription):
+    def iter_documents(self, subscription):
         if not isinstance(subscription, Subscription):
             subscription = self.get_subscription(subscription)
-        return self.browser.get_bills(subscription)
+        return self.browser.get_documents(subscription)
 
-    def download_bill(self, bill):
+    def download_document(self, bill):
         if not isinstance(bill, Bill):
-            bill = self.get_bill(bill)
-        self.browser.predownload(bill)
-        assert(self.browser.response.headers['content-type'] == "application/pdf")
+            bill = self.get_document(bill)
+        self.get_document(bill.id)
+        try:
+            self.browser.predownload(bill)
+        except ServerError:
+            return NotAvailable
+        assert(self.browser.response.headers['content-type'] in ["application/pdf", "application/download"])
         return self.browser.response.content
