@@ -18,11 +18,12 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from .accounts_list import AccountsList, TitreDetails
-from .login import LoginPage, StopPage
+from .accounts_list import AccountsList, TitreDetails, ASVInvest, DetailFondsPage, \
+                           IbanPage
+from .login import LoginPage, StopPage, ActionNeededPage, ReturnPage
 from .transfer import TransferPage, TransferConfirmPage
 from .bills import BillsPage
-from .titre import NetissimaPage, TitrePage, TitreHistory, TitreValuePage
+from .titre import NetissimaPage, TitrePage, TitreHistory, TitreValuePage, ASVHistory
 
 
 class AccountPrelevement(AccountsList):
@@ -30,5 +31,6 @@ class AccountPrelevement(AccountsList):
 
 __all__ = ['AccountsList', 'LoginPage', 'NetissimaPage','TitreDetails',
            'AccountPrelevement', 'TransferPage', 'TransferConfirmPage',
-           'BillsPage', 'StopPage', 'TitrePage', 'TitreHistory',
-           'TitreValuePage']
+           'BillsPage', 'StopPage', 'TitrePage', 'TitreHistory', 'IbanPage',
+           'TitreValuePage', 'ASVHistory', 'ASVInvest','DetailFondsPage',
+           'ActionNeededPage', 'ReturnPage']
