@@ -20,16 +20,15 @@
 
 from datetime import date, timedelta
 import datetime
-from decimal import Decimal
 import re
 
 from weboob.capabilities.bank import Account, Investment
 from weboob.capabilities.base import NotAvailable
 from weboob.browser.pages import HTMLPage, LoggedPage
-from weboob.browser.elements import ListElement, ItemElement, method
-from weboob.browser.filters.standard import CleanText, CleanDecimal, Filter, Field, MultiFilter, \
-                                            Date, Lower, Regexp, Async, AsyncLoad
-from weboob.browser.filters.html import Attr
+from weboob.browser.elements import ListElement, TableElement, ItemElement, method
+from weboob.browser.filters.standard import CleanText, CleanDecimal, Filter, Field, MultiFilter, Date, \
+                                            Lower, Async, AsyncLoad, Format, TableCell, Eval
+from weboob.browser.filters.html import Attr, Link
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 
 
@@ -89,17 +88,17 @@ class INGDate(Date):
 
     def filter(self, txt):
         if txt == 'hier':
-            return (date.today() - timedelta(days=1))
+            return date.today() - timedelta(days=1)
         elif txt == "aujourd'hui":
             return date.today()
         elif txt == 'demain':
-            return (date.today() + timedelta(days=1))
-        else:
-            frenchmonth = txt.split(' ')[1]
-            month = self.monthvalue[frenchmonth]
-            txt = txt.replace(' ', '')
-            txt = txt.replace(frenchmonth, '/%s/' % month)
-            return super(INGDate, self).filter(txt)
+            return date.today() + timedelta(days=1)
+
+        frenchmonth = txt.split(' ')[1]
+        month = self.monthvalue[frenchmonth]
+        txt = txt.replace(' ', '')
+        txt = txt.replace(frenchmonth, '/%s/' % month)
+        return super(INGDate, self).filter(txt)
 
 
 class INGCategory(Filter):
@@ -130,7 +129,6 @@ class AccountsList(LoggedPage, HTMLPage):
             klass = Account
 
             obj_currency = u'EUR'
-            obj__id = CleanText('span[@class="account-number"]')
             obj_label = CleanText('span[@class="title"]')
             obj_id = AddPref(Field('_id'), Field('label'))
             obj_type = AddType(Field('label'))
@@ -138,19 +136,24 @@ class AccountsList(LoggedPage, HTMLPage):
             obj_coming = NotAvailable
             obj__jid = Attr('//input[@name="javax.faces.ViewState"]', 'value')
 
+            def obj__id(self):
+                return CleanText('span[@class="account-number"]')(self) or CleanText('span[@class="life-insurance-application"]')(self)
+
     class generic_transactions(ListElement):
         class item(ItemElement):
             klass = Transaction
 
             obj_id = None  # will be overwrited by the browser
             # we use lower for compatibility with the old website
-            obj_raw = Transaction.Raw(Lower('.//td[@class="lbl"]'))
             obj_amount = CleanDecimal('.//td[starts-with(@class, "amount")]', replace_dots=True)
             obj_date = INGDate(CleanText('.//td[@class="date"]'), dayfirst=True)
             obj_rdate = Field('date')
             obj__hash = PreHashmd5(Field('date'), Field('raw'), Field('amount'))
             obj_category = INGCategory(Attr('.//td[@class="picto"]/span', 'class'))
 
+            def obj_raw(self):
+                return Transaction.Raw(Lower('.//td[@class="lbl"]'))(self) or Format('%s %s', Field('date'), Field('amount'))(self)
+
             def condition(self):
                 if self.el.find('.//td[@class="date"]') is None:
                     return False
@@ -176,65 +179,87 @@ class AccountsList(LoggedPage, HTMLPage):
         jid = span.split(':')[1]
         return jid
 
+    def get_asv_jid(self):
+        return self.doc.xpath('//input[@id="javax.faces.ViewState"]/@value')[0]
+
     def islast(self):
         havemore = self.doc.getroot().cssselect('.show-more-transactions')
         if len(havemore) == 0:
             return True
 
         nomore = self.doc.getroot().cssselect('.no-more-transactions')
-        return (len(nomore) > 0)
+        return len(nomore) > 0
 
     @property
     def is_asv(self):
         span = self.doc.xpath('//span[@id="index:panelASV"]')
         return len(span) > 0
 
-    @method
-    class iter_investments(ListElement):
-        item_xpath = '//div[has-class("asv_fond")]'
+    @property
+    def asv_has_detail(self):
+        ap = self.doc.xpath('//a[@id="index:asvInclude:goToAsvPartner"] | //p[contains(text(), "Gestion Libre")]')
+        return len(ap) > 0
 
-        class item(ItemElement):
-            klass = Investment
+    @property
+    def asv_is_other(self):
+        a = self.doc.xpath('//a[@id="index:asvInclude:goToAsvPartner"]')
+        return len(a) > 0
 
-            # ASV.popup('/general?command=displayAVEuroEpargne')
-            load_details = Attr('.//div[has-class("asv_fond_view")]//a', 'onclick') & Regexp(pattern="'(.*)'") & AsyncLoad
+    def submit(self):
+        form = self.get_form(name="follow_link")
+        form['follow_link:j_idcl'] = "follow_link:goToAsvPartner"
+        form.submit()
 
-            obj_label = CleanText('.//span[has-class("asv_cat_lbl")]')
-            obj_code = Async('details') & CleanText('//li[contains(text(), "Code ISIN")]/span[1]')
-            obj_id = obj_code
-            obj_description = Async('details') & CleanText('//h5')
-            obj_quantity = CleanDecimal('.//dl[contains(dt/text(), "Nombre de parts")]/dd', replace_dots=True)
-            obj_unitvalue = CleanDecimal('.//dl[contains(dt/text(), "Valeur de part")]/dd', replace_dots=True)
 
-            # There are two kind of lists:
-            # - Header contains percent and valuation is in a specific row ("ligne-montant")
-            # - Header contains valuation, there is no "ligne-montant" row, and percent is in a specific row
-            obj_valuation = CleanDecimal('.//dl[has-class("ligne-montant")]/dd | .//dd[@data-show="header" and not(contains(text(), "%"))]', replace_dots=True)
-
-            def obj_unitprice(self):
-                if 'eurossima' in self.el.get('class') or \
-                   'fondsEuro' in self.el.get('class'):
-                    # in this case, the content of field is:
-                    # <span data-sort="pm_value" class="pmvalue positive">NOT_A_NUMBER</span>
-                    return self.obj.unitvalue
-
-                if self.el.xpath('.//span[has-class("pmvalue")]')[0].text == u'+∞ %':
-                    percent = NotAvailable
-                    return NotAvailable
-                else:
-                    percent = CleanDecimal('.//span[has-class("pmvalue")]', replace_dots=True)(self)
-                return (self.obj.unitvalue / (1 + percent/Decimal('100.0'))).quantize(Decimal('1.00'))
-
-            def obj_diff(self):
-                if not self.obj.quantity:
-                    # Quantity of euro funds is null.
-                    return Decimal('0.00')
-
-                if not self.obj.unitprice:
-                    return NotAvailable
-
-                return (self.obj.valuation - (self.obj.quantity * self.obj.unitprice)).quantize(Decimal('1.00'))
+class IbanPage(LoggedPage, HTMLPage):
+    def get_iban(self):
+        iban = CleanText('//tr[td[1]//text()="IBAN"]/td[2]')(self.doc).strip().replace(' ', '')
+        if not iban or 'null' in iban:
+            return NotAvailable
+        return iban
 
 
 class TitreDetails(LoggedPage, HTMLPage):
+    def submit(self):
+        form = self.get_form()
+        form.submit()
+
+
+class ASVInvest(LoggedPage, HTMLPage):
+    @method
+    class iter_investments(TableElement):
+        item_xpath = '//table[@class="Tableau"]//tr[position()>2]'
+        head_xpath = '//table[@class="Tableau"]//tr[position()=2]/td'
+
+        col_label = u'Support(s)'
+        col_vdate = re.compile('Date')
+        col_unitvalue = u'Valeur de part'
+        col_quantity = u'Nombre de parts'
+        col_valuation = u'Contre-valeur'
+        col_unitprice = u'Prix revient'
+        col_diff = u'Montant'
+        col_portfolio_share = u'%'
+
+        class item(ItemElement):
+            klass = Investment
+            load_details = Link('.//td[1]//a')  & AsyncLoad
+
+            def obj_code(self):
+                val = Async('details', CleanText('//td[@class="libelle-normal" and contains(.,"CodeISIN")]', default=NotAvailable))(self)
+                return val.split('CodeISIN : ')[1] if val else val
+
+            def obj_portfolio_share(self):
+                p = CleanDecimal(TableCell('portfolio_share'), replace_dots=True, default=NotAvailable)(self)
+                return Eval(lambda x: x / 100, p)(self) if p else p
+
+            obj_label = CleanText(TableCell('label'))
+            obj_vdate = Date(CleanText(TableCell('vdate')), dayfirst=True)
+            obj_unitvalue = CleanDecimal(TableCell('unitvalue'), replace_dots=True, default=NotAvailable)
+            obj_quantity = CleanDecimal(TableCell('quantity'), replace_dots=True, default=NotAvailable)
+            obj_valuation = CleanDecimal(TableCell('valuation'), replace_dots=True)
+            obj_unitprice = CleanDecimal(TableCell('unitprice'), replace_dots=True, default=NotAvailable)
+            obj_diff = CleanDecimal(TableCell('diff'), replace_dots=True, default=NotAvailable)
+
+
+class DetailFondsPage(LoggedPage,HTMLPage):
     pass
