@@ -54,7 +54,7 @@ class BillsPage(LoggedPage, HTMLPage):
 
     @pagination
     @method
-    class iter_bills(ListElement):
+    class iter_documents(ListElement):
         item_xpath = '//ul[@id="statements_form:statementsel"]/li'
 
         def next_page(self):
@@ -87,4 +87,5 @@ class BillsPage(LoggedPage, HTMLPage):
             # Force first day of month as label is in form "janvier 2016"
             obj_date = Format("1 %s", Field('label')) & Date(parse_func=parse_french_date)
             obj_format = u"pdf"
+            obj_type = u"bill"
             obj__localid = Attr('a[2]', 'onclick')
