@@ -19,10 +19,11 @@
 
 from StringIO import StringIO
 
-from weboob.exceptions import BrowserIncorrectPassword
+from weboob.exceptions import BrowserIncorrectPassword, ActionNeeded
 from weboob.tools.captcha.virtkeyboard import VirtKeyboard
-from weboob.browser.pages import HTMLPage
+from weboob.browser.pages import HTMLPage, LoggedPage
 from weboob.browser.filters.html import Attr
+from weboob.browser.filters.standard import CleanText
 
 
 class INGVirtKeyboard(VirtKeyboard):
@@ -114,6 +115,27 @@ class LoginPage(HTMLPage):
         form['mrc:mrldisplayLogin'] = vk.get_coordinates(password)
         form.submit()
 
+    def check_for_action_needed(self):
+        link = Attr('//meta[@content="/general?command=displayTRAlertMessage"]', 'content', default=None)(self.doc)
+        if link:
+            self.browser.location(link)
+
+
+class ActionNeededPage(HTMLPage):
+    def on_load(self):
+        if self.doc.xpath(u'//form//h1[contains(text(), "Accusé de reception du chéquier")]'):
+            form = self.get_form(name='Alert')
+            form['command'] = 'validateAlertMessage'
+            form['radioValide_1_2_40003039944'] = 'Non'
+            form.submit()
+        else:
+            raise ActionNeeded(CleanText(u'//form//h1[1]')(self.doc))
+
 
 class StopPage(HTMLPage):
     pass
+
+
+class ReturnPage(LoggedPage, HTMLPage):
+    def on_load(self):
+        self.get_form(name='retoursso').submit()
