@@ -18,18 +18,19 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-import requests
 import urllib
 from urlparse import urlsplit, parse_qsl
 
 from weboob.exceptions import BrowserIncorrectPassword
 from weboob.browser import LoginBrowser, URL, need_login
+from weboob.browser.exceptions import ServerError
+from weboob.capabilities.base import NotAvailable
 from weboob.capabilities.bank import Account
 
 from .pages import LoginPage, AccountsPage, AccountHistoryPage, \
                    CBListPage, CBHistoryPage, ContractsPage, BoursePage, \
                    AVPage, AVDetailPage, DiscPage, NoPermissionPage, RibPage, \
-                   HomePage
+                   HomePage, LoansPage, TransferPage
 
 
 __all__ = ['LCLBrowser','LCLProBrowser']
@@ -38,7 +39,6 @@ __all__ = ['LCLBrowser','LCLProBrowser']
 # Browser
 class LCLBrowser(LoginBrowser):
     BASEURL = 'https://particuliers.secure.lcl.fr'
-    VERIFY = False
 
     login = URL('/outil/UAUT/Authentication/authenticate',
                 '/outil/UAUT\?from=.*',
@@ -76,19 +76,20 @@ class LCLBrowser(LoginBrowser):
                    'https://assurance-vie-et-prevoyance.secure.lcl.fr.*',
                    '/outil/UWVI/Routage', AVDetailPage)
 
-    TIMEOUT = 30.0
+    loans = URL('/outil/UWCR/SynthesePar/', LoansPage)
 
-    def __init__(self, *args, **kwargs):
-        if hasattr(requests.packages.urllib3.contrib, 'pyopenssl') \
-           and ':RC4' not in requests.packages.urllib3.contrib.pyopenssl.DEFAULT_SSL_CIPHER_LIST:
-            requests.packages.urllib3.contrib.pyopenssl.DEFAULT_SSL_CIPHER_LIST += ':RC4'
+    transfer_page = URL('/outil/UWVS/', TransferPage)
+    confirm_transfer = URL('/outil/UWVS/Accueil/redirectView', TransferPage)
+    #recipients = URL('/outil/UWBE/Consultation/list', RecipientPage)
 
-        super(LCLBrowser, self).__init__(*args, **kwargs)
+    accounts_list = None
 
     def do_login(self):
         assert isinstance(self.username, basestring)
         assert isinstance(self.password, basestring)
-        assert self.password.isdigit()
+
+        if not self.password.isdigit():
+            raise BrowserIncorrectPassword()
 
         # we force the browser to go to login page so it's work even
         # if the session expire
@@ -98,6 +99,7 @@ class LCLBrowser(LoginBrowser):
            (self.login.is_here() and self.page.is_error()) :
             raise BrowserIncorrectPassword("invalid login/password.\nIf you did not change anything, be sure to check for password renewal request\non the original web site.\nAutomatic renewal will be implemented later.")
 
+        self.accounts_list = None
         self.accounts.stay_or_go()
 
     @need_login
@@ -116,42 +118,61 @@ class LCLBrowser(LoginBrowser):
 
     @need_login
     def get_accounts_list(self):
-        self.assurancevie.stay_or_go()
-        if self.no_perm.is_here():
-            self.logger.warning('Life insurances are unavailable.')
-        else:
+        if self.accounts_list is None:
+            self.accounts_list = []
+            self.assurancevie.stay_or_go()
+            if self.no_perm.is_here():
+                self.logger.warning('Life insurances are unavailable.')
+            else:
+                for a in self.page.get_list():
+                    self.accounts_list.append(a)
+            self.accounts.stay_or_go()
             for a in self.page.get_list():
-                yield a
-        self.accounts.stay_or_go()
-        accounts = list()
-        for acc in self.page.get_list():
-            self.location('/outil/UWRI/Accueil/')
-            self.rib.go(data={'compte': '%s/%s/%s' % (acc.id[0:5],acc.id[5:11],acc.id[11:])})
-            if self.rib.is_here():
-                acc.iban = self.page.get_iban()
-            accounts.append(acc)
-
-        if self.connexion_bourse():
-            acc = list(self.page.populate(accounts))
-            self.deconnexion_bourse()
-            # Disconnecting from bourse portal before returning account list
-            # to be sure that we are on the banque portal
-            for a in acc:
-                yield a
-        else:
-            for a in accounts:
-                yield a
+                self.location('/outil/UWRI/Accueil/')
+                self.rib.go(data={'compte': '%s/%s/%s' % (a.id[0:5], a.id[5:11], a.id[11:])})
+                if self.rib.is_here():
+                    iban = self.page.get_iban()
+                    a.iban = iban if iban and a.id[11:] in iban else NotAvailable
+                self.accounts_list.append(a)
+            self.loans.stay_or_go()
+            if self.no_perm.is_here():
+                self.logger.warning('Loans are unavailable.')
+            else:
+                for a in self.page.get_list():
+                    self.accounts_list.append(a)
+            if self.connexion_bourse():
+                for a in self.page.get_list():
+                    self.accounts_list.append(a)
+                self.deconnexion_bourse()
+                # Disconnecting from bourse portal before returning account list
+                # to be sure that we are on the banque portal
+        return iter(self.accounts_list)
 
     @need_login
     def get_history(self, account):
-        if not account._link_id:
-            return
-        self.location(account._link_id)
-        for tr in self.page.get_operations():
-            yield tr
-
-        for tr in self.get_cb_operations(account, 1):
-            yield tr
+        if hasattr(account, '_market_link') and account._market_link:
+            self.connexion_bourse()
+            self.location(account._market_link)
+            self.location(account._link_id).page.get_fullhistory()
+            for tr in self.page.iter_history():
+                yield tr
+            self.deconnexion_bourse()
+        elif hasattr(account, '_link_id') and account._link_id:
+            try:
+                self.location(account._link_id)
+            except ServerError:
+                return
+            for tr in self.page.get_operations():
+                yield tr
+            for tr in self.get_cb_operations(account, 1):
+                yield tr
+        elif account.type == Account.TYPE_LIFE_INSURANCE and account._form:
+            self.assurancevie.stay_or_go()
+            account._form.submit()
+            self.page.sub().page.sub().page.get_details(account, "OHIPU")
+            for tr in self.page.iter_history():
+                yield tr
+            self.page.come_back().page.sub().page.come_back()
 
     @need_login
     def get_cb_operations(self, account, month=0):
@@ -161,6 +182,9 @@ class LCLBrowser(LoginBrowser):
         * month=0 : current operations (non debited)
         * month=1 : previous month operations (debited)
         """
+        if not hasattr(account, '_coming_links'):
+            return
+
         for link in account._coming_links:
             v = urlsplit(self.absurl(link))
             args = dict(parse_qsl(v.query))
@@ -176,28 +200,50 @@ class LCLBrowser(LoginBrowser):
                 for tr in self.page.get_operations():
                     yield tr
 
-    def disc_from_AV_investment_detail(self):
-        self.page.come_back()
-        self.page.sub()
-        self.page.come_back()
-
     @need_login
     def get_investment(self, account):
         if account.type == Account.TYPE_LIFE_INSURANCE and account._form:
             self.assurancevie.stay_or_go()
             account._form.submit()
-            self.page.sub()
-            self.page.sub()
+            self.page.sub().page.sub()
             for inv in self.page.iter_investment():
                 yield inv
-            self.disc_from_AV_investment_detail()
-        elif account._market_link:
+            self.page.come_back().page.sub().page.come_back()
+        elif hasattr(account, '_market_link') and account._market_link:
             self.connexion_bourse()
-            self.location(account._market_link)
-            for inv in self.page.iter_investment():
+            for inv in self.location(account._market_link).page.iter_investment():
                 yield inv
             self.deconnexion_bourse()
 
+    @need_login
+    def iter_recipients(self, origin_account):
+        if origin_account._transfer_id is None:
+            return
+        self.transfer_page.go()
+        if not self.page.can_transfer(origin_account._transfer_id):
+            return
+        self.page.choose_origin(origin_account._transfer_id)
+        for recipient in self.page.iter_recipients(account_transfer_id=origin_account._transfer_id):
+            yield recipient
+
+    @need_login
+    def init_transfer(self, account, recipient, amount, reason=None):
+        self.transfer_page.go()
+        self.page.choose_origin(account._transfer_id)
+        self.page.choose_recip(recipient)
+        self.page.transfer(amount, reason)
+        self.page.check_data_consistency(account, recipient, amount, reason)
+        return self.page.create_transfer(account, recipient, amount, reason)
+
+    @need_login
+    def execute_transfer(self, transfer):
+        self.page.confirm()
+        return self.page.fill_transfer_id(transfer)
+
+    @need_login
+    def get_advisor(self):
+        return iter([self.accounts.stay_or_go().get_advisor()])
+
 
 class LCLProBrowser(LCLBrowser):
     BASEURL = 'https://professionnels.secure.lcl.fr'
