@@ -17,24 +17,18 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-from .pages.article import ArticlePage
-from weboob.deprecated.browser import Browser
+from .pages import ArticlePage
+from weboob.browser.browsers import AbstractBrowser
+from weboob.browser.url import URL
 
 
-class NewspaperLibeBrowser(Browser):
+class NewspaperLibeBrowser(AbstractBrowser):
     "NewspaperLibeBrowser class"
-    PAGES = {"http://.*liberation.fr/.*": ArticlePage}
+    PARENT = 'genericnewspaper'
+    BASEURL = ''
 
-    def is_logged(self):
-        return False
+    article = URL('http://.*liberation.fr/.*', ArticlePage)
 
-    def login(self):
-        pass
-
-    def fillobj(self, obj, fields):
-        pass
-
-    def get_content(self, _id):
-        "return page article content"
-        self.location(_id)
-        return self.page.get_article(_id)
+    def __init__(self, weboob, *args, **kwargs):
+        self.weboob = weboob
+        super(self.__class__, self).__init__(*args, **kwargs)
