@@ -187,6 +187,54 @@ class MediawikiBrowser(DomainBrowser):
                     last_id = rev_content.id
                     results += 1
 
+    def _common_file_request(self):
+        return {'action':       'query',
+                'prop':         'info|imageinfo',
+                'inprop':       'url',
+                'iiprop':       'extmetadata|size|url|canonicaltitle',
+                'iiurlwidth':   512,
+                'iiurlheight':  512,
+               }
+
+    def _common_parse_file(self, info):
+        res = {'canonicalurl': info['canonicalurl'],
+               'title':        info['title'],
+               'size':         info['imageinfo'][0]['size'],
+              }
+
+        iinfo = info['imageinfo'][0]
+        if 'url' in iinfo:
+            res['original'] = iinfo['url']
+        if 'thumburl' in iinfo:
+            res['thumbnail'] = iinfo['thumburl']
+        return res
+
+    def search_file(self, pattern):
+        data = self._common_file_request()
+        data['generator'] = 'search'
+        data['gsrnamespace'] = 6 # File: namespace
+        data['gsrsearch'] = pattern
+
+        while True:
+            response = self.API_get(data)
+            for fdict in response['query']['pages'].values():
+                yield self._common_parse_file(fdict)
+
+            if 'continue' in response:
+                data.update(response['continue'])
+            else:
+                break
+
+    def get_image(self, page):
+        page = self.url2page(page)
+        data = self._common_file_request()
+        data['titles'] = page
+
+        response = self.API_get(data)
+        pageid = response['query']['pages'].keys()[0]
+        info = response['query']['pages'][pageid]
+        return self._common_parse_file(info)
+
     def home(self):
         # We don't need to change location, we're using the JSON API here.
         pass
