@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-
+import itertools
 from weboob.tools.test import BackendTest
 
 
@@ -25,13 +25,13 @@ class MonsterTest(BackendTest):
     MODULE = 'monster'
 
     def test_monster_search(self):
-        l = list(self.backend.search_job(u'marketing'))
+        l = list(itertools.islice(self.backend.search_job(u'marketing'), 0, 20))
         assert len(l)
         advert = self.backend.get_job_advert(l[0].id, None)
         self.assertTrue(advert.url, 'URL for announce "%s" not found: %s' % (advert.id, advert.url))
 
     def test_monster_advanced_search(self):
-        l = list(self.backend.advanced_search_job())
+        l = list(itertools.islice(self.backend.advanced_search_job(), 0, 20))
         assert len(l)
         advert = self.backend.get_job_advert(l[0].id, None)
         self.assertTrue(advert.url, 'URL for announce "%s" not found: %s' % (advert.id, advert.url))
