@@ -18,7 +18,7 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from weboob.capabilities.bill import CapBill, Subscription, SubscriptionNotFound, Detail
+from weboob.capabilities.bill import CapDocument, Subscription, SubscriptionNotFound, Detail
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword
 
@@ -28,11 +28,11 @@ from .browser import Nettokom
 __all__ = ['NettoKomModule']
 
 
-class NettoKomModule(Module, CapBill):
+class NettoKomModule(Module, CapDocument):
     NAME = 'nettokom'
     MAINTAINER = u'Florent Fourcot'
     EMAIL = 'weboob@flo.fourcot.fr'
-    VERSION = '1.1'
+    VERSION = '1.2'
     LICENSE = 'AGPLv3+'
     DESCRIPTION = 'Nettokom website'
     CONFIG = BackendConfig(ValueBackendPassword('login',
@@ -60,7 +60,7 @@ class NettoKomModule(Module, CapBill):
         else:
             raise SubscriptionNotFound()
 
-    def iter_bills_history(self, subscription):
+    def iter_documents_history(self, subscription):
         with self.browser:
             for history in self.browser.get_history():
                 yield history
