@@ -29,10 +29,9 @@ __all__ = ['OneyBrowser']
 
 class OneyBrowser(LoginBrowser):
     BASEURL = 'https://www.oney.fr'
-    VERIFY = False
 
     index =      URL(r'/oney/client', IndexPage)
-    login =      URL(r'/oney/client', LoginPage)
+    login =      URL(r'/site/s/login/login.html', LoginPage)
     operations = URL(r'/oney/client', OperationsPage)
     card_page =  URL(r'/oney/client\?task=Synthese&process=SyntheseMultiCompte&indexSelectionne=(?P<acc_num>/d)')
 
