@@ -18,9 +18,9 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from weboob.capabilities.bill import CapBill, Subscription, Bill, SubscriptionNotFound, BillNotFound
+from weboob.capabilities.bill import CapDocument, Subscription, Document, SubscriptionNotFound, DocumentNotFound
 from weboob.capabilities.messages import CantSendMessage, CapMessages, CapMessagesPost
-from weboob.capabilities.base import find_object
+from weboob.capabilities.base import find_object, NotAvailable
 from weboob.capabilities.account import CapAccount, StatusField
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import ValueBackendPassword, Value
@@ -32,7 +32,7 @@ from .bill.browser import OrangeBillBrowser
 __all__ = ['OrangeModule']
 
 # We need to have a switcher, CapMessages use a browser1 and
-# CapBill use a browser2
+# CapDocument use a browser2
 # This will be remove when CapMessages use a browser2
 def browser_switcher(b):
     def set_browser(func):
@@ -49,11 +49,12 @@ def browser_switcher(b):
         return func_wrapper
     return set_browser
 
-class OrangeModule(Module, CapAccount, CapMessages, CapMessagesPost, CapBill):
+
+class OrangeModule(Module, CapAccount, CapMessages, CapMessagesPost, CapDocument):
     NAME = 'orange'
     MAINTAINER = u'Lucas Nussbaum'
     EMAIL = 'lucas@lucas-nussbaum.net'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = 'Orange French mobile phone provider'
     LICENSE = 'AGPLv3+'
     CONFIG = BackendConfig(Value('login', label='Login'),
@@ -91,21 +92,21 @@ class OrangeModule(Module, CapAccount, CapMessages, CapMessagesPost, CapBill):
         return find_object(self.iter_subscription(), id=_id, error=SubscriptionNotFound)
 
     @browser_switcher(OrangeBillBrowser)
-    def get_bill(self, _id):
-        subid = _id.split('.')[0]
+    def get_document(self, _id):
+        subid = _id.rsplit('_', 1)[0]
         subscription = self.get_subscription(subid)
-
-        return find_object(self.iter_bills(subscription), id=_id, error=BillNotFound)
+        return find_object(self.iter_documents(subscription), id=_id, error=DocumentNotFound)
 
     @browser_switcher(OrangeBillBrowser)
-    def iter_bills(self, subscription):
+    def iter_documents(self, subscription):
         if not isinstance(subscription, Subscription):
             subscription = self.get_subscription(subscription)
-        return self.browser.iter_bills(subscription)
+        return self.browser.iter_documents(subscription)
 
     @browser_switcher(OrangeBillBrowser)
-    def download_bill(self, bill):
-        if not isinstance(bill, Bill):
-            bill = self.get_bill(bill)
-        return self.browser.open(bill._url).content
-
+    def download_document(self, document):
+        if not isinstance(document, Document):
+            document = self.get_document(document)
+        if document.url is NotAvailable:
+            return
+        return self.browser.open(document.url).content
