@@ -30,8 +30,8 @@ __all__ = ['ParolesmaniaModule']
 class ParolesmaniaModule(Module, CapLyrics):
     NAME = 'parolesmania'
     MAINTAINER = u'Julien Veyssier'
-    EMAIL = 'julien.veyssier@aiur.fr'
-    VERSION = '1.1'
+    EMAIL = 'eneiluj@gmx.fr'
+    VERSION = '1.2'
     DESCRIPTION = 'Paroles Mania lyrics website'
     LICENSE = 'AGPLv3+'
     BROWSER = ParolesmaniaBrowser
