@@ -18,13 +18,11 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from weboob.tools.test import BackendTest
+from weboob.tools.test import BackendTest, skip_without_config
 from weboob.capabilities.base import NotLoaded
 
 from weboob.capabilities.paste import PasteNotFound
 
-from .browser import Spam
-
 
 class PastealaconTest(BackendTest):
     MODULE = 'pastealacon'
@@ -46,6 +44,7 @@ class PastealaconTest(BackendTest):
         assert u'héhéhé' in p.contents
         assert p.public is True
 
+    @skip_without_config()
     def test_post(self):
         p = self.backend.new_paste(None, title=u'ouiboube', contents=u'Weboob Test héhéhé')
         self.backend.post_paste(p, max_age=3600*24)
@@ -63,7 +62,9 @@ class PastealaconTest(BackendTest):
 
     def test_spam(self):
         p = self.backend.new_paste(None, title=u'viagra', contents=u'http://example.com/')
-        self.assertRaises(Spam, self.backend.post_paste, p)
+        with self.assertRaises(Exception) as cm:
+            self.backend.post_paste(p)
+            self.assertEqual(cm.message, "Detected as spam and unable to handle the captcha")
 
     def test_notfound(self):
         for _id in ('424242424242424242424242424242424242',
