@@ -26,7 +26,8 @@ from weboob.exceptions import BrowserHTTPError, BrowserIncorrectPassword
 from weboob.browser.browsers import LoginBrowser, need_login
 from weboob.browser.url import URL
 
-from .pages import PromoPage, LoginPage, AccountPage, UselessPage, HomePage, ProHistoryPage, PartHistoryPage, HistoryDetailsPage, HistoryPaybackPage, ErrorPage
+from .pages import PromoPage, LoginPage, AccountPage, UselessPage, HomePage, ProHistoryPage, \
+                   PartHistoryPage, HistoryDetailsPage, ErrorPage, OldWebsitePage, LandingPage, InfoPage
 
 
 __all__ = ['Paypal']
@@ -35,42 +36,45 @@ __all__ = ['Paypal']
 class Paypal(LoginBrowser):
     BASEURL = 'https://www.paypal.com'
 
-    login = URL('https://\w+.paypal.com/signin/.*',
+    login = URL('https://\w+.paypal.com/signin.*',
                 '/cgi-bin/webscr\?cmd=_login-submit.+$',
-                LoginPage)
+                '/fr/webapps/mpp/home', LoginPage)
+    landing = URL('/home',
+                  '/$', LandingPage)
     useless = URL('/cgi-bin/webscr\?cmd=_login-processing.+$',
                   '/cgi-bin/webscr\?cmd=_account.*$',
                   '/cgi-bin/webscr\?cmd=_login-done.+$',
                   UselessPage)
-    home = URL('/cgi-bin/webscr\?cmd=_home&country_lang.x=true$',
+    info = URL('/fr/merchantsignup/personalInfo', InfoPage)
+    home = URL('.*/cgi-bin/webscr\?cmd=_home&country_lang.x=true$',
                'https://\w+.paypal.com/webapps/business/\?country_lang.x=true',
                'https://\w+.paypal.com/myaccount/\?nav=0.0',
                'https://\w+.paypal.com/webapps/business/\?nav=0.0',
                'https://\w+.paypal.com/myaccount/$',
+               '/businessexp/summary.*',
+               '/myaccount/?\?country_lang.x=true',
+               '/businessexp/fees/interchange-fees',
                HomePage)
     error = URL('/auth/validatecaptcha$', ErrorPage)
     history_details = URL('https://\w+.paypal.com/cgi-bin/webscr\?cmd=_history-details-from-hub&id=[\-A-Z0-9]+$',
                           'https://\w+.paypal.com/myaccount/transaction/details/[\-A-Z0-9]+$',
                           HistoryDetailsPage)
-    history_payback = URL('https://history.paypal.com/fr/cgi-bin/webscr\?cmd=_history-details.*', HistoryPaybackPage)
-    promo = URL('https://www.paypal.com/fr/webapps/mpp/clickthru/paypal-app-promo-2.*', PromoPage)
+    promo = URL('https://www.paypal.com/fr/webapps/mpp/clickthru/paypal-app-promo-2.*',
+                '/fr/webapps/mpp/clickthru.*', PromoPage)
     account = URL('https://www.paypal.com/businessexp/money', AccountPage)
-    pro_history = URL('https://\w+.paypal.com/webapps/business/activity\?.*',
-                      'https://\w+.paypal.com/businessexp/summary',
+    pro_history = URL('https://\w+.paypal.com/businessexp/transactions/activity\?.*',
                       ProHistoryPage)
     part_history = URL('https://\w+.paypal.com/myaccount/activity/.*', PartHistoryPage)
+    old_website = URL('https://paypalmanager.paypal.com/login.do', OldWebsitePage)
 
     TIMEOUT = 180.0
 
-    BEGINNING = datetime.date.today() - relativedelta(months=24)
-    account_type = None
 
-    def find_account_type(self):
-        try:
-            self.location('https://www.paypal.com/myaccount/')
-            self.account_type = "perso"
-        except:
-            self.account_type = "pro"
+    def __init__(self, *args, **kwargs):
+        self.BEGINNING = datetime.date.today() - relativedelta(months=24)
+        self.account_type = None
+        self.account_currencies = list()
+        super(Paypal, self).__init__(*args, **kwargs)
 
     def do_login(self):
         assert isinstance(self.username, basestring)
@@ -80,23 +84,35 @@ class Paypal(LoginBrowser):
             self.location('/signin/')
 
         response = self.open(self.page.get_script_url())
-        token, csrf = self.page.get_token_and_csrf(response.text)
+        token, csrf, key, value, sessionID = self.page.get_token_and_csrf(response.text)
         data = {}
         data['ads_token_js'] = token
         data['_csrf'] = csrf
+        data['_sessionID'] = sessionID
+        data[key] = value
         data = urllib.urlencode(data)
         self.open('/auth/verifychallenge', data=data)
         res = self.page.login(self.username, self.password)
 
-        if 'LoginFailed' in res.content or 'Sorry, we can\'t log you in' in res.content or self.login.is_here() or self.error.is_here():
+        if 'LoginFailed' in res.content or 'Sorry, we can\'t log you in' in res.content or self.error.is_here():
             raise BrowserIncorrectPassword()
 
-        self.find_account_type()
+        self.location('/')
+        if self.old_website.is_here():
+            self.location('https://www.paypal.com/businessexp/summary')
+        if self.login.is_here() or self.landing.is_here():
+            raise BrowserIncorrectPassword(u'Impossible de se connecter, le compte nécessite une étape de vérification supplémentaire.')
+        self.detect_account_type()
+
+    @need_login
+    def detect_account_type(self):
+        self.page.detect_account_type()
 
     @need_login
     def get_accounts(self):
+        if self.account_type is None:
+            self.detect_account_type()
         self.account.stay_or_go()
-
         return self.page.get_accounts()
 
     @need_login
@@ -138,9 +154,17 @@ class Paypal(LoginBrowser):
                 step_max = 180
 
             def fetch_fn(start, end):
-                if self.download_history(start, end):
-                    return self.page.iter_transactions(account)
-                return iter([])
+                p = self.download_history(start, end)
+                transactions = []
+                # Iter on each page
+                while self.location("https://www.paypal.com/businessexp/transactions/activity", \
+                                    params=p).page.transaction_left():
+                    p['next_page_token'] = self.page.get_next_page_token()
+                    for t in self.page.iter_transactions(account):
+                        transactions.append(t)
+                    if not p['next_page_token']:
+                        break
+                return transactions if len(transactions) else iter([])
 
             assert step_max <= 365*2  # PayPal limitations as of 2014-06-16
             try:
@@ -181,28 +205,24 @@ class Paypal(LoginBrowser):
         However, it is not normalized, and sometimes the download is refused
         and sent later by mail.
         """
-        s = start.strftime('%d/%m/%Y')
-        e = end.strftime('%d/%m/%Y')
-        # Settings a big magic number so we hope to get all transactions for the period
-        LIMIT = '9999'
-        self.location('https://www.paypal.com/webapps/business/activity?fromdate=' + s + '&todate=' + e + '&transactiontype=ALL_TRANSACTIONS&currency=ALL_TRANSACTIONS_CURRENCY&limit=' + LIMIT + '&archive=true', headers={'X-Requested-With': 'XMLHttpRequest'})
-        return self.page.transaction_left()
+        params = {'transactiontype': "ALL_TRANSACTIONS",
+                  'currency': "ALL_TRANSACTIONS_CURRENCY",
+                  'limit': "",
+                  'archive': "ACTIVE_TRANSACTIONS",
+                  'fromdate_year': start.year,
+                  'fromdate_month': start.month-1, # Months are from 0 to 11.
+                  'fromdate_day': start.day,
+                  'todate_year': end.year,
+                  'todate_month': end.month-1,
+                  'todate_day': end.day
+                 }
+        return params
 
     def transfer(self, from_id, to_id, amount, reason=None):
         raise NotImplementedError()
 
     def convert_amount(self, account, trans, link):
-        self.location(link)
+        self.location('%s%s' % (self.BASEURL, link.replace(self.BASEURL, '')))
         if self.history_details.is_here():
             cc = self.page.get_converted_amount(account)
             return cc
-
-    def check_for_payback(self, trans, link):
-        self.location(link)
-        if self.history_details.is_here():
-            url = self.page.get_payback_url()
-            if url:
-                self.location(url)
-                if self.history_payback.is_here():
-                    return self.page.get_payback()
-        return None, None, None, None
