@@ -19,7 +19,8 @@
 
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import Value
-from weboob.capabilities.pricecomparison import CapPriceComparison, Price, Product
+from weboob.capabilities.pricecomparison import CapPriceComparison, Price, Product, PriceNotFound
+from weboob.capabilities.base import find_object
 
 from .browser import PrixCarburantsBrowser
 
@@ -31,39 +32,31 @@ class PrixCarburantsModule(Module, CapPriceComparison):
     NAME = 'prixcarburants'
     MAINTAINER = u'Romain Bignon'
     EMAIL = 'romain@weboob.org'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = 'French governement website to compare fuel prices'
     LICENSE = 'AGPLv3+'
     BROWSER = PrixCarburantsBrowser
     CONFIG = BackendConfig(Value('zipcode', label='Zipcode', regexp='\d+'))
 
     def search_products(self, pattern=None):
-        with self.browser:
-            for product in self.browser.iter_products():
-                if pattern is None or pattern.lower() in product.name.lower():
-                    yield product
+        for product in self.browser.iter_products():
+            if pattern is None or pattern.lower() in product.name.lower():
+                yield product
 
-    def iter_prices(self, product):
-        with self.browser:
-            return self.browser.iter_prices(self.config['zipcode'].get(), product)
+    def iter_prices(self, products):
+        product = [product for product in products if product.backend == self.name]
+        if product:
+            return self.browser.iter_prices(self.config['zipcode'].get(), product[0])
 
-    def get_price(self, id):
-        with self.browser:
-            if isinstance(id, Price):
-                price = id
-            else:
-                p_id, s_id = id.split('.', 2)
-                product = Product(p_id)
-                for price in self.iter_prices(product):
-                    if price.id == id:
-                        break
-                else:
-                    return None
+    def get_price(self, id, price=None):
+        product = Product(id.split('.')[0])
+        product.backend = self.name
 
-            price.shop.info = self.browser.get_shop_info(price.id.split('.', 2)[-1])
-            return price
+        price = find_object(self.iter_prices([product]), id=id, error=PriceNotFound)
+        price.shop.info = self.browser.get_shop_info(price.id.split('.', 2)[-1])
+        return price
 
     def fill_price(self, price, fields):
-        return self.get_price(price)
+        return self.get_price(price.id, price)
 
     OBJECTS = {Price: fill_price, }
