@@ -19,14 +19,22 @@
 
 
 from weboob.tools.test import BackendTest
+from weboob.tools.value import Value
+import itertools
 
 
 class PrixCarburantsTest(BackendTest):
     MODULE = 'prixcarburants'
 
+    def setUp(self):
+        if not self.is_backend_configured():
+            self.backend.config['Zipcode'] = Value(value='59000')
+
     def test_prixcarburants(self):
         products = list(self.backend.search_products('gpl'))
         self.assertTrue(len(products) == 1)
 
-        prices = list(self.backend.iter_prices(products[0]))
+        product = products[0]
+        product.backend = self.backend.name
+        prices = list(itertools.islice(self.backend.iter_prices([product]), 0, 20))
         self.backend.fillobj(prices[0])
