@@ -27,7 +27,7 @@
 import datetime
 from weboob.capabilities.base import UserError, StringField
 from weboob.capabilities.video import CapVideo, BaseVideo
-from weboob.capabilities.image import BaseImage
+from weboob.capabilities.image import Thumbnail
 from weboob.tools.backend import Module
 from weboob.tools.misc import to_unicode
 
@@ -43,7 +43,7 @@ class QuviModule(Module, CapVideo):
     MAINTAINER = u'Vincent A'
     EMAIL = 'dev@indigo.re'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.1'
+    VERSION = '1.2'
 
     BROWSER = None
 
@@ -70,7 +70,7 @@ class QuviModule(Module, CapVideo):
         if duration:
             video.duration = datetime.timedelta(milliseconds=duration)
         if info.get('thumbnail'):
-            video.thumbnail = BaseImage(info.get('thumbnail'))
+            video.thumbnail = Thumbnail(info.get('thumbnail'))
             video.thumbnail.url = video.thumbnail.id
         return video
 
