@@ -26,28 +26,55 @@ __all__ = ['RadioFranceBrowser']
 class RadioFranceBrowser(PagesBrowser):
     json_page = URL('sites/default/files/(?P<json_url>.*).json',
                     'player-json/reecoute/(?P<json_url_fip>.*)',
-                    'station/(?P<fbplayer>.*)', JsonPage)
+                    'station/(?P<fbplayer>.*)',
+                    'programmes\?xmlHttpRequest=1',
+                    'autocomplete/emissions.json',
+                    JsonPage)
     podcast_page = URL('podcast09/rss_(?P<podcast_id>.*)\.xml', PodcastPage)
     radio_page = URL('(?P<page>.*)', RadioPage)
 
     def get_radio_url(self, radio, player):
-        self.BASEURL = 'http://www.%s.fr/' % radio
+        self.fill_base_url(radio)
+
         if radio == 'francebleu':
             return self.json_page.go(fbplayer=player).get_fburl()
 
         return self.radio_page.go(page=player).get_url()
 
+    def fill_base_url(self, radio):
+        if radio in ['franceinter', 'francebleu', 'franceculture']:
+            self.BASEURL = 'https://www.%s.fr/' % radio
+        else:
+            self.BASEURL = 'http://www.%s.fr/' % radio
+
     def get_current(self, radio, url):
-        self.BASEURL = 'http://www.%s.fr/' % radio
+        self.fill_base_url(radio)
+
         if radio == 'francebleu':
             return self.radio_page.go(page=url).get_current()
 
+        if radio in ['franceculture', 'franceinter']:
+            return self.json_page.go().get_culture_inter_current()
+
+        if radio == 'francetvinfo':
+            return u'', u''
+
         return self.json_page.go(json_url=url).get_current()
 
     def get_selection(self, radio_url, json_url, radio_id):
         self.BASEURL = 'http://www.%s.fr/' % radio_url
         if radio_id == 'fipradio':
             return self.json_page.go(json_url_fip=json_url).get_selection(radio_id=radio_id)
+        elif radio_id == 'franceculture':
+            self.fill_base_url(radio_id)
+            return self.radio_page.go(page='').get_france_culture_selection(radio_id=radio_id)
+        elif radio_id == 'francetvinfo':
+            self.fill_base_url(radio_id)
+            selection_list = self.radio_page.go(page=json_url).get_francetvinfo_selection_list()
+            sel = []
+            for item in selection_list:
+                sel.append(self.radio_page.go(page=item).get_francetvinfo_selection())
+            return sel
 
         return self.json_page.go(json_url=json_url).get_selection(radio_id=radio_id)
 
@@ -63,12 +90,13 @@ class RadioFranceBrowser(PagesBrowser):
                 yield item
 
     def get_podcast_emissions(self, radio_url, podcast_url, split_path):
-        self.BASEURL = 'http://www.%s.fr/' % radio_url
+        self.fill_base_url(radio_url)
         if split_path[0] == 'franceinter':
             return self.radio_page.go(page=podcast_url).get_france_inter_podcast_emissions(split_path=split_path)
         elif split_path[0] == 'franceculture':
-            return self.radio_page.go(page=podcast_url).get_france_culture_podcast_emissions(split_path=split_path)
-        elif split_path[0] == 'franceinfo':
+            self.location('%s%s' % (self.BASEURL, podcast_url))
+            return self.page.get_france_culture_podcast_emissions(split_path=split_path)
+        elif split_path[0] == 'francetvinfo':
             return self.radio_page.go(page=podcast_url).get_france_info_podcast_emissions(split_path=split_path)
         elif split_path[0] == 'francemusique':
             return self.radio_page.go(page=podcast_url).get_france_musique_podcast_emissions(split_path=split_path)
@@ -80,5 +108,9 @@ class RadioFranceBrowser(PagesBrowser):
         return self.podcast_page.go(podcast_id=podcast_id).iter_podcasts()
 
     def get_france_culture_podcasts_url(self, url):
-        self.BASEURL = 'http://www.franceculture.fr/podcast/'
-        return self.radio_page.go(page=url).get_france_culture_podcasts_url()
+        self.BASEURL = 'https://www.franceculture.fr/'
+        return self.radio_page.go(page='emissions/%s' % url).get_france_culture_podcasts_url()
+
+    def get_francetvinfo_podcasts_url(self, url):
+        self.BASEURL = 'http://www.francetvinfo.fr/'
+        return self.radio_page.go(page='replay-radio/%s' % url).get_francetvinfo_podcasts_url()
