@@ -39,44 +39,43 @@ class RadioFranceModule(Module, CapRadio, CapCollection, CapAudio):
     NAME = 'radiofrance'
     MAINTAINER = u'Laurent Bachelier'
     EMAIL = 'laurent@bachelier.name'
-    VERSION = '1.1'
+    VERSION = '1.2'
     DESCRIPTION = u'Radios of Radio France: Inter, Info, Bleu, Culture, Musique, FIP, Le Mouv\''
     LICENSE = 'AGPLv3+'
     BROWSER = RadioFranceBrowser
 
     _RADIOS = {
         'franceinter': {u'title': u'France Inter',
-                        u'player': u'player',
-                        u'live': u'lecteur_commun_json/timeline',
-                        u'podcast': u'podcasts',
-                        u'selection': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.now().replace(hour=13, minute=0, second=0).timetuple()))},
+                        u'player': u'',
+                        u'live': u'programmes?xmlHttpRequest=1',
+                        u'podcast': u'podcasts'},
         'franceculture': {u'title': u'France Culture',
-                          u'player': u'player',
-                          u'live': u'lecteur_commun_json/timeline',
-                          u'podcast': u'podcasts',
-                          u'selection': u'lecteur_commun_json/selection'},
-        'franceinfo': {u'title': u'France Info',
-                       u'player': u'player',
-                       u'live': u'lecteur_commun_json/timeline',
-                       u'podcast': u'programmes-chroniques/podcasts',
-                       u'selection': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.now().replace(hour=13, minute=0, second=0).timetuple()))},
+                          u'player': u'',
+                          u'live': u'programmes?xmlHttpRequest=1',
+                          u'podcast': u'programmes?xmlHttpRequest=1',
+                          u'selection': u''},
+        'francetvinfo': {u'title': u'France Info',
+                         u'player': u'en-direct/radio.html',
+                         u'live': u'',
+                         u'podcast': u'replay-radio',
+                         u'selection': u'en-direct/radio.html'},
         'fbidf': {u'title': u'France Bleu Île-de-France (Paris)',
                   u'player': u'107-1',
                   u'live': u'grid/107-1'},
         'fipradio': {u'title': u'FIP',
                      u'player': u'player',
                      u'live': 'import_si/si_titre_antenne/FIP_player_current',
-                     u'selection': u'%s' % int(time.mktime(datetime.now().replace(hour=12, minute=0, second=0).timetuple()))},
+                     u'selection': u'%s' % int(time.mktime(datetime.utcnow().replace(hour=12, minute=0, second=0).timetuple()))},
         'francemusique': {u'title': u'France Musique',
                           u'player': u'player',
-                          u'live': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.now().replace(hour=13, minute=0, second=0).timetuple())),
+                          u'live': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.utcnow().replace(hour=14, minute=0, second=0).timetuple())),
                           u'podcast': u'emissions',
-                          u'selection': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.now().replace(hour=13, minute=0, second=0).timetuple()))},
+                          u'selection': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.utcnow().replace(hour=14, minute=0, second=0).timetuple()))},
         'mouv': {u'title': u'Le Mouv\'',
                  u'player': u'player',
                  u'live': u'lecteur_commun_json/timeline',
                  u'podcast': u'podcasts',
-                 u'selection': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.now().replace(hour=13, minute=0, second=0).timetuple()))},
+                 u'selection': u'lecteur_commun_json/reecoute-%s' % int(time.mktime(datetime.utcnow().replace(hour=14, minute=0, second=0).timetuple()))},
         'fbalsace': {u'title': u'France Bleu Alsace (Strasbourg)',
                      u'player': u'alsace',
                      u'live': u'grid/alsace'},
@@ -89,9 +88,6 @@ class RadioFranceModule(Module, CapRadio, CapCollection, CapAudio):
         'fbazur': {u'title': u'France Bleu Azur (Nice)',
                    u'player': u'azur',
                    u'live': u'grid/azur'},
-        'fbbassenormandie': {u'title': u'France Bleu Basse Normandie (Caen)',
-                             u'player': u'basse-normandie',
-                             u'live': u'grid/basse-normandie'},
         'fbbearn': {u'title': u'France Bleu Bearn (Pau)',
                     u'player': u'bearn',
                     u'live': u'grid/bearn'},
@@ -134,9 +130,6 @@ class RadioFranceModule(Module, CapRadio, CapCollection, CapAudio):
         'fbgironde': {u'title': u'France Bleu Gironde (Bordeaux)',
                       u'player': u'gironde',
                       u'live': u'grid/gironde'},
-        'fbhautenormandie': {u'title': u'France Bleu Haute Normandie (Rouen)',
-                             u'player': u'haute-normandie',
-                             u'live': u'grid/haute-normandie'},
         'fbherault': {u'title': u'France Bleu Hérault (Montpellier)',
                       u'player': u'herault',
                       u'live': u'grid/herault'},
@@ -164,6 +157,12 @@ class RadioFranceModule(Module, CapRadio, CapCollection, CapAudio):
         'fbnord': {u'title': u'France Bleu Nord (Lille)',
                    u'player': u'nord',
                    u'live': u'grid/nord'},
+        'fbcaen': {u'title': u'France Bleu Normandie (Calvados - Orne)',
+                   u'player': u'normandie-caen',
+                   u'live': u'grid/normandie-caen'},
+        'fbrouen': {u'title': u'France Bleu Normandie (Seine-Maritime - Eure)',
+                    u'player': u'normandie-rouen',
+                    u'live': u'grid/normandie-rouen'},
         'fborleans': {u'title': u'France Bleu Orléans',
                       u'player': u'orleans',
                       u'live': u'grid/orleans'},
@@ -270,8 +269,11 @@ class RadioFranceModule(Module, CapRadio, CapCollection, CapAudio):
             podcasts_url = split_path[-1]
             if split_path[0] == 'franceculture':
                 podcasts_url = self.browser.get_france_culture_podcasts_url(split_path[-1])
-            for item in self.browser.get_podcasts(podcasts_url):
-                yield item
+            elif split_path[0] == 'francetvinfo':
+                podcasts_url = self.browser.get_francetvinfo_podcasts_url(split_path[-1])
+            if podcasts_url:
+                for item in self.browser.get_podcasts(podcasts_url):
+                    yield item
 
         else:
             raise CollectionNotFound(split_path)
@@ -284,7 +286,7 @@ class RadioFranceModule(Module, CapRadio, CapCollection, CapAudio):
                 stream.bitrate = 128
             else:
                 stream.bitrate = 32
-                url = url.replace('midfi128', 'lofi32')
+                url = url.replace('midfi', 'lofi')
 
             stream.format = u'mp3'
             stream.title = u'%s kbits/s' % (stream.bitrate)
