@@ -16,11 +16,10 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
-import urllib
 
 from weboob.browser import PagesBrowser, URL
 
-from .pages import SearchPage, AdvertPage
+from .pages import SearchPage, AdvertPage, LocationPage
 
 __all__ = ['RegionsjobBrowser']
 
@@ -29,15 +28,16 @@ class RegionsjobBrowser(PagesBrowser):
 
     search_page = URL('emplois/recherche.html\?.*', SearchPage)
     advert_page = URL('emplois/(?P<_id>.*)\.html', AdvertPage)
+    location_page = URL('search/getloc\?term=(?P<place>.*)', LocationPage)
 
     def __init__(self, website, *args, **kwargs):
         self.BASEURL = 'http://%s/' % website
         PagesBrowser.__init__(self, *args, **kwargs)
 
     def search_job(self, pattern='', fonction='', secteur='', contract='',
-                   experience='', qualification='', enterprise_type=''):
+                   experience='', qualification='', enterprise_type='', place=''):
 
-        params = {'k': urllib.quote_plus(pattern.encode('utf-8'))}
+        params = {'k': pattern.encode('utf-8')}
 
         if fonction:
             params['f'] = fonction
@@ -57,6 +57,10 @@ class RegionsjobBrowser(PagesBrowser):
         if enterprise_type:
             params['et'] = enterprise_type
 
+        if place:
+            location = self.location_page.go(place=place).get_location()
+            params['l'] = location
+
         return self.search_page.go(params=params).iter_job_adverts(domain=self.BASEURL)
 
     def get_job_advert(self, _id, advert):
