@@ -25,12 +25,14 @@ from weboob.browser.filters.html import XPath
 from weboob.browser.filters.standard import CleanText, CleanDecimal, DateTime
 from weboob.capabilities.base import NotAvailable
 from weboob.capabilities.housing import Housing, HousingPhoto, City
+from weboob.tools.capabilities.housing.housing import PricePerMeterFilter
 
 
 class CitiesPage(JsonPage):
     @method
     class iter_cities(DictElement):
-        item_xpath = '0/values'
+        item_xpath = '*/values'
+        ignore_duplicate = True
 
         class item(ItemElement):
             klass = City
@@ -50,7 +52,8 @@ class SeLogerItem(ItemElement):
     obj_date = DateTime(CleanText('dtFraicheur'))
     obj_cost = CleanDecimal('prix')
     obj_currency = CleanText('prixUnite')
-    obj_area = CleanDecimal('surface')
+    obj_area = CleanDecimal('surface', default=NotAvailable)
+    obj_price_per_meter = PricePerMeterFilter()
     obj_text = CleanText('descriptif')
     obj_location = CleanText('ville')
     obj_station = CleanText('proximite', default=NotAvailable)
@@ -64,7 +67,7 @@ class SearchResultsPage(XMLPage):
         item_xpath = "//annonce"
 
         def next_page(self):
-            page = CleanText('//pageSuivante', default=None)(self)
+            page = CleanText('//pageSuivante', default=None, replace=[('http://ws.seloger.com/', '')])(self)
             if page:
                 return page
 
@@ -72,8 +75,8 @@ class SearchResultsPage(XMLPage):
             def obj_photos(self):
                 photos = []
 
-                for photo in XPath('./photos/photo/stdurl')(self):
-                    photos.append(HousingPhoto(photo))
+                for photo in XPath('./photos/photo/stdUrl')(self):
+                    photos.append(HousingPhoto(CleanText('.')(photo)))
 
                 return photos
 
