@@ -16,6 +16,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
+import re
 
 from .calendar import SensCritiquenCalendarEvent
 
@@ -31,11 +32,11 @@ class Description(Filter):
     def filter(self, el):
         header = "//div[@class='pvi-hero-product']"
         section = "//section[@class='pvi-productDetails']"
-        return Format(u'%s %s\n\n%s%s\n\n',
-                      CleanText("%s/div[@class='d-rubric-inner']/h1" % header),
-                      CleanText("%s/div[@class='d-rubric-inner']/small" % header),
-                      Join(u'- ', "%s/ul[@class='pvi-product-specs']/li" % header, newline=True),
-                      Join(u'- ', "%s/ul/li" % section, newline=True, addBefore='- '))(el[0])
+        return Format(u'\n%s\n\n%s%s\n',
+                      CleanText("(%s/div[@class='d-rubric-inner']/h1)[1]" % header),
+                      Join(u'- ', "%s/ul/li" % section, newline=True, addBefore='- '),
+                      Join(u'- Avec ', "%s/div[@class='pvi-productDetails-workers']/a" % section,
+                           newline=True, addBefore='- Avec '))(el[0])
 
 
 class FormatDate(Filter):
@@ -49,10 +50,18 @@ class FormatDate(Filter):
 
 class Date(Filter):
     def filter(self, el):
-        spans_date = el[0].xpath("span[@class='d-date']")
+        str_time = el[0].xpath("time")[0].attrib['datetime'][:-6]
+        _time = datetime.strptime(str_time, '%H:%M:%S')
+
+        str_date = CleanText('.')(el[0])
         _date = date.today()
-        if len(spans_date) == 2:
-            day_number = int(spans_date[1].text)
+        m = re.search('\w* (\d\d?) .*', str_date)
+        if (('Demain' in str_date and str_time[0] != "0") or ('Ce soir' in str_date and str_time[0] == "0")):
+            _date += timedelta(days=1)
+        elif 'Demain' in str_date:
+            _date += timedelta(days=2)
+        elif m:
+            day_number = int(m.group(1))
             month = _date.month
             year = _date.year
             if day_number < _date.day:
@@ -60,10 +69,7 @@ class Date(Filter):
                 if _date.month == 12:
                     year = _date.year + 1
             _date = date(day=day_number, month=month, year=year)
-        elif spans_date[0].attrib['data-sc-day'] == 'Demain':
-            _date += timedelta(days=1)
-        str_time = el[0].xpath("time")[0].attrib['datetime'][:-6]
-        _time = datetime.strptime(str_time, '%H:%M:%S')
+
         return datetime.combine(_date, _time.time())
 
 
@@ -95,7 +101,7 @@ class FilmsPage(HTMLPage):
                     return Format(u'%s#%s#%s',
                                   Regexp(Link('.'), '/film/(.*)'),
                                   FormatDate("%Y%m%d%H%M",
-                                             Date('div/div[@class="elgr-data-diffusion"]')),
+                                             Date('div[@class="elgr-guide-details"]/div[@class="elgr-data-diffusion"]')),
                                   CleanText('./div/span[@class="d-offset"]',
                                             replace=[(' ', '-')]))(self) == self.env['_id']
                 return True
