@@ -40,7 +40,7 @@ class SueurDeMetalModule(Module, CapCalendarEvent):
     MAINTAINER = u'Vincent A'
     EMAIL = 'dev@indigo.re'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.1'
+    VERSION = '1.2'
 
     BROWSER = SueurDeMetalBrowser
 
@@ -124,7 +124,9 @@ class SueurDeMetalModule(Module, CapCalendarEvent):
 
     def fill_concert(self, obj, fields):
         if set(fields) & set(('price', 'location', 'description')):
-            return self.get_event(obj.id)
+            new_obj = self.get_event(obj.id)
+            for field in fields:
+                setattr(obj, field, getattr(new_obj, field))
         return obj
 
     OBJECTS = {Concert: fill_concert}
