@@ -72,7 +72,7 @@ class TinderModule(Module, CapMessages, CapMessagesPost, CapDating):
     MAINTAINER = u'Roger Philibert'
     EMAIL = 'roger.philibert@gmail.com'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.1'
+    VERSION = '1.2'
     CONFIG = BackendConfig(Value('username',                label='Facebook email'),
                            ValueBackendPassword('password', label='Facebook password'))
 
@@ -81,7 +81,7 @@ class TinderModule(Module, CapMessages, CapMessagesPost, CapDating):
               }
 
     def create_default_browser(self):
-        facebook = FacebookBrowser()
+        facebook = self.create_browser(klass=FacebookBrowser)
         facebook.login(self.config['username'].get(),
                        self.config['password'].get())
         return self.create_browser(facebook)
