@@ -94,11 +94,11 @@ class ThreadPage(HTMLPage):
 
         obj_id = Format('%s#%s', Env('user'), Env('_id'))
         obj_title = Format('%s \n\t %s',
-                           CleanText('//div[@class="permalink-inner permalink-tweet-container"]/div/div/div/a',
+                           CleanText('//div[has-class("permalink-inner permalink-tweet-container")]/div/div/div/a',
                                      replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')]),
-                           CleanText('//div[@class="permalink-inner permalink-tweet-container"]/div/p',
+                           CleanText('//div[has-class("permalink-inner permalink-tweet-container")]/div/div/p',
                                      replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')]))
-        obj_date = DateTime(Regexp(CleanText('//div[@class="permalink-inner permalink-tweet-container"]/div/div/div[@class="client-and-actions"]/span/span'),
+        obj_date = DateTime(Regexp(CleanText('//div[has-class("permalink-inner permalink-tweet-container")]/div/div/div[@class="client-and-actions"]/span/span'),
                                    '(\d+:\d+).+- (.+\d{4})',
                                    '\\2 \\1'), translations=DATE_TRANSLATE_FR)
 
@@ -111,9 +111,11 @@ class ThreadPage(HTMLPage):
 
             obj_id = Regexp(Link('./div/div/small/a', default=''), '/.+/status/(.+)', default=None)
 
-            obj_title = Regexp(CleanText('./div/p', replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')]),
+            obj_title = Regexp(CleanText('./div[@class="content"]/div/p[has-class("tweet-text")]',
+                                         replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')]),
                                '(.{50}|.+).+')
-            obj_content = CleanText('./div/p', replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')])
+            obj_content = CleanText('./div[@class="content"]/div/p[has-class("tweet-text")]',
+                                    replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')])
             obj_sender = Regexp(Link('./div/div/small/a', default=''), '/(.+)/status/.+', default=None)
             obj_date = DatetimeFromTimestamp(Attr('./div/div[@class="stream-item-header"]/small/a/span | ./div/div[@class="ProfileTweet-authorDetails"]/span/a/span', 'data-time'))
 
@@ -157,7 +159,7 @@ class TimelineListElement(ListElement):
         obj_title = Format('%s \n\t %s',
                            CleanText('./div/div[@class="stream-item-header"]/a|./div/div[@class="ProfileTweet-authorDetails"]/a',
                                      replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')]),
-                           CleanText('./div/p',
+                           CleanText('./div/div/p',
                                      replace=[('@ ', '@'), ('# ', '#'), ('http:// ', 'http://')]))
         obj_date = DatetimeFromTimestamp(Attr('./div/div[@class="stream-item-header"]/small/a/span | ./div/div[@class="ProfileTweet-authorDetails"]/span/a/span', 'data-time'))
 
