@@ -23,6 +23,3 @@ from weboob.tools.test import BackendTest
 
 class UpsTest(BackendTest):
     MODULE = 'ups'
-
-    def test_ups(self):
-        raise NotImplementedError()
