@@ -19,13 +19,13 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from weboob.capabilities.video import BaseVideo
-from weboob.capabilities.image import BaseImage
+from weboob.capabilities.image import Thumbnail
 from weboob.capabilities.collection import Collection
 
 from weboob.exceptions import ParseError
-from weboob.browser.elements import ItemElement, ListElement, method
+from weboob.browser.elements import ItemElement, ListElement, method, DictElement
 from weboob.browser.pages import HTMLPage, pagination, JsonPage
-from weboob.browser.filters.standard import Regexp, Env, CleanText, DateTime, Duration, Field
+from weboob.browser.filters.standard import Regexp, Env, CleanText, DateTime, Duration, Field, BrowserURL
 from weboob.browser.filters.html import Attr, Link, CleanHTML, XPath
 from weboob.browser.filters.json import Dict
 
@@ -36,22 +36,68 @@ class VimeoDuration(Duration):
     _regexp = re.compile(r'PT(?P<hh>\d+)H(?P<mm>\d+)M(?P<ss>\d+)S')
 
 
-class SearchPage(HTMLPage):
+class ListPage(HTMLPage):
+    def get_token(self):
+        return Regexp(CleanText('//script'), '"jwt":"(.*)","url"', default=None)(self.doc)
+
     @pagination
     @method
     class iter_videos(ListElement):
         item_xpath = '//div[@id="browse_content"]/ol/li'
+        next_page = Link(u'//a[text()="Next"]')
 
+        class item(ItemElement):
+            klass = BaseVideo
+            obj_id = Regexp(Attr('.', 'id'), 'clip_(.*)')
+            obj_title = Attr('./a', 'title')
+
+            def obj_thumbnail(self):
+                thumbnail = Thumbnail(self.xpath('./a/img')[0].attrib['src'])
+                thumbnail.url = thumbnail.id
+                return thumbnail
+
+
+class APIPage(JsonPage):
+    @pagination
+    @method
+    class iter_videos(DictElement):
+        item_xpath = 'data'
+
+        def parse(self, el):
+            self.env['next_page'] = Regexp(Dict('paging/next'), 'page=(\d*)', default=None)(el)
+
+        def next_page(self):
+            if Env('next_page')(self) is not None:
+                return BrowserURL('api_page', page=int(Env('next_page')(self)), category=Env('category'))(self)
+
+        class item(ItemElement):
+            klass = BaseVideo
+
+            obj_id = Regexp(Dict('clip/uri'), '/videos/(.*)')
+            obj_title = Dict('clip/name')
+
+            def obj_thumbnail(self):
+                thumbnail = Thumbnail(Dict('clip/pictures/sizes/0/link')(self))
+                thumbnail.url = thumbnail.id
+                return thumbnail
+
+
+class SearchPage(HTMLPage):
+    @pagination
+    @method
+    class iter_videos(ListElement):
+        item_xpath = '//ul[@class="small-block-grid-3"]/li/div[has-class("clip_thumbnail")]'
+        ignore_duplicate = True
         next_page = Link(u'//a[text()="Next"]')
 
         class item(ItemElement):
             klass = BaseVideo
 
-            obj_id = Regexp(Attr('.', 'id'), 'clip_(.*)')
-            obj_title = Attr('./a', 'title')
+            obj_id = Attr('.', 'data-clip-id')
+            obj_title = Attr('./a/span', 'title')
 
             def obj_thumbnail(self):
-                thumbnail = BaseImage(self.xpath('./a/img')[0].attrib['src'])
+                thumbnail = Thumbnail(self.xpath('./a/div/img')[0].attrib['src'])
                 thumbnail.url = thumbnail.id
                 return thumbnail
 
@@ -68,9 +114,9 @@ class VideoPage(HTMLPage):
         klass = BaseVideo
 
         obj_id = Env('_id')
-        obj_title = CleanText(Dict('name'))
+        obj_title = CleanText(CleanHTML(Dict('name')))
         obj_description = CleanHTML(Dict('description'))
-        obj_date = DateTime(Dict('datePublished'))
+        obj_date = DateTime(Dict('uploadDate'))
         obj_duration = VimeoDuration(Dict('duration'))
         obj_author = CleanText(Dict('author/name'))
 
@@ -79,7 +125,7 @@ class VideoPage(HTMLPage):
             return _sfw != "True"
 
         def obj_thumbnail(self):
-            thumbnail = BaseImage(Dict('thumbnailUrl')(self.el))
+            thumbnail = Thumbnail(Dict('thumbnailUrl')(self.el))
             thumbnail.url = thumbnail.id
             return thumbnail
 
@@ -90,22 +136,34 @@ class VideoJsonPage(JsonPage):
         klass = BaseVideo
 
         def obj_url(self):
-            quality = 'sd'
-            codec = None
             data = self.el
-            if 'vp6' in data['request']['files']:
-                codec = 'vp6'
-            if 'vp8' in data['request']['files']:
-                codec = 'vp8'
-            if 'h264' in data['request']['files']:
-                codec = 'h264'
-            if not codec:
-                raise ParseError('Unable to detect available codec for id: %r' % int(Field('id')(self)))
-            if 'hd' in data['request']['files'][codec]:
-                quality = 'hd'
-            return data['request']['files'][codec][quality]['url']
 
-        obj_ext = Regexp(Field('url'), '.*\.(.*?)\?.*')
+            if not data['request']['files']:
+                raise ParseError('Unable to detect any stream method for id: %r (available: %s)'
+                                 % (int(Field('id')(self)),
+                                    data['request']['files'].keys()))
+
+            # Choosen method is not available, we choose an other one
+            method = self.obj._method
+            if method not in data['request']['files']:
+                method = data['request']['files'].keys()[0]
+
+            streams = data['request']['files'][method]
+            if not streams:
+                raise ValueError('There is no url available for id: %r' % (int(Field('id')(self))))
+
+            # stream is single for hls, just return the url
+            stream = streams['url'] if method == 'hls' else None
+
+            # ...but a list for progressive
+            # we assume the list is sorted by quality with best first
+            if not stream:
+                quality = self.obj._quality
+                stream = streams[quality]['url'] if quality < len(streams) else streams[0]['url']
+
+            return stream
+
+        obj_ext = Regexp(Field('url'), '.*\.(.*)\?.*$', '\\1')
 
 
 class CategoriesPage(HTMLPage):
