@@ -21,12 +21,14 @@ from weboob.capabilities.bank import Account, Transaction
 from weboob.tools.capabilities.bank.transactions import \
     AmericanTransaction as AmTr
 from weboob.browser.pages import HTMLPage, LoggedPage, RawPage
-from urllib import unquote
 from decimal import Decimal
 from requests.cookies import morsel_to_cookie
 from .parsers import StatementParser, clean_label
+from time import sleep
 import itertools
+import json
 import re
+import os
 import datetime
 import Cookie
 
@@ -59,7 +61,49 @@ class LoggedInPage(HTMLPage):
     @property
     def logged(self):
         return bool(self.doc.xpath(u'//a[text()="Sign Off"]')) \
-            or bool(self.doc.xpath(u'//title[text()="Splash Page"]'))
+            or bool(self.doc.xpath(u'//title[text()="Splash Page"]')) \
+            or bool(self.doc.xpath(u'//title[contains(text(),'
+                                   u'"Advanced Access Required")]'))
+
+
+class CodeRequestPage(LoggedInPage):
+    is_here = u'contains(//label/text(),"Send Code to")'
+
+    def request_code(self):
+        phone = self.browser.page.doc.xpath(
+            '//select[@name="telephone"]/option[contains(text(),"%s")]/@value'
+            % self.browser.phone_last4)[0]
+        form = self.get_form(name='otp')
+        form['telephone'] = [phone]
+        form['deliveryMode'] = ['sms']
+        form['sendcode'] = ['Request Code']
+        del form['cancelBtn']
+        del form['sendcode2']
+        return form.submit()
+
+
+class CodeSubmitPage(LoggedInPage):
+    is_here = u'contains(//title/text(),"Enter and Submit Advanced Access Code")'
+
+    def submit_code(self):
+        self.browser.logger.warning(
+            'The code has been sent to the phone number ending with %s. '
+            'Please write this code into the file %s'
+            % (self.browser.phone_last4, self.browser.code_file))
+        while True:
+            try:
+                with open(self.browser.code_file) as f:
+                    code = f.read().strip()
+                break
+            except IOError:
+                sleep(1)
+        os.remove(self.browser.code_file)
+        self.browser.logger.info('The code %s has been successfully read'%code)
+        form = self.get_form(name='otp')
+        form['passcode'] = [code]
+        del form['cancelBtn']
+        del form['btnSubmit']
+        return form.submit()
 
 
 class SummaryPage(LoggedInPage):
@@ -69,13 +113,13 @@ class SummaryPage(LoggedInPage):
         href = self.doc.xpath(u'//a[text()="Account Activity"]/@href')[0]
         self.browser.location(href)
 
-    def to_statements(self):
+    def to_documents(self):
         href = self.doc.xpath('//a[text()="Statements & Documents"]'
                               '/@href')[0]
         self.browser.location(href)
 
 
-class AccountPage(LoggedInPage):
+class AccountPage(object):
     def account_id(self, name=None):
         if name:
             return name[-4:] # Last 4 digits of "BLAH XXXXXXX1234"
@@ -83,7 +127,7 @@ class AccountPage(LoggedInPage):
             return self.account_id(self.account_name())
 
 
-class ActivityPage(AccountPage):
+class ActivityPage(AccountPage, LoggedInPage):
     def is_here(self):
         return bool(self.doc.xpath(
             u'contains(//title/text(),"Account Activity")'))
@@ -182,20 +226,21 @@ class ActivityCashPage(ActivityPage):
             u'//td[@headers="currentPostedBalance"]/span/text()')[0]
 
     def since_last_statement(self):
-        form = self.get_form(xpath='//form[@id="ddaShowForm"]')
-        form['showTabDDACommand.transactionTypeFilterValue'] = [
-            u'All Transactions']
-        form['showTabDDACommand.timeFilterValue'] = ['8']
-        form.submit()
-        return True
+        if not self.doc.xpath(u'//p[@id="noactivitymessage"]'):
+            form = self.get_form(xpath='//form[@id="ddaShowForm"]')
+            form['showTabDDACommand.transactionTypeFilterValue'] = [
+                u'All Transactions']
+            form['showTabDDACommand.timeFilterValue'] = ['8']
+            form.submit()
+            return True
 
     def iter_transactions(self):
         for row in self.doc.xpath('//tr/th[@headers='
                                   '"postedHeader dateHeader"]/..'):
             date = row.xpath('th[@headers="postedHeader '
                              'dateHeader"]/text()')[0]
-            desc = row.xpath('td[@headers="postedHeader '
-                             'descriptionHeader"]/span/text()')[0]
+            desc = row.xpath('td[@headers="postedHeader descriptionHeader"]'
+                             '//span[@class="OneLinkNoTx"]/text()')[0]
             deposit = row.xpath('td[@headers="postedHeader '
                                 'depositsConsumerHeader"]/span/text()')[0]
             withdraw = row.xpath('td[@headers="postedHeader '
@@ -321,49 +366,96 @@ class ActivityCardPage(ActivityPage):
         return False
 
 
-class StatementsPage(AccountPage):
-    is_here = u'contains(//title/text(),"Statements")'
+class DocumentsPage(LoggedInPage):
+    HEADER_XPATH = u'//h1[contains(text(),"Statements and Documents")]'
+    LINK_XPATH = u'//a[@data-async-load-template="stmtdisc.html"]' \
+                 u'/@data-async-load-url'
+
+    def is_here(self):
+        return self.doc.xpath(self.HEADER_XPATH) \
+           and self.doc.xpath(self.LINK_XPATH)
+
+    def to_statements(self):
+        url = self.doc.xpath(self.LINK_XPATH)[0]
+        self.browser.location(url)
+
+
+class StatementsEmbeddedPage(LoggedInPage):
+    HEADER_XPATH = u'//h1[contains(text(),"Statements and Documents")]'
+    SCRIPT_XPATH = '//script[contains(text(),"stmtdisc.html")]/text()'
+
+    def is_here(self):
+        return self.doc.xpath(self.HEADER_XPATH) \
+           and self.doc.xpath(self.SCRIPT_XPATH)
+
+    def get_embedded_data(self):
+        scr = self.doc.xpath(self.SCRIPT_XPATH)[0]
+        data = json.loads('\n'.join(scr.split('\n')[2:-2]).replace(
+            "'appendTo'",'"appendTo"'))
+        return json.loads(data['data'])
+
+    def parser(self):
+        return StatementsPageParser(self.get_embedded_data(), self.browser)
+
+
+class WfJsonPage(LoggedPage, RawPage):
+    def __init__(self, *args, **kwArgs):
+        RawPage.__init__(self, *args, **kwArgs)
+        clean = self.doc.replace('"/*WellFargoProprietary%','') \
+            .replace('%WellFargoProprietary*/"','').decode('string_escape')
+        self.doc = json.loads(clean)
+
+
+class StatementsPage(WfJsonPage):
+    def parser(self):
+        return StatementsPageParser(self.doc, self.browser)
+
+
+class StatementsPageParser(AccountPage):
+    def __init__(self, doc, browser):
+        self.doc = doc
+        self.browser = browser
 
     def account_name(self):
-        return self.doc.xpath(
-            u'//select[@name="selectedAccountKey"]'
-            u'/option[@selected="selected"]/text()')[0]
-
-    def account_uid(self, id_):
-        return self.doc.xpath(
-            u'//select[@name="selectedAccountKey"]'
-            u'/option[contains(text(),"%s")]/@value' % id_)[0]
+        for account in self.accounts():
+            if account['selected']:
+                return account['accountDisplayName']
 
     def to_account(self, id_):
-        form = self.get_form(xpath='//form[@id="statementsAndDocumentsModel"]')
-        form['selectedAccountKey'] = [self.account_uid(id_)]
-        form.submit()
+        for account in self.accounts():
+            if account['accountDisplayName'].endswith(id_):
+                self.browser.location(account['url'])
 
     def year(self):
-        for text in self.doc.xpath('//h2/strong/text()'):
-            try:
-                return int(text)
-            except ValueError:
-                pass
+        for period in self.periods():
+            if period['selected']:
+                try:
+                    return int(period['timePeriod'])
+                except ValueError:
+                    pass
 
     def years(self):
-        for text in self.doc.xpath('//h2//strong/text()'):
+        for period in self.periods():
             try:
-                yield int(text)
+                yield int(period['timePeriod'])
             except ValueError:
                 pass
 
     def to_year(self, year):
-        href = self.doc.xpath('//h2/a/strong[text()="%s"]/../@href' % year)[0]
-        self.browser.location(href)
+        for period in self.periods():
+            if period['timePeriod'] == str(year):
+                self.browser.location(period['url'])
 
     def statements(self):
-        for outer_uri in self.doc.xpath(
-                                '//table[@id="listOfStatements"]'
-                                '//a[contains(text(), "Statement")]/@href'):
-            inner_uri = re.match('.*destinationClickUrl=([^&]+)&.*',
-                                 outer_uri).group(1)
-            yield unquote(inner_uri)
+        stmts = self.doc['statementsDisclosuresInfo'].get('statements', [])
+        for stmt in stmts:
+            yield stmt['url']
+
+    def accounts(self):
+        return self.doc['statementsDisclosuresInfo']['accountList']
+
+    def periods(self):
+        return self.doc['statementsDisclosuresInfo']['timePeriodList']
 
 
 class StatementPage(LoggedPage, RawPage):
