@@ -30,7 +30,13 @@ class YahooTest(BackendTest):
 
         city = l[0]
         current = self.backend.get_current(city.id)
-        self.assertTrue(current.temp.value > -20 and current.temp.value < 50)
+
+        self.assertTrue(current.temp.unit in ['C', 'F'])
+
+        if current.temp.unit == 'F':
+            self.assertTrue(current.temp.value > -4 and current.temp.value < 122)
+        else:
+            self.assertTrue(current.temp.value > -20 and current.temp.value < 50)
 
         forecasts = list(self.backend.iter_forecast(city.id))
         self.assertTrue(len(forecasts) > 0)
