@@ -40,10 +40,10 @@ class VideoPage(HTMLPage):
 
         def obj_url(self):
             real_id = int(self.env['id'].split('-')[-1])
-            response = self.page.browser.open('http://www.youjizz.com/videos/embed/%s' % real_id)
+            response = self.page.browser.open('https://www.youjizz.com/videos/embed/%s' % real_id)
             data = response.text
 
-            video_file_urls = re.findall(r'"(http://[^",]+\.yjcontentdelivery.com[^",]+\.flv(?:\?[^"]*)?)"', data)
+            video_file_urls = re.findall(r'"(https?://[^",]+\.(?:flv|mp4)(?:\?[^"]*)?)"', data)
             if len(video_file_urls) == 0:
                 raise ValueError('Video URL not found')
             elif len(video_file_urls) > 1:
