@@ -35,12 +35,14 @@ MODULE_PATH = os.getenv(
 TEMPLATE_PATH = os.getenv(
     'TEMPLATE_PATH',
     os.path.realpath(os.path.join(os.path.dirname(__file__), 'boilerplate_data')))
-VERSION = '1.1'
+VERSION = '1.2'
 
 TEMPLATES = TemplateLookup(directories=[TEMPLATE_PATH])
 
 
 def u8(s):
+    if isinstance(s, unicode):
+        return s
     return s.decode('utf-8')
 
 
@@ -105,7 +107,7 @@ class BaseRecipe(Recipe):
 class CapRecipe(Recipe):
     NAME = 'cap'
 
-    LINES = {'def'    :  '    def %s(%s):',
+    LINES = {'def'    :  '    def %s%s:',
              'docbound': '        """',
              'docline':  '        %s',
              'body'   :  '        raise NotImplementedError()'
@@ -170,7 +172,7 @@ class CapRecipe(Recipe):
         for name, member in inspect.getmembers(klass):
             if inspect.ismethod(member):
                 argspec = inspect.getargspec(member)
-                args = ', '.join(argspec[0])
+                args = inspect.formatargspec(*argspec)
 
                 code = []
                 code.append(self.LINES['def'] % (name, args))
