@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
+from __future__ import absolute_import, print_function
 
 import imp
 import inspect
@@ -68,13 +68,14 @@ class ManpageHelpFormatter(optparse.HelpFormatter):
         desc = u'.SH DESCRIPTION\n.LP\n\n%s\n' % description
         if hasattr(self.app, 'CAPS'):
             self.app.weboob.modules_loader.load_all()
-            backends = []
-            for name, backend in self.app.weboob.modules_loader.loaded.iteritems():
-                if backend.has_caps(self.app.CAPS):
-                    backends.append(u'* %s (%s)' % (name, backend.description))
-            if len(backends) > 0:
+            caps = self.app.CAPS if isinstance(self.app.CAPS, tuple) else (self.app.CAPS,)
+            modules = []
+            for name, module in self.app.weboob.modules_loader.loaded.iteritems():
+                if module.has_caps(*caps):
+                    modules.append(u'* %s (%s)' % (name, module.description))
+            if len(modules) > 0:
                 desc += u'\n.SS Supported websites:\n'
-                desc += u'\n.br\n'.join(sorted(backends))
+                desc += u'\n.br\n'.join(sorted(modules))
         return desc
 
     def format_commands(self, commands):
@@ -130,7 +131,7 @@ def main():
                     print("Loaded %s" % fname)
                     # Find the applications we can handle
                     for klass in script.__dict__.itervalues():
-                        if inspect.isclass(klass) and issubclass(klass, Application):
+                        if inspect.isclass(klass) and issubclass(klass, Application) and klass.VERSION:
                             analyze_application(klass, fname)
                 finally:
                     # Cleanup compiled files if needed
