@@ -29,7 +29,9 @@ from weboob.browser.browsers import APIBrowser
 from weboob.browser.profiles import Weboob
 from weboob.exceptions import BrowserHTTPError
 from weboob.capabilities.base import empty
-from weboob.capabilities.bank import CapBank, Account, Transaction
+from weboob.capabilities.bank import CapBank, Account, Transaction, CapBankTransfer, \
+                                     Transfer, TransferStep
+from weboob.capabilities.contact import CapContact, Advisor
 from weboob.tools.application.repl import ReplApplication, defaultcount
 from weboob.tools.application.formatters.iformatter import IFormatter, PrettyFormatter
 
@@ -274,11 +276,49 @@ class RecipientListFormatter(PrettyFormatter):
         return obj.label
 
 
-class AccountListFormatter(IFormatter):
-    MANDATORY_FIELDS = ('id', 'label', 'balance', 'coming')
+class AdvisorListFormatter(IFormatter):
+    MANDATORY_FIELDS = ('id', 'name')
 
-    tot_balance = Decimal(0)
-    tot_coming = Decimal(0)
+    def start_format(self, **kwargs):
+        self.output('   Bank           Name                           Contacts')
+        self.output('-----------------+------------------------------+-----------------------------------------')
+
+    def format_obj(self, obj, alias):
+        bank = obj.backend
+        phones = ""
+        contacts = []
+        if not empty(obj.phone):
+            phones += obj.phone
+        if not empty(obj.mobile):
+            if phones != "":
+                phones += " or %s" % obj.mobile
+            else:
+                phones += obj.mobile
+        if phones:
+            contacts.append(phones)
+
+        for attr in ('email', 'agency', 'address'):
+            value = getattr(obj, attr)
+            if not empty(value):
+                contacts.append(value)
+
+        if len(contacts) > 0:
+            first_contact = contacts.pop(0)
+        else:
+            first_contact = ""
+
+        result = u"  %s %s %s " % (self.colored('%-15s' % bank, 'yellow'),
+                                   self.colored('%-30s' % obj.name, 'red'),
+                                   self.colored("%-30s" % first_contact, 'green'))
+        for contact in contacts:
+            result += "\n %s %s" % ((" ") * 47, self.colored("%-25s" % contact, 'green'))
+
+        return result
+
+class AccountListFormatter(IFormatter):
+    MANDATORY_FIELDS = ('id', 'label', 'balance', 'coming', 'type')
+
+    totals = {}
 
     def start_format(self, **kwargs):
         self.output('               %s  Account                     Balance    Coming ' % ((' ' * 15) if not self.interactive else ''))
@@ -296,31 +336,41 @@ class AccountListFormatter(IFormatter):
 
         balance = obj.balance or Decimal('0')
         coming = obj.coming or Decimal('0')
+        currency = obj.currency or 'EUR'
         result = u'%s %s %s  %s' % (id,
-                                    self.colored('%-25s' % obj.label[:25], 'yellow'),
+                                    self.colored('%-25s' % obj.label[:25], 'yellow' if obj.type != Account.TYPE_LOAN else 'blue'),
                                     self.colored('%9.2f' % obj.balance, 'green' if balance >= 0 else 'red') if not empty(obj.balance) else ' ' * 9,
                                     self.colored('%9.2f' % obj.coming, 'green' if coming >= 0 else 'red') if not empty(obj.coming) else '')
 
-        self.tot_balance += balance
-        self.tot_coming += coming
+        currency_totals = self.totals.setdefault(currency, {})
+        currency_totals.setdefault('balance', Decimal(0))
+        currency_totals.setdefault('coming', Decimal(0))
+
+        if obj.type != Account.TYPE_LOAN:
+            currency_totals['balance'] += balance
+            currency_totals['coming'] += coming
         return result
 
     def flush(self):
         self.output(u'------------------------------------------%s+----------+----------' % (('-' * 15) if not self.interactive else ''))
-        self.output(u'%s                                    Total   %s   %s' % (
-                    (' ' * 15) if not self.interactive else '',
-                    self.colored('%8.2f' % self.tot_balance, 'green' if self.tot_balance >= 0 else 'red'),
-                    self.colored('%8.2f' % self.tot_coming, 'green' if self.tot_coming >= 0 else 'red'))
-                    )
-        self.tot_balance = Decimal(0)
-        self.tot_coming = Decimal(0)
+        for currency, currency_totals in sorted(self.totals.iteritems(), key=lambda (k,v): (v,k)):
+            balance = currency_totals['balance']
+            coming = currency_totals['coming']
+
+            self.output(u'%s                              Total (%s)   %s   %s' % (
+                        (' ' * 15) if not self.interactive else '',
+                        currency,
+                        self.colored('%8.2f' % balance, 'green' if balance >= 0 else 'red'),
+                        self.colored('%8.2f' % coming, 'green' if coming >= 0 else 'red'))
+                        )
+        self.totals.clear()
 
 
 class Boobank(ReplApplication):
     APPNAME = 'boobank'
-    VERSION = '1.1'
+    VERSION = '1.2'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon, Christophe Benz'
-    CAPS = CapBank
+    CAPS = CapBank, CapBankTransfer
     DESCRIPTION = "Console application allowing to list your bank accounts and get their balance, " \
                   "display accounts history and coming bank operations, and transfer money from an account to " \
                   "another (if available)."
@@ -333,6 +383,7 @@ class Boobank(ReplApplication):
                         'ofx':            OfxFormatter,
                         'ops_list':       TransactionsFormatter,
                         'investment_list': InvestmentFormatter,
+                        'advisor_list':   AdvisorListFormatter,
                         }
     DEFAULT_FORMATTER = 'table'
     COMMANDS_FORMATTERS = {'ls':          'account_list',
@@ -341,9 +392,24 @@ class Boobank(ReplApplication):
                            'history':     'ops_list',
                            'coming':      'ops_list',
                            'investment':  'investment_list',
+                           'advisor':     'advisor_list',
                            }
     COLLECTION_OBJECTS = (Account, Transaction, )
 
+    def bcall_error_handler(self, backend, error, backtrace):
+        if isinstance(error, TransferStep):
+            params = {}
+            for key, value in error.fields.iteritems():
+                if key and value:
+                    params[key] = self.ask(value)
+            #backend.config['accept_transfer'].set(v)
+            params['backends'] = backend
+            self.start_format()
+            for transfer in self.do('transfer', error.transfer, **params):
+                self.format(transfer)
+        else:
+            return ReplApplication.bcall_error_handler(self, backend, error, backtrace)
+
     def load_default_backends(self):
         self.load_backends(CapBank, storage=self.create_storage())
 
@@ -450,11 +516,11 @@ class Boobank(ReplApplication):
 
         if not id_to:
             self.objects = []
-            self.set_formatter('recipient_list')
+            self.set_formatter('table')
             self.set_formatter_header(u'Available recipients')
 
             self.start_format()
-            for recipient in self.do('iter_transfer_recipients', account.id, backends=account.backend):
+            for recipient in self.do('iter_transfer_recipients', account.id, backends=account.backend, caps=CapBankTransfer):
                 self.cached_format(recipient)
             return 0
 
@@ -470,12 +536,14 @@ class Boobank(ReplApplication):
             print('Error: please give a decimal amount to transfer', file=self.stderr)
             return 2
 
+        exec_date = datetime.date.today()
+
         if self.interactive:
             # Try to find the recipient label. It can be missing from
             # recipients list, for example for banks which allow transfers to
             # arbitrary recipients.
             to = id_to
-            for recipient in self.do('iter_transfer_recipients', account.id, backends=account.backend):
+            for recipient in self.do('iter_transfer_recipients', account.id, backends=account.backend, caps=CapBankTransfer):
                 if recipient.id == id_to:
                     to = recipient.label
                     break
@@ -484,12 +552,20 @@ class Boobank(ReplApplication):
             print('From:   %s' % account.label)
             print('To:     %s' % to)
             print('Reason: %s' % (reason or ''))
+            print('Date:   %s' % exec_date)
             if not self.ask('Are you sure to do this transfer?', default=True):
                 return
 
         self.start_format()
-        for transfer in self.do('transfer', account.id, id_to, amount, reason, backends=account.backend):
-            self.format(transfer)
+
+        transfer = Transfer()
+        transfer.account_id = account.id
+        transfer.recipient_id = id_to
+        transfer.amount = amount
+        transfer.label = reason
+        transfer.exec_date = exec_date
+
+        next(iter(self.do('transfer', transfer, backends=account.backend)))
 
     def do_investment(self, id):
         """
@@ -522,11 +598,12 @@ class Boobank(ReplApplication):
 
         client = APIBrowser(baseurl='https://budgea.biapi.pro/2.0/')
         client.set_profile(Weboob(self.VERSION))
+        client.TIMEOUT = 60
         try:
             r = client.request('auth/token', data={'username': username, 'password': password, 'application': 'weboob'})
         except BrowserHTTPError as r:
             error = r.response.json()
-            print('Error: %s' % (error['message'] or error['code']), file=self.stderr)
+            print('Error: {}'.format(error.get('message', error['code'])), file=self.stderr)
             return 1
 
         client.session.headers['Authorization'] = 'Bearer %s' % r['token']
@@ -558,3 +635,18 @@ class Boobank(ReplApplication):
                                data={'transactions': transactions})
             client.request('users/me/accounts/%s' % account_id, data={'balance': account.balance})
             print('- %s (%s%s): %s new transactions' % (account.label, account.balance, account.currency_text, len(r)))
+
+    def do_advisor(self, line):
+        """
+        advisor
+
+        Display advisors.
+        """
+        self.start_format()
+        found = 0
+        for advisor in self.do('iter_contacts', caps=CapContact):
+            if isinstance(advisor, Advisor):
+                self.format(advisor)
+                found = 1
+        if not found:
+            print('Error: no advisor found', file=self.stderr)
