@@ -18,17 +18,19 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import codecs
 
-from PyQt4.QtCore import SIGNAL, Qt, QStringList
-from PyQt4.QtGui import QApplication, QCompleter, QFrame, QShortcut, QKeySequence
+from PyQt5.QtCore import Qt, pyqtSlot as Slot
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import QApplication, QFrame, QShortcut
 
 from weboob.capabilities.base import NotAvailable
 from weboob.capabilities.cinema import CapCinema
 from weboob.capabilities.torrent import CapTorrent
 from weboob.capabilities.subtitle import CapSubtitle
-from weboob.tools.application.qt import QtMainWindow, QtDo
-from weboob.tools.application.qt.backendcfg import BackendCfg
+from weboob.tools.application.qt5 import QtMainWindow, QtDo
+from weboob.tools.application.qt5.backendcfg import BackendCfg
+from weboob.tools.application.qt5.models import BackendListModel
+from weboob.tools.application.qt5.search_history import HistoryCompleter
 
 from weboob.applications.suboob.suboob import LANGUAGE_CONV
 from weboob.applications.qcineoob.ui.main_window_ui import Ui_MainWindow
@@ -43,10 +45,11 @@ from .person import Person
 from .torrent import Torrent
 from .subtitle import Subtitle
 
+MAX_TAB_TEXT_LENGTH=30
 
 class Result(QFrame):
     def __init__(self, weboob, app, parent=None):
-        QFrame.__init__(self, parent)
+        super(Result, self).__init__(parent)
         self.ui = Ui_Result()
         self.ui.setupUi(self)
 
@@ -59,7 +62,8 @@ class Result(QFrame):
         # action history is composed by the last action and the action list
         # An action is a function, a list of arguments and a description string
         self.action_history = {'last_action': None, 'action_list': []}
-        self.connect(self.ui.backButton, SIGNAL("clicked()"), self.doBack)
+        self.ui.backButton.clicked.connect(self.doBack)
+        self.ui.backButton.setShortcut(QKeySequence('Alt+Left'))
         self.ui.backButton.hide()
 
     def doAction(self, description, fun, args):
@@ -69,11 +73,19 @@ class Result(QFrame):
         self.ui.currentActionLabel.setText(description)
         if self.action_history['last_action'] is not None:
             self.action_history['action_list'].append(self.action_history['last_action'])
-            self.ui.backButton.setToolTip(self.action_history['last_action']['description'])
+            self.ui.backButton.setToolTip('%s (Alt+Left)'%self.action_history['last_action']['description'])
             self.ui.backButton.show()
         self.action_history['last_action'] = {'function': fun, 'args': args, 'description': description}
+        # manage tab text
+        mytabindex = self.parent.ui.resultsTab.indexOf(self)
+        tabtxt = description
+        if len(tabtxt) > MAX_TAB_TEXT_LENGTH:
+            tabtxt = '%s...'%tabtxt[:MAX_TAB_TEXT_LENGTH]
+        self.parent.ui.resultsTab.setTabText(mytabindex, tabtxt)
+        self.parent.ui.resultsTab.setTabToolTip(mytabindex, description)
         return fun(*args)
 
+    @Slot()
     def doBack(self):
         ''' Go back in action history
         Basically call previous function and update history
@@ -86,6 +98,14 @@ class Result(QFrame):
                 self.ui.backButton.hide()
             else:
                 self.ui.backButton.setToolTip(self.action_history['action_list'][-1]['description'])
+            # manage tab text
+            mytabindex = self.parent.ui.resultsTab.indexOf(self)
+            tabtxt = todo['description']
+            if len(tabtxt) > MAX_TAB_TEXT_LENGTH:
+                tabtxt = '%s...'%tabtxt[:MAX_TAB_TEXT_LENGTH]
+            self.parent.ui.resultsTab.setTabText(mytabindex, tabtxt)
+            self.parent.ui.resultsTab.setTabToolTip(mytabindex, todo['description'])
+
             return todo['function'](*todo['args'])
 
     def castingAction(self, backend_name, id, role):
@@ -228,16 +248,13 @@ class Result(QFrame):
         self.parent.ui.searchEdit.setEnabled(False)
         QApplication.setOverrideCursor(Qt.WaitCursor)
 
-        backend_name = str(self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex()).toString())
+        backend_name = self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex())
 
         self.process = QtDo(self.weboob, self.addMovie, fb=self.processFinished)
         #self.process.do('iter_movies', pattern, backends=backend_name, caps=CapCinema)
         self.process.do(self.app._do_complete, self.parent.getCount(), ('original_title'), 'iter_movies', pattern, backends=backend_name, caps=CapCinema)
         self.parent.ui.stopButton.show()
 
-    def stopProcess(self):
-        self.process.process.finish_event.set()
-
     def addMovie(self, movie):
         minimovie = MiniMovie(self.weboob, self.weboob[movie.backend], movie, self)
         self.ui.list_content.layout().insertWidget(self.ui.list_content.layout().count()-1,minimovie)
@@ -270,7 +287,7 @@ class Result(QFrame):
         self.parent.ui.searchEdit.setEnabled(False)
         QApplication.setOverrideCursor(Qt.WaitCursor)
 
-        backend_name = str(self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex()).toString())
+        backend_name = self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex())
 
         self.process = QtDo(self.weboob, self.addPerson, fb=self.processFinished)
         #self.process.do('iter_persons', pattern, backends=backend_name, caps=CapCinema)
@@ -309,7 +326,7 @@ class Result(QFrame):
         self.parent.ui.searchEdit.setEnabled(False)
         QApplication.setOverrideCursor(Qt.WaitCursor)
 
-        backend_name = str(self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex()).toString())
+        backend_name = self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex())
 
         self.process = QtDo(self.weboob, self.addTorrent, fb=self.processFinished)
         #self.process.do('iter_torrents', pattern, backends=backend_name, caps=CapTorrent)
@@ -322,10 +339,25 @@ class Result(QFrame):
         self.process = None
         self.parent.ui.stopButton.hide()
 
+    @Slot()
+    def stopProcess(self):
+        if self.process is not None:
+            self.process.stop()
+
     def addTorrent(self, torrent):
         minitorrent = MiniTorrent(self.weboob, self.weboob[torrent.backend], torrent, self)
-        self.ui.list_content.layout().insertWidget(self.ui.list_content.layout().count()-1,minitorrent)
-        self.minis.append(minitorrent)
+        positionToInsert = self.ui.list_content.layout().count()-1
+        # if possible, we insert the torrent keeping a sort by seed
+        if torrent.seeders != NotAvailable:
+            seeders = torrent.seeders
+            positionToInsert = 0
+            while positionToInsert < len(self.minis) and\
+            (self.minis[positionToInsert].torrent.seeders != NotAvailable and\
+                    seeders <= self.minis[positionToInsert].torrent.seeders):
+                positionToInsert += 1
+
+        self.ui.list_content.layout().insertWidget(positionToInsert, minitorrent)
+        self.minis.insert(positionToInsert, minitorrent)
 
     def displayTorrent(self, torrent, backend):
         self.ui.stackedWidget.setCurrentWidget(self.ui.info_page)
@@ -353,7 +385,7 @@ class Result(QFrame):
         self.parent.ui.searchEdit.setEnabled(False)
         QApplication.setOverrideCursor(Qt.WaitCursor)
 
-        backend_name = str(self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex()).toString())
+        backend_name = self.parent.ui.backendEdit.itemData(self.parent.ui.backendEdit.currentIndex())
 
         self.process = QtDo(self.weboob, self.addSubtitle, fb=self.processFinished)
         #self.process.do('iter_subtitles', lang, pattern, backends=backend_name, caps=CapSubtitle)
@@ -404,7 +436,7 @@ class Result(QFrame):
 
 class MainWindow(QtMainWindow):
     def __init__(self, config, weboob, app, parent=None):
-        QtMainWindow.__init__(self, parent)
+        super(MainWindow, self).__init__(parent)
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
 
@@ -413,36 +445,38 @@ class MainWindow(QtMainWindow):
         self.app = app
 
         # search history is a list of patterns which have been searched
-        self.search_history = self.loadSearchHistory()
-        self.updateCompletion()
+        history_path = os.path.join(self.weboob.workdir, 'qcineoob_history')
+        qc = HistoryCompleter(history_path, self)
+        qc.load()
+        qc.setCaseSensitivity(Qt.CaseInsensitive)
+        self.ui.searchEdit.setCompleter(qc)
 
-        self.connect(self.ui.searchEdit, SIGNAL("returnPressed()"), self.search)
-        self.connect(self.ui.idEdit, SIGNAL("returnPressed()"), self.searchId)
-        self.connect(self.ui.typeCombo, SIGNAL("currentIndexChanged(QString)"), self.typeComboChanged)
+        self.ui.searchEdit.returnPressed.connect(self.search)
+        self.ui.idEdit.returnPressed.connect(self.searchId)
+        self.ui.typeCombo.currentIndexChanged[unicode].connect(self.typeComboChanged)
 
         count = self.config.get('settings', 'maxresultsnumber')
         self.ui.countSpin.setValue(int(count))
         showT = self.config.get('settings', 'showthumbnails')
         self.ui.showTCheck.setChecked(showT == '1')
 
-        self.connect(self.ui.stopButton, SIGNAL("clicked()"), self.stopProcess)
         self.ui.stopButton.hide()
 
-        self.connect(self.ui.actionBackends, SIGNAL("triggered()"), self.backendsConfig)
+        self.ui.actionBackends.triggered.connect(self.backendsConfig)
         q = QShortcut(QKeySequence(Qt.CTRL + Qt.Key_Q), self)
-        self.connect(q, SIGNAL("activated()"), self.close)
+        q.activated.connect(self.close)
         n = QShortcut(QKeySequence(Qt.CTRL + Qt.Key_PageDown), self)
-        self.connect(n, SIGNAL("activated()"), self.nextTab)
+        n.activated.connect(self.nextTab)
         p = QShortcut(QKeySequence(Qt.CTRL + Qt.Key_PageUp), self)
-        self.connect(p, SIGNAL("activated()"), self.prevTab)
+        p.activated.connect(self.prevTab)
         w = QShortcut(QKeySequence(Qt.CTRL + Qt.Key_W), self)
-        self.connect(w, SIGNAL("activated()"), self.closeCurrentTab)
+        w.activated.connect(self.closeCurrentTab)
 
         l = QShortcut(QKeySequence(Qt.CTRL + Qt.Key_L), self)
-        self.connect(l, SIGNAL("activated()"), self.ui.searchEdit.setFocus)
-        self.connect(l, SIGNAL("activated()"), self.ui.searchEdit.selectAll)
+        l.activated.connect(self.ui.searchEdit.setFocus)
+        l.activated.connect(self.ui.searchEdit.selectAll)
 
-        self.connect(self.ui.resultsTab, SIGNAL("tabCloseRequested(int)"), self.closeTab)
+        self.ui.resultsTab.tabCloseRequested.connect(self.closeTab)
 
         self.loadBackendsList()
 
@@ -455,24 +489,23 @@ class MainWindow(QtMainWindow):
         self.ui.langCombo.hide()
         self.ui.langLabel.hide()
 
-    def stopProcess(self):
-        self.ui.resultsTab.currentWidget().stopProcess()
-
+    @Slot(int)
     def closeTab(self, index):
         if self.ui.resultsTab.widget(index) != 0:
-            tabToClose = self.ui.resultsTab.widget(index)
             self.ui.resultsTab.removeTab(index)
-            del(tabToClose)
 
+    @Slot()
     def closeCurrentTab(self):
         self.closeTab(self.ui.resultsTab.currentIndex())
 
+    @Slot()
     def prevTab(self):
         index = self.ui.resultsTab.currentIndex() - 1
         size = self.ui.resultsTab.count()
         if size != 0:
             self.ui.resultsTab.setCurrentIndex(index % size)
 
+    @Slot()
     def nextTab(self):
         index = self.ui.resultsTab.currentIndex() + 1
         size = self.ui.resultsTab.count()
@@ -494,81 +527,66 @@ class MainWindow(QtMainWindow):
             id = torrent.id
             stype = 'torrent'
         new_res = Result(self.weboob, self.app, self)
-        self.ui.resultsTab.addTab(new_res, txt)
+        self.ui.stopButton.clicked.connect(new_res.stopProcess)
+        tabtxt = txt
+        if len(tabtxt) > MAX_TAB_TEXT_LENGTH:
+            tabtxt = '%s...'%tabtxt[:MAX_TAB_TEXT_LENGTH]
+        index = self.ui.resultsTab.addTab(new_res, tabtxt)
+        self.ui.resultsTab.setTabToolTip(index, txt)
         new_res.searchId(id, stype)
 
+    @Slot()
     def search(self):
-        pattern = unicode(self.ui.searchEdit.text())
-        # arbitrary max number of completion word
-        if len(self.search_history) > 50:
-            self.search_history.pop(0)
-        if pattern not in self.search_history:
-            self.search_history.append(pattern)
-            self.updateCompletion()
+        pattern = self.ui.searchEdit.text()
+        self.ui.searchEdit.completer().addString(pattern)
 
-        tosearch = unicode(self.ui.typeCombo.currentText())
-        lang = unicode(self.ui.langCombo.currentText())
+        tosearch = self.ui.typeCombo.currentText()
+        lang = self.ui.langCombo.currentText()
         new_res = Result(self.weboob, self.app, self)
-        self.ui.resultsTab.addTab(new_res, pattern)
+
+        txt = 'search %s "%s"'%(tosearch, pattern)
+        tabtxt = txt
+        if len(tabtxt) > MAX_TAB_TEXT_LENGTH:
+            tabtxt = '%s...'%tabtxt[:MAX_TAB_TEXT_LENGTH]
+        index = self.ui.resultsTab.addTab(new_res, tabtxt)
+        self.ui.resultsTab.setTabToolTip(index, txt)
+
         self.ui.resultsTab.setCurrentWidget(new_res)
         new_res.search(tosearch, pattern, lang)
 
+    @Slot()
     def searchId(self):
-        id = unicode(self.ui.idEdit.text())
-        stype = unicode(self.ui.idTypeCombo.currentText())
+        id = self.ui.idEdit.text()
+        stype = self.ui.idTypeCombo.currentText()
         new_res = Result(self.weboob, self.app, self)
         self.ui.resultsTab.addTab(new_res, id)
         self.ui.resultsTab.setCurrentWidget(new_res)
         new_res.searchId(id, stype)
 
+    @Slot()
     def backendsConfig(self):
         bckndcfg = BackendCfg(self.weboob, (CapCinema, CapTorrent, CapSubtitle,), self)
         if bckndcfg.run():
             self.loadBackendsList()
 
     def loadBackendsList(self):
-        self.ui.backendEdit.clear()
-        for i, backend in enumerate(self.weboob.iter_backends()):
-            if i == 0:
-                self.ui.backendEdit.addItem('All backends', '')
-            self.ui.backendEdit.addItem(backend.name, backend.name)
-            if backend.name == self.config.get('settings', 'backend'):
-                self.ui.backendEdit.setCurrentIndex(i+1)
+        model = BackendListModel(self.weboob)
+        model.addBackends()
+        self.ui.backendEdit.setModel(model)
+
+        current_backend = self.config.get('settings', 'backend')
+        idx = self.ui.backendEdit.findData(current_backend)
+        if idx >= 0:
+            self.ui.backendEdit.setCurrentIndex(idx)
 
         if self.ui.backendEdit.count() == 0:
             self.ui.searchEdit.setEnabled(False)
         else:
             self.ui.searchEdit.setEnabled(True)
 
-    def loadSearchHistory(self):
-        ''' Return search string history list loaded from history file
-        '''
-        result = []
-        history_path = os.path.join(self.weboob.workdir, 'qcineoob_history')
-        if os.path.exists(history_path):
-            f = codecs.open(history_path, 'r', 'utf-8')
-            conf_hist = f.read()
-            f.close()
-            if conf_hist is not None and conf_hist.strip() != '':
-                result = conf_hist.strip().split('\n')
-        return result
-
-    def saveSearchHistory(self):
-        ''' Save search history in history file
-        '''
-        if len(self.search_history) > 0:
-            history_path = os.path.join(self.weboob.workdir, 'qcineoob_history')
-            f = codecs.open(history_path, 'w', 'utf-8')
-            f.write('\n'.join(self.search_history))
-            f.close()
-
-    def updateCompletion(self):
-        qc = QCompleter(QStringList(self.search_history), self)
-        qc.setCaseSensitivity(Qt.CaseInsensitive)
-        self.ui.searchEdit.setCompleter(qc)
-
+    @Slot(unicode)
     def typeComboChanged(self, value):
-        if unicode(value) == 'subtitle':
+        if value == 'subtitle':
             self.ui.langCombo.show()
             self.ui.langLabel.show()
         else:
@@ -583,9 +601,9 @@ class MainWindow(QtMainWindow):
             return num
 
     def closeEvent(self, ev):
-        self.config.set('settings', 'backend', str(self.ui.backendEdit.itemData(
-            self.ui.backendEdit.currentIndex()).toString()))
-        self.saveSearchHistory()
+        self.config.set('settings', 'backend', self.ui.backendEdit.itemData(
+            self.ui.backendEdit.currentIndex()))
+        self.ui.searchEdit.completer().save()
         self.config.set('settings', 'maxresultsnumber', self.ui.countSpin.value())
         self.config.set('settings', 'showthumbnails', '1' if self.ui.showTCheck.isChecked() else '0')
 
