@@ -23,7 +23,7 @@ import os
 import re
 
 from weboob.capabilities.account import CapAccount
-from weboob.core.modules import ModuleLoadError
+from weboob.exceptions import ModuleLoadError
 from weboob.tools.application.repl import ReplApplication
 from weboob.tools.application.console import ConsoleProgress
 from weboob.tools.ordereddict import OrderedDict
@@ -76,7 +76,7 @@ class ModuleInfoFormatter(IFormatter):
 
 class WeboobCfg(ReplApplication):
     APPNAME = 'weboob-config'
-    VERSION = '1.1'
+    VERSION = '1.2'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Christophe Benz, Romain Bignon'
     DESCRIPTION = "Weboob-Config is a console application to add/edit/remove backends, " \
                   "and to register new website accounts."
