@@ -19,14 +19,15 @@
 
 from __future__ import absolute_import, print_function
 
+from functools import wraps
 import re
 import pickle
 import base64
 import zlib
 try:
-    import urllib3
-except ImportError:
     from requests.packages import urllib3
+except ImportError:
+    import urllib3
 try:
     from urllib.parse import urlparse, urljoin
 except ImportError:
@@ -43,6 +44,8 @@ try:
 except ImportError:
     raise ImportError('Please install python-requests >= 2.0')
 
+from weboob.exceptions import BrowserHTTPSDowngrade, ModuleInstallError
+
 from weboob.tools.log import getLogger
 from weboob.tools.ordereddict import OrderedDict
 from weboob.tools.json import json
@@ -107,14 +110,14 @@ class Browser(object):
 
     def __init__(self, logger=None, proxy=None, responses_dirname=None):
         self.logger = getLogger('browser', logger)
+        self.responses_dirname = responses_dirname
+        self.responses_count = 1
+
         self.PROXIES = proxy
         self._setup_session(self.PROFILE)
         self.url = None
         self.response = None
 
-        self.responses_dirname = responses_dirname
-        self.responses_count = 1
-
         if isinstance(self.VERIFY, basestring):
             self.VERIFY = self.asset(self.VERIFY)
 
@@ -211,7 +214,7 @@ class Browser(object):
 
         profile.setup_session(session)
 
-        if self.logger.settings['save_responses']:
+        if self.responses_dirname is not None:
             session.hooks['response'].append(self.save_response)
 
         self.session = session
@@ -389,8 +392,8 @@ class Browser(object):
         if isinstance(req.data, unicode) and data_encoding:
             req.data = req.data.encode(data_encoding)
         if isinstance(req.data, dict) and data_encoding:
-            req.data = dict([(k, v.encode(data_encoding) if isinstance(v, unicode) else v)
-                             for k, v in req.data.iteritems()])
+            req.data = OrderedDict([(k, v.encode(data_encoding) if isinstance(v, unicode) else v)
+                                    for k, v in req.data.iteritems()])
 
         if referrer is None:
             referrer = self.get_referrer(self.url, url)
@@ -530,15 +533,18 @@ class DomainBrowser(Browser):
 
     def absurl(self, uri, base=None):
         """
-        Get the absolute URL, relative to the base URL.
-        If BASEURL is None, it will try to use the current URL.
+        Get the absolute URL, relative to a base URL.
+        If base is None, it will try to use the current URL.
+        If there is no current URL, it will try to use BASEURL.
+
         If base is False, it will always try to use the current URL.
+        If base is True, it will always try to use BASEURL.
 
         :param uri: URI to make absolute. It can be already absolute.
         :type uri: str
 
         :param base: Base absolute URL.
-        :type base: str or None or False
+        :type base: str or None or False or True
 
         :rtype: str
         """
@@ -550,7 +556,7 @@ class DomainBrowser(Browser):
 
     def open(self, req, *args, **kwargs):
         """
-        Like :meth:`Browser.open` but hanldes urls without domains, using
+        Like :meth:`Browser.open` but handles urls without domains, using
         the :attr:`BASEURL` attribute.
         """
         uri = req.url if isinstance(req, requests.Request) else req
@@ -659,6 +665,16 @@ class PagesBrowser(DomainBrowser):
                     break
 
             if response.page is None:
+                regexp = r'^(?P<proto>\w+)://.*'
+
+                proto_response = re.match(regexp, response.url)
+                if proto_response:
+                    proto_response = proto_response.group('proto')
+                    proto_base = re.match(regexp, self.BASEURL).group('proto')
+
+                    if proto_base == 'https' and proto_response != 'https':
+                        raise BrowserHTTPSDowngrade()
+
                 self.logger.debug('Unable to handle %s' % response.url)
 
             return callback(response)
@@ -707,7 +723,7 @@ class PagesBrowser(DomainBrowser):
         ...             raise NextPage(next.attrib['href'])
         ...
         >>> class Browser(PagesBrowser):
-        ...     BASEURL = 'http://people.symlink.me'
+        ...     BASEURL = 'https://people.symlink.me'
         ...     list = URL('/~rom1/projects/weboob/list-(?P<pagenum>\d+).html', Page)
         ...
         >>> b = Browser()
@@ -730,6 +746,8 @@ def need_login(func):
     """
     Decorator used to require to be logged to access to this function.
     """
+
+    @wraps(func)
     def inner(browser, *args, **kwargs):
         if browser.page is None or not browser.page.logged:
             browser.do_login()
@@ -790,12 +808,13 @@ class StatesMixin(object):
         if 'url' in state:
             try:
                 self.location(state['url'])
-            except requests.exceptions.HTTPError:
+            except (requests.exceptions.HTTPError, requests.exceptions.TooManyRedirects):
                 pass
 
     def dump_state(self):
         state = {}
-        state['url'] = self.page.url
+        if self.page:
+            state['url'] = self.page.url
         state['cookies'] = base64.b64encode(zlib.compress(pickle.dumps(self.session.cookies, -1)))
         for attrname in self.__states__:
             state[attrname] = getattr(self, attrname)
@@ -808,6 +827,15 @@ class APIBrowser(DomainBrowser):
     A browser for API websites.
     """
 
+    def build_request(self, *args, **kwargs):
+        if 'data' in kwargs:
+            kwargs['data'] = json.dumps(kwargs['data'])
+        if 'headers' not in kwargs:
+            kwargs['headers'] = {}
+        kwargs['headers']['Content-Type'] = 'application/json'
+
+        return super(APIBrowser, self).build_request(*args, **kwargs)
+
     def open(self, *args, **kwargs):
         """
         Do a JSON request.
@@ -819,12 +847,6 @@ class APIBrowser(DomainBrowser):
         :param headers: if specified, add these headers to the request
         :type headers: :class:`dict`
         """
-        if 'data' in kwargs:
-            kwargs['data'] = json.dumps(kwargs['data'])
-        if 'headers' not in kwargs:
-            kwargs['headers'] = {}
-        kwargs['headers']['Content-Type'] = 'application/json'
-
         return super(APIBrowser, self).open(*args, **kwargs)
 
     def request(self, *args, **kwargs):
@@ -835,3 +857,43 @@ class APIBrowser(DomainBrowser):
         :rtype: :class:`dict`
         """
         return self.open(*args, **kwargs).json()
+
+
+class AbstractBrowserMissingParentError(Exception):
+    pass
+
+
+class AbstractBrowser(Browser):
+    """ AbstractBrowser allow inheritance of a browser defined in another module.
+
+    Websites can share many pages and code base. This class allow to load a browser
+    provided by another module and to build our own browser on top of it (like standard
+    python inheritance. Weboob will install and download the PARENT module for you.
+
+    PARENT is a mandatory attribute, it's the name of the module providing the parent Browser
+
+    PARENT_ATTR is an optionnal attribute used when the parent module does not have only one
+    browser defined as BROWSER class attribute: you can customized the path of the object to load.
+
+    Note that you must pass a valid weboob instance as first argument of the constructor.
+    """
+    PARENT = None
+    PARENT_ATTR = None
+
+    def __new__(cls, weboob, *args, **kwargs):
+        if cls.PARENT is None:
+            raise AbstractBrowserMissingParentError("PARENT is not defined for browser %s" % cls)
+
+        try:
+            module = weboob.load_or_install_module(cls.PARENT)
+        except ModuleInstallError as err:
+            raise ModuleInstallError('This module depends on %s module but %s\'s installation failed with: %s' % (cls.PARENT, cls.PARENT, err))
+
+        if cls.PARENT_ATTR is None:
+            parent = module.klass.BROWSER
+        else:
+            parent = reduce(getattr, cls.PARENT_ATTR.split('.'), module)
+
+        if parent is None:
+            raise AbstractBrowserMissingParentError("Failed to load parent class")
+        return type(cls.__name__, (parent,), dict(cls.__dict__))(*args, **kwargs)
