@@ -50,6 +50,7 @@ def method(klass):
 
 class AbstractElement(object):
     _creation_counter = 0
+    condition = None
 
     def __init__(self, page, parent=None, el=None):
         self.page = page
@@ -136,6 +137,9 @@ class ListElement(AbstractElement):
             yield self.el
 
     def __iter__(self):
+        if self.condition is not None and not self.condition():
+            return
+
         self.parse(self.el)
 
         items = []
@@ -144,6 +148,9 @@ class ListElement(AbstractElement):
                 attr = getattr(self, attrname)
                 if isinstance(attr, type) and issubclass(attr, AbstractElement) and attr != type(self):
                     item = attr(self.page, self, el)
+                    if item.condition is not None and not item.condition():
+                        continue
+
                     item.handle_loaders()
                     items.append(item)
 
@@ -222,7 +229,6 @@ class ItemElement(AbstractElement):
     _attrs = None
     _loaders = None
     klass = None
-    condition = None
     validate = None
 
     class Index(object):
@@ -292,13 +298,16 @@ class TableElement(ListElement):
                 cols = getattr(self, attrname)
                 if not isinstance(cols, (list,tuple)):
                     cols = [cols]
-                columns[m.group(1)] = [s.lower() for s in cols]
+                columns[m.group(1)] = [s.lower() if isinstance(s, (str, unicode)) else s for s in cols]
 
         colnum = 0
         for el in self.el.xpath(self.head_xpath):
-            title = self.cleaner.clean(el).lower()
+            title = self.cleaner.clean(el)
             for name, titles in columns.iteritems():
-                if title in titles and name not in self._cols:
+                if name in self._cols:
+                    continue
+                if title.lower() in [s for s in titles if isinstance(s, (str, unicode))] or \
+                   any(map(lambda x: x.match(title), [s for s in titles if isinstance(s, type(re.compile('')))])):
                     self._cols[name] = colnum
             try:
                 colnum += int(el.attrib.get('colspan', 1))
@@ -320,9 +329,23 @@ class DictElement(ListElement):
         else:
             selector = self.item_xpath
 
+        _subdict = False
         for el in selector:
             if isinstance(self.el, list):
-                el = int(el)
+                if _subdict:
+                    subdicts = []
+                    for i in range (0, len(self.el)):
+                        _el = int(el) if isinstance(self.el[i], list) else el
+                        subdicts += self.el[i][_el]
+                    self.el = subdicts
+                    _subdict = False
+                    continue
+
+                if el == '*':
+                    _subdict = True
+                    continue
+                elif el.isdigit():
+                    el = int(el) if int(el) < len(self.el) else 0
 
             self.el = self.el[el]
 
