@@ -29,6 +29,7 @@ from collections import Iterator
 from dateutil.parser import parse as parse_date
 
 from weboob.capabilities.base import empty
+from weboob.capabilities.base import Currency as BaseCurrency
 from weboob.tools.compat import basestring
 from weboob.exceptions import ParseError
 from weboob.browser.url import URL
@@ -44,10 +45,10 @@ _NO_DEFAULT = NoDefault()
 
 __all__ = ['FilterError', 'ColumnNotFound', 'RegexpError', 'ItemNotFound',
            'Filter', 'Base', 'Env', 'TableCell', 'RawText',
-           'CleanText', 'Lower', 'CleanDecimal', 'Field', 'Regexp', 'Map',
-           'DateTime', 'Date', 'Time', 'DateGuesser', 'Duration',
-           'MultiFilter', 'CombineDate', 'Format', 'Join', 'Type', 'Eval',
-           'BrowserURL', 'Async', 'AsyncLoad']
+           'CleanText', 'Lower', 'Upper', 'Capitalize', 'CleanDecimal',
+           'Field', 'Regexp', 'Map', 'DateTime', 'Date', 'Time', 'DateGuesser',
+           'Duration', 'MultiFilter', 'CombineDate', 'Format', 'Join', 'Type',
+           'Eval', 'BrowserURL', 'Async', 'AsyncLoad']
 
 
 class FilterError(ParseError):
@@ -212,9 +213,12 @@ class Async(_Filter):
         if item.loaders[self.name] is None:
             return None
 
+        return self.selector(self.loaded_page(item).doc)
+
+    def loaded_page(self, item):
         result = item.loaders[self.name].result()
         assert result.page is not None, 'The loaded url %s hasn\'t been matched by an URL object' % result.url
-        return self.selector(result.page.doc)
+        return result.page
 
 
 class Base(Filter):
@@ -237,8 +241,11 @@ class Decode(Filter):
     """
     Filter that aims to decode urlencoded strings
 
-    >>> Decode(Env(_id))
-    >>> Decode(Link(./a))
+    >>> Decode(Env('_id'))  # doctest: +ELLIPSIS
+    <weboob.browser.filters.standard.Decode object at 0x...>
+    >>> from .html import Link
+    >>> Decode(Link('./a'))  # doctest: +ELLIPSIS
+    <weboob.browser.filters.standard.Decode object at 0x...>
 
     """
     def __call__(self, item):
@@ -296,28 +303,45 @@ class TableCell(_Filter):
     """
 
     def __init__(self, *names, **kwargs):
+        support_th = kwargs.pop('support_th', False)
         super(TableCell, self).__init__(**kwargs)
         self.names = names
 
+        if support_th:
+            self.td = '(./th | ./td)[%s]'
+        else:
+            self.td = './td[%s]'
+
     def __call__(self, item):
         for name in self.names:
             idx = item.parent.get_colnum(name)
             if idx is not None:
-                return item.xpath('./td[%s]' % (idx + 1))
+                return item.xpath(self.td % (idx + 1))
 
         return self.default_or_raise(ColumnNotFound('Unable to find column %s' % ' or '.join(self.names)))
 
 
 class RawText(Filter):
+    def __init__(self, selector=None, children=False, default=_NO_DEFAULT):
+        super(RawText, self).__init__(selector, default=default)
+        self.children = children
+
     @debug()
     def filter(self, el):
         if isinstance(el, (tuple, list)):
             return u' '.join([self.filter(e) for e in el])
 
-        if el.text is None:
-            return self.default
+        if self.children:
+            text = el.text_content()
         else:
-            return unicode(el.text)
+            text = el.text
+
+        if text is None:
+            result = self.default
+        else:
+            result = unicode(text)
+
+        return result
 
 
 class CleanText(Filter):
@@ -403,6 +427,27 @@ class Lower(CleanText):
         return txt.lower()
 
 
+class Upper(CleanText):
+    @debug()
+    def filter(self, txt):
+        txt = super(Upper, self).filter(txt)
+        return txt.upper()
+
+
+class Capitalize(CleanText):
+    @debug()
+    def filter(self, txt):
+        txt = super(Capitalize, self).filter(txt)
+        return txt.title()
+
+
+class Currency(CleanText):
+    @debug()
+    def filter(self, txt):
+        txt = super(Currency, self).filter(txt)
+        return BaseCurrency.get_currency(txt)
+
+
 class CleanDecimal(CleanText):
     """
     Get a cleaned Decimal value from an element.
@@ -590,11 +635,13 @@ class Map(Filter):
 
 
 class DateTime(Filter):
-    def __init__(self, selector=None, default=_NO_DEFAULT, dayfirst=False, translations=None, parse_func=parse_date):
+    def __init__(self, selector=None, default=_NO_DEFAULT, dayfirst=False, translations=None,
+                 parse_func=parse_date, fuzzy=False):
         super(DateTime, self).__init__(selector, default=default)
         self.dayfirst = dayfirst
         self.translations = translations
         self.parse_func = parse_func
+        self.fuzzy = fuzzy
 
     @debug()
     def filter(self, txt):
@@ -604,14 +651,16 @@ class DateTime(Filter):
             if self.translations:
                 for search, repl in self.translations:
                     txt = search.sub(repl, txt)
-            return self.parse_func(txt, dayfirst=self.dayfirst)
+            return self.parse_func(txt, dayfirst=self.dayfirst, fuzzy=self.fuzzy)
         except (ValueError, TypeError) as e:
             return self.default_or_raise(ParseError('Unable to parse %r: %s' % (txt, e)))
 
 
 class Date(DateTime):
-    def __init__(self, selector=None, default=_NO_DEFAULT, dayfirst=False, translations=None, parse_func=parse_date):
-        super(Date, self).__init__(selector, default=default, dayfirst=dayfirst, translations=translations, parse_func=parse_func)
+    def __init__(self, selector=None, default=_NO_DEFAULT, dayfirst=False, translations=None,
+                 parse_func=parse_date, fuzzy=False):
+        super(Date, self).__init__(selector, default=default, dayfirst=dayfirst, translations=translations,
+                                   parse_func=parse_func, fuzzy=fuzzy)
 
     @debug()
     def filter(self, txt):
