@@ -23,14 +23,18 @@ import warnings
 from io import BytesIO
 import codecs
 from cgi import parse_header
-import urlparse
+try:
+    import urlparse
+except ImportError:
+    import urllib.parse as urlparse
 
 import requests
 
-from weboob.tools.ordereddict import OrderedDict
+from weboob.exceptions import ParseError, ModuleInstallError
 from weboob.tools.compat import basestring
-
 from weboob.tools.log import getLogger
+from weboob.tools.ordereddict import OrderedDict
+from weboob.tools.pdf import decompress_pdf
 
 
 def pagination(func):
@@ -53,7 +57,7 @@ def pagination(func):
     >>> from .browsers import PagesBrowser
     >>> from .url import URL
     >>> class Browser(PagesBrowser):
-    ...     BASEURL = 'http://people.symlink.me'
+    ...     BASEURL = 'https://people.symlink.me'
     ...     list = URL('/~rom1/projects/weboob/list-(?P<pagenum>\d+).html', Page)
     ...
     >>> b = Browser()
@@ -119,7 +123,7 @@ class Page(object):
 
     logged = False
     """
-    If True, the page is in a restrected area of the wesite. Useful with
+    If True, the page is in a restricted area of the website. Useful with
     :class:`LoginBrowser` and the :func:`need_login` decorator.
     """
 
@@ -249,6 +253,7 @@ class Form(OrderedDict):
         self.method = el.attrib.get('method', 'GET')
         self.url = el.attrib.get('action', page.url)
         self.name = el.attrib.get('name', '')
+        self.req = None
         submits = 0
 
         # Find all elements of the form that will be useful to create the request
@@ -306,12 +311,13 @@ class Form(OrderedDict):
         """
         Get the Request object from the form.
         """
-        if self.method.lower() == 'get':
-            req = requests.Request(self.method, self.url, params=self)
-        else:
-            req = requests.Request(self.method, self.url, data=self)
-        req.headers.setdefault('Referer', self.page.url)
-        return req
+        if self.req is None:
+            if self.method.lower() == 'get':
+                self.req = requests.Request(self.method, self.url, params=self)
+            else:
+                self.req = requests.Request(self.method, self.url, data=self)
+            self.req.headers.setdefault('Referer', self.page.url)
+        return self.req
 
     def submit(self, **kwargs):
         """
@@ -429,6 +435,51 @@ class JsonPage(Page):
         return json.loads(text)
 
 
+class XLSPage(Page):
+    """
+    XLS Page.
+    """
+
+    HEADER = None
+    """
+    If not None, will consider the line represented by this index as a header.
+    """
+
+    SHEET_INDEX = 0
+    """
+    Specify the index of the worksheet to use.
+    """
+
+    def build_doc(self, content):
+        return self.parse(content)
+
+    def parse(self, data):
+        """
+        Method called by the constructor of :class:`XLSPage` to parse the document.
+        """
+        import xlrd
+        wb = xlrd.open_workbook(file_contents=data)
+        sh = wb.sheet_by_index(self.SHEET_INDEX)
+
+        header = None
+        drows = []
+        rows = []
+        for i in range(sh.nrows - 1):
+            if self.HEADER and i + 1 < self.HEADER:
+                continue
+            row = sh.row_values(i)
+            if header is None and self.HEADER:
+                header = map(lambda s: s.replace('/', ''), row)
+            else:
+                rows.append(row)
+                if header:
+                    drow = {}
+                    for i, cell in enumerate(sh.row_values(i)):
+                        drow[header[i]] = cell
+                    drows.append(drow)
+        return drows if header is not None else rows
+
+
 class XMLPage(Page):
     """
     XML Page.
@@ -550,14 +601,32 @@ class HTMLPage(Page):
             expressions = ' and '.join(["contains(concat(' ', normalize-space(@class), ' '), ' {0} ')".format(c) for c in classes])
             xpath = 'self::*[@class and {0}]'.format(expressions)
             return bool(context.context_node.xpath(xpath))
+
+        def starts_with(context, text, prefix):
+            if not isinstance(text, list):
+                text = [text]
+            return any(t.startswith(prefix) for t in text)
+
+        def ends_with(context, text, suffix):
+            if not isinstance(text, list):
+                text = [text]
+            return any(t.endswith(suffix) for t in text)
+
         ns['has-class'] = has_class
+        ns['starts-with'] = starts_with
+        ns['ends-with'] = ends_with
 
     def build_doc(self, content):
         """
         Method to build the lxml document from response and given encoding.
         """
+        encoding = self.encoding
+        if encoding == 'latin-1':
+            encoding = 'latin1'
+        if encoding:
+            encoding = encoding.replace('ISO8859_', 'ISO8859-')
         import lxml.html as html
-        parser = html.HTMLParser(encoding=self.encoding)
+        parser = html.HTMLParser(encoding=encoding)
         return html.parse(BytesIO(content), parser)
 
     def detect_encoding(self):
@@ -624,12 +693,84 @@ class HTMLPage(Page):
         raise FormNotFound()
 
 
+class PartialHTMLPage(HTMLPage):
+    def build_doc(self, content):
+        import lxml.etree
+        try:
+            return super(PartialHTMLPage, self).build_doc(content)
+        except lxml.etree.XMLSyntaxError:
+            content = '<html>%s</html>' % content
+            return super(PartialHTMLPage, self).build_doc(content)
+
+
+class GWTPage(Page):
+    """
+    GWT page where the "doc" attribute is a list
+
+    More info about GWT protcol here : https://goo.gl/GP5dv9
+    """
+
+    def build_doc(self, content):
+        """
+        Reponse starts with "//" followed by "OK" or "EX".
+        2 last elements in list are protocol and flag.
+        We need to read the list in reversed order.
+        """
+
+        assert content[2:4] == "OK"
+        doc, array = [], []
+        from ast import literal_eval
+        for el in reversed(literal_eval(content[4:])[:-2]):
+            # If we find an array, args after are indices or date
+            if not array and isinstance(el, list):
+                array = el
+            elif array and isinstance(el, int) and len(array) >= el >= 1:
+                doc.append(array[el - 1])
+            elif array and isinstance(el, basestring):
+                doc.append(self.get_date(el))
+        return doc
+
+    def get_date(self, data):
+        """
+        Get date from string
+        """
+
+        base = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_$"
+        timestamp = sum(base.index(data[el]) * (len(base) ** (len(data) - el - 1)) for el in range(len(data)))
+        from datetime import datetime
+        return datetime.fromtimestamp(int(str(timestamp)[:10])).strftime('%d/%m/%Y')
+
+    def get_elements(self, type="String"):
+        """
+        Get elements of specified type
+        """
+
+        strings = []
+        for i, el in enumerate(self.doc):
+            if i > 0 and ".%s" % type in self.doc[i - 1]:
+                strings.append(el)
+        return [string for string in strings if "java." not in string]
+
+
+class PDFPage(Page):
+    """
+    Parse a PDF and write raw data in the "doc" attribute as a string.
+    """
+    def build_doc(self, content):
+        try:
+            doc = decompress_pdf(content)
+        except OSError as e:
+            raise ParseError(u'Make sure mupdf-tools is installed (%s)' % e)
+
+        return doc
+
+
 class LoggedPage(object):
     """
     A page that only logged users can reach. If we did not get a redirection
     for this page, we are sure that the login is still active.
 
-    Do not use this class for page we mixed content (logged/anonymous) or for
+    Do not use this class for page with mixed content (logged/anonymous) or for
     pages with a login form.
     """
     logged = True
@@ -647,3 +788,41 @@ class ChecksumPage(object):
     def build_doc(self, content):
         self.checksum = self.hashfunc(content).hexdigest()
         return super(ChecksumPage, self).build_doc(content)
+
+
+class AbstractPageError(Exception):
+    pass
+
+
+class AbstractPage(Page):
+    PARENT = None
+    PARENT_URL = None
+    BROWSER_ATTR = None
+
+    def __new__(cls, browser, *args, **kwargs):
+        weboob = getattr(browser, 'weboob', None)
+        if not weboob:
+            raise AbstractPageError("weboob is not defined in %s" % browser)
+
+        if cls.PARENT is None:
+            raise AbstractPageError("PARENT is not defined for page %s" % cls.__name__)
+
+        if cls.PARENT_URL is None:
+            raise AbstractPageError("PARENT_URL is not defined for page %s" % cls.__name__)
+
+        try:
+            parent_module = weboob.load_or_install_module(cls.PARENT)
+        except ModuleInstallError as err:
+            raise ModuleInstallError('This module depends on %s module but %s\'s installation failed with: %s' % (cls.PARENT, cls.PARENT, err))
+
+        if cls.BROWSER_ATTR is None:
+            parent_browser = parent_module.klass.BROWSER
+        else:
+            parent_browser = reduce(getattr, cls.BROWSER_ATTR.split('.'), parent_module)
+
+        parent = parent_browser._urls.get(cls.PARENT_URL, None)
+        if parent is None:
+            raise AbstractPageError("cls.PARENT_URL is not defined in %s" % browser)
+
+        cls.__bases__ = (parent.klass,)
+        return cls.__new__(cls, browser, *args, **kwargs)
