@@ -49,14 +49,13 @@ class ContactPhoto(BaseObject):
     Photo of a contact.
     """
     name =              StringField('Name of the photo')
-    url =               StringField('Direct URL to photo')
     data =              BytesField('Data of photo')
     thumbnail_url =     StringField('Direct URL to thumbnail')
     thumbnail_data =    BytesField('Data of thumbnail')
     hidden =            Field('True if the photo is hidden on website', bool)
 
-    def __init__(self, name):
-        BaseObject.__init__(self, name)
+    def __init__(self, name, url=None):
+        BaseObject.__init__(self, name, url)
         self.name = name
 
     def __iscomplete__(self):
@@ -66,12 +65,32 @@ class ContactPhoto(BaseObject):
         return self.url
 
     def __repr__(self):
-        return u'<ContactPhoto "%s" data=%do tndata=%do>' % (self.id,
-                                                             len(self.data) if self.data else 0,
-                                                             len(self.thumbnail_data) if self.thumbnail_data else 0)
+        return '<ContactPhoto %r data=%do tndata=%do>' % (self.id,
+                                                          len(self.data) if self.data else 0,
+                                                          len(self.thumbnail_data) if self.thumbnail_data else 0)
 
 
-class Contact(BaseObject):
+class BaseContact(BaseObject):
+    """
+    This is the blase class for a contact.
+    """
+    name =      StringField('Name of contact')
+
+
+class Advisor(BaseContact):
+    """
+    An advisor.
+    """
+    email =     StringField('Mail of advisor')
+    phone =     StringField('Phone number of advisor')
+    mobile =    StringField('Mobile number of advisor')
+    fax =       StringField('Fax number of advisor')
+    agency =    StringField('Name of agency')
+    address =   StringField('Address of agency')
+    role =      StringField('Role of advisor', default="bank")
+
+
+class Contact(BaseContact):
     """
     A contact.
     """
@@ -80,16 +99,14 @@ class Contact(BaseObject):
     STATUS_OFFLINE = 0x004
     STATUS_ALL =     0xfff
 
-    name =          StringField('Name of contact')
     status =        IntField('Status of contact (STATUS_* constants)')
-    url =           StringField('URL to the profile of contact')
     status_msg =    StringField('Message of status')
     summary =       StringField('Description of contact')
     photos =        Field('List of photos', dict, default=OrderedDict())
     profile =       Field('Contact profile', dict, default=OrderedDict())
 
-    def __init__(self, id, name, status):
-        BaseObject.__init__(self, id)
+    def __init__(self, id, name, status, url=None):
+        BaseObject.__init__(self, id, url)
         self.name = name
         self.status = status
 
@@ -160,8 +177,8 @@ class Query(BaseObject):
     """
     message =   StringField('Message received')
 
-    def __init__(self, id, message):
-        BaseObject.__init__(self, id)
+    def __init__(self, id, message, url=None):
+        BaseObject.__init__(self, id, url)
         self.message = message
 
 
