@@ -19,7 +19,7 @@
 
 
 from .base import Capability, BaseObject, Field, IntField, DecimalField, \
-                  StringField, BytesField, enum, UserError
+                  StringField, BytesField, enum, UserError, FloatField
 from .date import DateField
 
 __all__ = ['HousingPhoto', 'Housing', 'Query', 'City', 'CapHousing']
@@ -39,12 +39,10 @@ class HousingPhoto(BaseObject):
     """
     Photo of a housing.
     """
-    url =       StringField('Direct URL to photo')
     data =      BytesField('Data of photo')
 
     def __init__(self, url):
-        BaseObject.__init__(self, url.split('/')[-1])
-        self.url = url
+        BaseObject.__init__(self, url.split('/')[-1], url)
 
     def __iscomplete__(self):
         return self.data
@@ -53,25 +51,25 @@ class HousingPhoto(BaseObject):
         return self.url
 
     def __repr__(self):
-        return u'<HousingPhoto "%s" data=%do>' % (self.id, len(self.data) if self.data else 0)
+        return '<HousingPhoto %r data=%do url=%r>' % (self.id, len(self.data) if self.data else 0, self.url)
 
 
 class Housing(BaseObject):
     """
     Content of a housing.
     """
-    title =         StringField('Title of housing')
-    area =          DecimalField('Area of housing, in m2')
-    cost =          DecimalField('Cost of housing')
-    currency =      StringField('Currency of cost')
-    date =          DateField('Date when the housing has been published')
-    location =      StringField('Location of housing')
-    station =       StringField('What metro/bus station next to housing')
-    text =          StringField('Text of the housing')
-    phone =         StringField('Phone number to contact')
-    photos =        Field('List of photos', list)
-    details =       Field('Key/values of details', dict)
-    url =           StringField('Url of the the advert')
+    title =           StringField('Title of housing')
+    area =            DecimalField('Area of housing, in m2')
+    cost =            DecimalField('Cost of housing')
+    price_per_meter = FloatField('Price per meter ratio')
+    currency =        StringField('Currency of cost')
+    date =            DateField('Date when the housing has been published')
+    location =        StringField('Location of housing')
+    station =         StringField('What metro/bus station next to housing')
+    text =            StringField('Text of the housing')
+    phone =           StringField('Phone number to contact')
+    photos =          Field('List of photos', list)
+    details =         Field('Key/values of details', dict)
 
 
 class Query(BaseObject):
