@@ -21,13 +21,15 @@
 import os
 
 from weboob.core.bcall import BackendsCall
-from weboob.core.modules import ModulesLoader, RepositoryModulesLoader, ModuleLoadError
+from weboob.core.modules import ModulesLoader, RepositoryModulesLoader
 from weboob.core.backendscfg import BackendsConfig
+from weboob.core.requests import RequestsManager
 from weboob.core.repositories import Repositories, PrintProgress
 from weboob.core.scheduler import Scheduler
 from weboob.tools.backend import Module
 from weboob.tools.config.iconfig import ConfigError
 from weboob.tools.log import getLogger
+from weboob.exceptions import ModuleLoadError
 
 
 __all__ = ['WebNip', 'Weboob']
@@ -51,14 +53,12 @@ class WebNip(object):
     :param scheduler: what scheduler to use; default is :class:`weboob.core.scheduler.Scheduler`
     :type scheduler: :class:`weboob.core.scheduler.IScheduler`
     """
-    VERSION = '1.1'
+    VERSION = '1.2'
 
     def __init__(self, modules_path=None, storage=None, scheduler=None):
         self.logger = getLogger('weboob')
         self.backend_instances = {}
-        self.callbacks = {'login':   lambda backend_name, value: None,
-                          'captcha': lambda backend_name, image: None,
-                         }
+        self.requests = RequestsManager()
 
         if modules_path is None:
             import pkg_resources
@@ -83,7 +83,7 @@ class WebNip(object):
         """
         self.unload_backends()
 
-    def build_backend(self, module_name, params=None, storage=None, name=None):
+    def build_backend(self, module_name, params=None, storage=None, name=None, nofail=False):
         """
         Create a backend.
 
@@ -98,10 +98,12 @@ class WebNip(object):
         :param name: name of backend
         :type name: :class:`basestring`
         :rtype: :class:`weboob.tools.backend.Module`
+        :param nofail: if true, this call can't fail
+        :type nofail: :class:`bool`
         """
         module = self.modules_loader.get_or_load_module(module_name)
 
-        backend_instance = module.create_instance(self, name or module_name, params or {}, storage)
+        backend_instance = module.create_instance(self, name or module_name, params or {}, storage, nofail)
         return backend_instance
 
     class LoadError(Exception):
@@ -315,6 +317,10 @@ class WebNip(object):
         """
         return self.scheduler.run()
 
+    def load_or_install_module(self, module_name):
+        """ Load a backend, but can't install it """
+        return self.modules_loader.get_or_load_module(module_name)
+
 
 class Weboob(WebNip):
     """
@@ -387,7 +393,7 @@ class Weboob(WebNip):
             if minfo and not minfo.is_installed():
                 self.repositories.install(minfo, progress)
 
-    def build_backend(self, module_name, params=None, storage=None, name=None):
+    def build_backend(self, module_name, params=None, storage=None, name=None, nofail=False):
         """
         Create a single backend which is not listed in configuration.
 
@@ -399,6 +405,8 @@ class Weboob(WebNip):
         :param name: name of backend
         :type name: :class:`basestring`
         :rtype: :class:`weboob.tools.backend.Module`
+        :param nofail: if true, this call can't fail
+        :type nofail: :class:`bool`
         """
         minfo = self.repositories.get_module_info(module_name)
         if minfo is None:
@@ -407,7 +415,7 @@ class Weboob(WebNip):
         if not minfo.is_installed():
             self.repositories.install(minfo)
 
-        return super(Weboob, self).build_backend(module_name, params, storage, name)
+        return super(Weboob, self).build_backend(module_name, params, storage, name, nofail)
 
     def load_backends(self, caps=None, names=None, modules=None, exclude=None, storage=None, errors=None):
         """
@@ -474,3 +482,11 @@ class Weboob(WebNip):
             else:
                 self.backend_instances[backend_name] = loaded[backend_name] = backend_instance
         return loaded
+
+    def load_or_install_module(self, module_name):
+        """ Load a backend, and install it if not done before """
+        try:
+            return self.modules_loader.get_or_load_module(module_name)
+        except ModuleLoadError:
+            self.repositories.install(module_name)
+            return self.modules_loader.get_or_load_module(module_name)
