@@ -32,7 +32,7 @@ from contextlib import closing
 from compileall import compile_dir
 from io import BytesIO
 
-from weboob.exceptions import BrowserHTTPError, BrowserHTTPNotFound
+from weboob.exceptions import BrowserHTTPError, BrowserHTTPNotFound, ModuleInstallError
 from .modules import LoadedModule
 from weboob.tools.log import getLogger
 from weboob.tools.misc import get_backtrace, to_unicode, find_exe
@@ -72,10 +72,10 @@ class ModuleInfo(object):
         self.icon = items['icon'].strip() or None
         self.urls = items['urls']
 
-    def has_caps(self, caps):
+    def has_caps(self, *caps):
         """Return True if module implements at least one of the caps."""
-        if not isinstance(caps, (list, tuple)):
-            caps = [caps]
+        if len(caps) == 1 and isinstance(caps[0], (list, tuple)):
+            caps = caps[0]
         for c in caps:
             if type(c) == type:
                 c = c.__name__
@@ -401,10 +401,6 @@ class PrintProgress(IProgress):
         return True
 
 
-class ModuleInstallError(Exception):
-    pass
-
-
 DEFAULT_SOURCES_LIST = \
 """# List of Weboob repositories
 #
@@ -626,7 +622,8 @@ class Repositories(object):
         to_update = []
         for name, info in self.get_all_modules_info().iteritems():
             if not info.is_local() and info.is_installed():
-                to_update.append(info)
+                if self.versions.get(name) != info.version:
+                    to_update.append(info)
 
         if len(to_update) == 0:
             progress.progress(1.0, 'All modules are up-to-date.')
@@ -802,6 +799,7 @@ class Keyring(object):
             try:
                 sigfile.write(sigdata)
                 sigfile.flush()  # very important
+                sigfile.close()
                 assert isinstance(data, basestring)
                 # Yes, all of it is necessary
                 proc = subprocess.Popen(verify_command + [
