@@ -30,9 +30,11 @@ import os
 from weboob.capabilities import UserError
 from weboob.capabilities.account import CapAccount, Account, AccountRegisterError
 from weboob.core.backendscfg import BackendAlreadyExists
-from weboob.core.modules import ModuleLoadError
-from weboob.core.repositories import ModuleInstallError, IProgress
-from weboob.exceptions import BrowserUnavailable, BrowserIncorrectPassword, BrowserForbidden, BrowserSSLError, BrowserQuestion
+from weboob.core.repositories import IProgress
+from weboob.exceptions import BrowserUnavailable, BrowserIncorrectPassword, BrowserForbidden, \
+                              BrowserSSLError, BrowserQuestion, BrowserHTTPSDowngrade, \
+                              ModuleInstallError, ModuleLoadError, NoAccountsException, \
+                              ActionNeeded
 from weboob.tools.value import Value, ValueBool, ValueFloat, ValueInt, ValueBackendPassword
 from weboob.tools.misc import to_unicode
 from weboob.tools.compat import check_output
@@ -90,7 +92,7 @@ class ConsoleApplication(Application):
 
     def __init__(self, option_parser=None):
         Application.__init__(self, option_parser)
-        self.weboob.callbacks['login'] = self.login_cb
+        self.weboob.requests.register('login', self.login_cb)
         self.enabled_backends = set()
 
     def login_cb(self, backend_name, value):
@@ -521,6 +523,9 @@ class ConsoleApplication(Application):
         v.noprompt = True
         return v.get()
 
+    def print(self, txt):
+        print(txt.encode(self.encoding, "replace"))
+
     def acquire_input(self, content=None, editor_params=None):
         editor = os.getenv('EDITOR', 'vi')
         if self.stdin.isatty() and editor:
@@ -568,22 +573,27 @@ class ConsoleApplication(Application):
                 self.load_backends(names=[backend.name])
         elif isinstance(error, BrowserSSLError):
             print(u'FATAL(%s): ' % backend.name + self.BOLD + '/!\ SERVER CERTIFICATE IS INVALID /!\\' + self.NC, file=self.stderr)
+        elif isinstance(error, BrowserHTTPSDowngrade):
+            print(u'FATAL(%s): ' % backend.name + 'Downgrade from HTTPS to HTTP')
         elif isinstance(error, BrowserForbidden):
             msg = unicode(error)
             print(u'Error(%s): %s' % (backend.name, msg or 'Forbidden'), file=self.stderr)
         elif isinstance(error, BrowserUnavailable):
             msg = unicode(error)
-            if not msg:
-                msg = 'website is unavailable.'
-            print(u'Error(%s): %s' % (backend.name, msg), file=self.stderr)
+            print(u'Error(%s): %s' % (backend.name, msg or 'Website is unavailable.'), file=self.stderr)
+        elif isinstance(error, ActionNeeded):
+            msg = unicode(error)
+            print(u'Error(%s): Action needed on website: %s' % (backend.name, msg), file=self.stderr)
         elif isinstance(error, NotImplementedError):
             print(u'Error(%s): this feature is not supported yet by this backend.' % backend.name, file=self.stderr)
             print(u'      %s   To help the maintainer of this backend implement this feature,' % (' ' * len(backend.name)), file=self.stderr)
-            print(u'      %s   please contact: %s <%s@issues.weboob.org>' % (' ' * len(backend.name), backend.MAINTAINER, backend.NAME), file=self.stderr)
+            print(u'      %s   please contact us on the project mailing list' % (' ' * len(backend.name)), file=self.stderr)
         elif isinstance(error, UserError):
             print(u'Error(%s): %s' % (backend.name, to_unicode(error)), file=self.stderr)
         elif isinstance(error, MoreResultsAvailable):
             print(u'Hint: There are more results for backend %s' % (backend.name), file=self.stderr)
+        elif isinstance(error, NoAccountsException):
+            print(u'Error(%s): %s' % (backend.name, to_unicode(error) or 'No account on this backend'), file=self.stderr)
         else:
             print(u'Bug(%s): %s' % (backend.name, to_unicode(error)), file=self.stderr)
 
