@@ -282,12 +282,11 @@ class ReplApplication(Cmd, ConsoleApplication):
             return self.objects
         elif method is not None:
             kwargs['backends'] = self.enabled_backends
-            for _object in self.weboob.do(self._do_complete, None, None, method, *args, **kwargs):
+            for _object in self.do(method, *args, **kwargs):
                 self.add_object(_object)
             return self.objects
         # XXX: what can we do without method?
-        else:
-            return tuple()
+        return tuple()
 
     def unload_backends(self, *args, **kwargs):
         self.objects = []
@@ -965,8 +964,8 @@ class ReplApplication(Cmd, ConsoleApplication):
                 return -1
         elif obj1.backend > obj2.backend:
             return 1
-        else:
-            return -1
+
+        return -1
 
 
     @defaultcount(40)
@@ -980,7 +979,7 @@ class ReplApplication(Cmd, ConsoleApplication):
         return results as soon as possible.
         Use -d option to display information about a collection (and to not
         display the content of it). It has the same behavior than the well
-        know UNIX "ls" command.
+        known UNIX "ls" command.
         """
         # TODO: real parsing of options
         path = line.strip()
