@@ -102,15 +102,15 @@ class Value(object):
             raise ValueError('Value "%s" is not in list: %s' % (
                 self.show_value(v), ', '.join(unicode(s) for s in self.choices)))
 
-    def load(self, domain, v, callbacks):
+    def load(self, domain, v, requests):
         """
         Load value.
 
         :param domain: what is the domain of this value
         :type domain: str
         :param v: value to load
-        :param callbacks: list of weboob callbacks
-        :type callbacks: dict
+        :param requests: list of weboob requests
+        :type requests: weboob.core.requests.Requests
         """
         return self.set(v)
 
@@ -145,15 +145,16 @@ class Value(object):
 
 class ValueBackendPassword(Value):
     _domain = None
-    _callbacks = {}
+    _requests = None
     _stored = True
 
     def __init__(self, *args, **kwargs):
         kwargs['masked'] = kwargs.pop('masked', True)
         self.noprompt = kwargs.pop('noprompt', False)
         Value.__init__(self, *args, **kwargs)
+        self.default = kwargs.get('default', '')
 
-    def load(self, domain, password, callbacks):
+    def load(self, domain, password, requests):
         if self.is_command(password):
             cmd = password[1:-1]
             try:
@@ -165,7 +166,7 @@ class ValueBackendPassword(Value):
         self.check_valid(password)
         self._domain = domain
         self._value = to_unicode(password)
-        self._callbacks = callbacks
+        self._requests = requests
 
     def check_valid(self, passwd):
         if passwd == '':
@@ -221,11 +222,12 @@ class ValueBackendPassword(Value):
             return to_unicode(passwd)
 
         # Prompt user to enter password by hand.
-        if not self.noprompt and 'login' in self._callbacks:
-            self._value = to_unicode(self._callbacks['login'](self._domain, self))
+        if not self.noprompt and self._requests:
+            self._value = self._requests.request('login', self._domain, self)
             if self._value is None:
                 self._value = ''
             else:
+                self._value = to_unicode(self._value)
                 self._stored = False
         return self._value
 
@@ -234,6 +236,7 @@ class ValueInt(Value):
     def __init__(self, *args, **kwargs):
         kwargs['regexp'] = '^\d+$'
         Value.__init__(self, *args, **kwargs)
+        self.default = kwargs.get('default', 0)
 
     def get(self):
         return int(self._value)
@@ -243,6 +246,7 @@ class ValueFloat(Value):
     def __init__(self, *args, **kwargs):
         kwargs['regexp'] = '^[\d\.]+$'
         Value.__init__(self, *args, **kwargs)
+        self.default = kwargs.get('default', 0.0)
 
     def check_valid(self, v):
         try:
@@ -258,6 +262,7 @@ class ValueBool(Value):
     def __init__(self, *args, **kwargs):
         kwargs['choices'] = {'y': 'True', 'n': 'False'}
         Value.__init__(self, *args, **kwargs)
+        self.default = kwargs.get('default', False)
 
     def check_valid(self, v):
         if not isinstance(v, bool) and \
